// Copyright 2024 Yuji Tanaka
// HP : http://galaxystar.image.coocan.jp/
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
#include <SPI.h>
#include <ILI9341_game.h>
#include <XPT2046_Touchscreen.h>
#include "gmahj.h"
#include "jis_font.h"
#include "pitches.h"

#define debug  0
#define ver 110

#define TFT_DC 48
#define TFT_CS 47
#define TFT_RST 45

// ILI9341_game tft = ILI9341_game(TFT_CS, TFT_DC, TFT_MOSI, TFT_SCLK, TFT_RST, -1);
ILI9341_game tft = ILI9341_game(TFT_CS, TFT_DC, TFT_RST);

#define CS_PIN 39
XPT2046_Touchscreen ts(CS_PIN);
#define TIRQ_PIN 38
#define TS_MINX 400
#define TS_MINY 300
#define TS_MAXX 3900
#define TS_MAXY 3800

boolean istouched, wastouched;

#define XMAX 240
#define YMAX 320
#define STARTX 0
#define STARTY 0
#define SIZEX 16
#define SIZEY 24

int _width, _height;

int StickXPin = 6;
int StickYPin = 7;
int StickX;
int StickY;

int ButtonAPin = 15;
int ButtonBPin = 16;
int ButtonA;
int ButtonB;

int SoundPin = 17;

#define SCREEN_WIDTH  240
#define SCREEN_HEIGHT 320
#define SCREEN_START_X 0
#define SCREEN_START_Y 0

static const uint16_t ten1000_bmp[] =
{
0x0001, 0x0001, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0x0001, 0x0001,
0x0001, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xfc00, 0xfc00, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0x0001,
0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xfc00, 0xfc00, 0xfc00, 0xfc00, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff,
0x0001, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xfc00, 0xfc00, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0x0001,
0x0001, 0x0001, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0x0001, 0x0001
};
static const uint16_t ten100_bmp[] =
{
0x0001, 0x0001, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0x0001, 0x0001,
0x0001, 0xffff, 0xffff, 0x0000, 0xffff, 0x0000, 0xffff, 0x0000, 0xffff, 0x0000, 0xffff, 0x0000, 0xffff, 0x0000, 0xffff, 0x0001,
0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff,
0x0001, 0xffff, 0xffff, 0x0000, 0xffff, 0x0000, 0xffff, 0x0000, 0xffff, 0x0000, 0xffff, 0x0000, 0xffff, 0x0000, 0xffff, 0x0001,
0x0001, 0x0001, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0x0001, 0x0001
};
static const uint16_t pai_mem[] =
{
0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xEF5D, 0xAD55, 0xBDF7, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xEF5D, 0xAD55, 0xAD55, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD6BA, 0xAD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAD55, 0xEF5D, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD6BA, 0xD6BA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAD55, 0x528A, 0xAD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xBDF7, 0x528A, 0x39E7, 0x0000, 0xAD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x528A, 0x528A, 0x528A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD6BA, 0x528A, 0xFFFF, 0xAD55, 0x39E7, 0x0000, 0x8410, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7BEF, 0x0000, 0xD6BA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0000, 0x94B2, 0xFFFF, 0xFFFF, 0x528A, 0x528A, 0xAD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD6BA, 0x52AA, 0xFFFF, 0xD6BA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8410, 0x0000, 0x0000, 0x7BEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8410, 0x0000, 0x0000, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0000, 0x0000, 0x8410, 0xFFFF, 0x0000, 0x7BEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7BEF, 0x0000, 0x0000, 0x0000, 0x7BEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xBDF7, 0x0000, 0xFFFF, 0xFFFF, 0x8410, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0000, 0x7BEF, 0xFFFF, 0x7BEF, 0x0000, 0x0000, 0x0000, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0000, 0x8410, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x4208, 0xFFFF, 0x0000, 0x0000, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xCE59, 0xAD55, 0xF7BE, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8410, 0x52AA, 0xAD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xEF5D, 0xAD55, 0xEF5D, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xEF5D, 0xD6BA, 0xBDF7, 0x52AA, 0x10A2, 0xAD55, 0x4208, 0xFFFF, 0xD6BA, 0x0000, 0x94B2, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x6B4D, 0x52AA, 0xBDF7, 0x0000, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD6BA, 0x7BEF, 0x0000, 0x4208, 0x52AA, 0x10A2, 0x0000, 0xD6BD, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0000, 0xBDF7, 0xAD55, 0x4208, 0xAD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x2945, 0xD6BA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD6BA, 0x2945, 0x2945, 0x2104, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD6BA, 0x528A, 0x528A, 0x18E3, 0x0000, 0x4A49, 0xAD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xEF5D, 0xAD55, 0x39E7, 0x52AA, 0xD6BA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xEF5D, 0x2945, 0xC618, 0xAD55, 0x10A2, 0xFFFF, 0x6B4D, 0xFFFF, 0x52AA, 0x0000, 0xEF5D, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x4208, 0xFFFF, 0x94B2, 0x0000, 0x528A, 0x528A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x528A, 0x528A, 0x2945, 0x2945, 0xAD55, 0xC618, 0xFFFF, 0xC618, 0xAD55, 0xD6BD, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x52AA, 0x39E7, 0x52AA, 0xEF5D, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x528A, 0xD6BA, 0xD6BA, 0x2945, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x528A, 0x2945, 0x2945, 0xD6BA, 0x73AE, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0x7BEF, 0x0000, 0x0000, 0x0000, 0x0000, 0xC618, 0xFFFF, 0xFFFF, 0x630C, 0x0000, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x630C, 0x0000, 0xDEFB, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xBDF7, 0x0000, 0xBDF7, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0000, 0x7BEF, 0xFFFF, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8410, 0x7BEF, 0xFFFF, 0x0000, 0x0000, 0x0000, 0x0000, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8410, 0xFFFF, 0xBDF7, 0xFFFF, 0xBDF7, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8410, 0x7BEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0000, 0x7BEF, 0xFFFF, 0x4208, 0x8410, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xBDF7, 0xFFFF, 0x7BEF, 0xFFFF, 0x7BEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xD6BA, 0x52AA, 0x94B2, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD6BA, 0xAD55, 0xAD55, 0x7BEF, 0x0000, 0x4208, 0x52AA, 0x52AA, 0x2104, 0x52AA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xEF5D, 0xAD55, 0xAD55, 0x39E7, 0x0000, 0x94B2, 0xD6BA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x2945, 0x52AA, 0x52AA, 0x52AA, 0x8410, 0xAD55, 0xAD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD6BA, 0x2945, 0x7BEF, 0xFFFF, 0x6B4D, 0xFFFF, 0x6B4D, 0xAD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD6BA, 0x0000, 0xFFFF, 0x94B2, 0x52AA, 0xD6BA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x94B2, 0x2945, 0xAD55, 0xFFFF, 0xEF5D, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAD55, 0x0000, 0xAD55, 0xFFFF, 0xAD55, 0x0000, 0x52AA, 0xD6BA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x52AA, 0x94B2, 0xFFFF, 0x6B4D, 0xFFFF, 0xFFFF, 0x52AA, 0xFFFF, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAD55, 0x0000, 0x4208, 0xAD55, 0xAD55, 0xEF5D, 0xFFFF, 0xFFFF, 0xCE59, 0xAD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAD55, 0x528A, 0x528A, 0x39E7, 0x0000, 0x8410, 0xAD55, 0xAD55, 0x4208, 0x2945, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD6BA, 0xAD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7BEF, 0xD6BA, 0x7BEF, 0xFFFF, 0x52AA, 0xAD55, 0x10A2, 0x528A, 0x528A, 0x528A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD6BA, 0x2945, 0x52AA, 0xFFFF, 0xEF5D, 0x0000, 0x52AA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x528A, 0x4208, 0xD6BA, 0x294A, 0x528A, 0x39E7, 0x528A, 0xD6BA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x52AA, 0xAD55, 0xFFFF, 0xFFFF, 0xFFFF, 0x52AA, 0x0000, 0x2945, 0x7BEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD6BA, 0x0000, 0xEF5D, 0xFFFF, 0x4208, 0x528A, 0x528A, 0x0000, 0xAD55, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xBDF7, 0x0000, 0x630C, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7BEF, 0x0000, 0x0000, 0x0000, 0x7BEF, 0xFFFF, 0x7BEF, 0x0000, 0x7BEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x4208, 0x8410, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0000, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8410, 0xBDF7, 0xFFFF, 0xFFFF, 0x0000, 0x0000, 0x0000, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8410, 0x7BEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x4208, 0x0000, 0x0000, 0x0000, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7BEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0000, 0x0000, 0x0000, 0x7BEF, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFBEF, 0xFD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFBEF, 0xFD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFBEF, 0xFD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFBEF, 0xFD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x52AA, 0xAD55, 0xD6BA, 0xFFFF, 0xFBEF, 0xFD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFBEF, 0xFD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFBEF, 0xFD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD6BA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFBEF, 0xFD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFBEF, 0xFD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xFFFF, 0xF945, 0xFD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xFFFF, 0xF945, 0xFD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xFFFF, 0xF945, 0xFD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xFFFF, 0xF945, 0xFD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD6BA, 0xFFFF, 0xFD55, 0xFFFF, 0xF945, 0xFD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xFFFF, 0xF945, 0xFD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xFFFF, 0xF945, 0xFD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xFFFF, 0xF945, 0xFD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xFFFF, 0xF945, 0xFD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFBEF, 0xF800, 0xF800, 0xF800, 0xFBEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFBEF, 0xF800, 0xF800, 0xF800, 0xFBEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFBEF, 0xF800, 0xF800, 0xF800, 0xFBEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFBEF, 0xF800, 0xF800, 0xF800, 0xFBEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFBEF, 0xF800, 0xF800, 0xF800, 0xFBEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFBEF, 0xF800, 0xF800, 0xF800, 0xFBEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFBEF, 0xF800, 0xF800, 0xF800, 0xFBEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFBEF, 0xF800, 0xF800, 0xF800, 0xFBEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFBEF, 0xF800, 0xF800, 0xF800, 0xFBEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xF800, 0xF945, 0xFAAA, 0xFD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xF800, 0xF945, 0xFAAA, 0xFD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xF800, 0xF945, 0xFAAA, 0xFD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xF800, 0xF945, 0xFAAA, 0xFD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xF800, 0xF945, 0xFAAA, 0xFD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xF800, 0xF945, 0xFAAA, 0xFD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xF800, 0xF945, 0xFAAA, 0xFD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xF800, 0xF945, 0xFAAA, 0xFD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xF800, 0xF945, 0xFAAA, 0xFD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xFD55, 0xFEBA, 0xFA8A, 0xFA8A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xFD55, 0xFEBA, 0xFA8A, 0xFA8A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xFD55, 0xFEBA, 0xFA8A, 0xFA8A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xFD55, 0xFEBA, 0xFA8A, 0xFA8A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xFD55, 0xFEBA, 0xFA8A, 0xFA8A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xFD55, 0xFEBA, 0xFA8A, 0xFA8A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xFD55, 0xFEBA, 0xFA8A, 0xFA8A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xFD55, 0xFEBA, 0xFA8A, 0xFA8A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xFD55, 0xFEBA, 0xFA8A, 0xFA8A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xF800, 0xFBEF, 0xF800, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xF800, 0xFBEF, 0xF800, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xF800, 0xFBEF, 0xF800, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xF800, 0xFBEF, 0xF800, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xF800, 0xFBEF, 0xF800, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xF800, 0xFBEF, 0xF800, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xF800, 0xFBEF, 0xF800, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xF800, 0xFBEF, 0xF800, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xF800, 0xFBEF, 0xF800, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xFAAA, 0xF800, 0xF945, 0xFAAA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xFAAA, 0xF800, 0xF945, 0xFAAA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xFAAA, 0xF800, 0xF945, 0xFAAA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xFAAA, 0xF800, 0xF945, 0xFAAA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xFAAA, 0xF800, 0xF945, 0xFAAA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xFAAA, 0xF800, 0xF945, 0xFAAA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xFAAA, 0xF800, 0xF945, 0xFAAA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xFAAA, 0xF800, 0xF945, 0xFAAA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xFAAA, 0xF800, 0xF945, 0xFAAA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xFAAA, 0xF800, 0xF945, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xFAAA, 0xF800, 0xF945, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xFAAA, 0xF800, 0xF945, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xFAAA, 0xF800, 0xF945, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xFAAA, 0xF800, 0xF945, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xFAAA, 0xF800, 0xF945, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xFAAA, 0xF800, 0xF945, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xFAAA, 0xF800, 0xF945, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xFAAA, 0xF800, 0xF945, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xF800, 0xFFFF, 0xFFFF, 0xF800, 0xF800, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xF800, 0xFFFF, 0xFFFF, 0xF800, 0xF800, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xF800, 0xFFFF, 0xFFFF, 0xF800, 0xF800, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xF800, 0xFFFF, 0xFFFF, 0xF800, 0xF800, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xF800, 0xFFFF, 0xFFFF, 0xF800, 0xF800, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xF800, 0xFFFF, 0xFFFF, 0xF800, 0xF800, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xF800, 0xFFFF, 0xFFFF, 0xF800, 0xF800, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xF800, 0xFFFF, 0xFFFF, 0xF800, 0xF800, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xF800, 0xFFFF, 0xFFFF, 0xF800, 0xF800, 0xFFFF, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFEBA, 0xFD55, 0xFD55, 0xF800, 0xF945, 0xFAAA, 0xFD55, 0xF800, 0xFBEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFEBA, 0xFD55, 0xFD55, 0xF800, 0xF945, 0xFAAA, 0xFD55, 0xF800, 0xFBEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFEBA, 0xFD55, 0xFD55, 0xF800, 0xF945, 0xFAAA, 0xFD55, 0xF800, 0xFBEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFEBA, 0xFD55, 0xFD55, 0xF800, 0xF945, 0xFAAA, 0xFD55, 0xF800, 0xFBEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFEBA, 0xFD55, 0xFD55, 0xF800, 0xF945, 0xFAAA, 0xFD55, 0xF800, 0xFBEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFEBA, 0xFD55, 0xFD55, 0xF800, 0xF945, 0xFAAA, 0xFD55, 0xF800, 0xFBEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFEBA, 0xFD55, 0xFD55, 0xF800, 0xF945, 0xFAAA, 0xFD55, 0xF800, 0xFBEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFEBA, 0xFD55, 0xFD55, 0xF800, 0xF945, 0xFAAA, 0xFD55, 0xF800, 0xFBEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFEBA, 0xFD55, 0xFD55, 0xF800, 0xF945, 0xFAAA, 0xFD55, 0xF800, 0xFBEF, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF945, 0xF800, 0xFAAA, 0xF800, 0xF945, 0xFA8A, 0xFFFF, 0xF800, 0xFBEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF945, 0xF800, 0xFAAA, 0xF800, 0xF945, 0xFA8A, 0xFFFF, 0xF800, 0xFBEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF945, 0xF800, 0xFAAA, 0xF800, 0xF945, 0xFA8A, 0xFFFF, 0xF800, 0xFBEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF945, 0xF800, 0xFAAA, 0xF800, 0xF945, 0xFA8A, 0xFFFF, 0xF800, 0xFBEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF945, 0xF800, 0xFAAA, 0xF800, 0xF945, 0xFA8A, 0xFFFF, 0xF800, 0xFBEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF945, 0xF800, 0xFAAA, 0xF800, 0xF945, 0xFA8A, 0xFFFF, 0xF800, 0xFBEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF945, 0xF800, 0xFAAA, 0xF800, 0xF945, 0xFA8A, 0xFFFF, 0xF800, 0xFBEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF945, 0xF800, 0xFAAA, 0xF800, 0xF945, 0xFA8A, 0xFFFF, 0xF800, 0xFBEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF945, 0xF800, 0xFAAA, 0xF800, 0xF945, 0xFA8A, 0xFFFF, 0xF800, 0xFBEF, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFBEF, 0xF800, 0xF800, 0xFFFF, 0xFBEF, 0xF800, 0xFFFF, 0xF800, 0xFBEF, 0xF800, 0xFBEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFBEF, 0xF800, 0xF800, 0xFFFF, 0xFBEF, 0xF800, 0xFFFF, 0xF800, 0xFBEF, 0xF800, 0xFBEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFBEF, 0xF800, 0xF800, 0xFFFF, 0xFBEF, 0xF800, 0xFFFF, 0xF800, 0xFBEF, 0xF800, 0xFBEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFBEF, 0xF800, 0xF800, 0xFFFF, 0xFBEF, 0xF800, 0xFFFF, 0xF800, 0xFBEF, 0xF800, 0xFBEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFBEF, 0xF800, 0xF800, 0xFFFF, 0xFBEF, 0xF800, 0xFFFF, 0xF800, 0xFBEF, 0xF800, 0xFBEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFBEF, 0xF800, 0xF800, 0xFFFF, 0xFBEF, 0xF800, 0xFFFF, 0xF800, 0xFBEF, 0xF800, 0xFBEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFBEF, 0xF800, 0xF800, 0xFFFF, 0xFBEF, 0xF800, 0xFFFF, 0xF800, 0xFBEF, 0xF800, 0xFBEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFBEF, 0xF800, 0xF800, 0xFFFF, 0xFBEF, 0xF800, 0xFFFF, 0xF800, 0xFBEF, 0xF800, 0xFBEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFBEF, 0xF800, 0xF800, 0xFFFF, 0xFBEF, 0xF800, 0xFFFF, 0xF800, 0xFBEF, 0xF800, 0xFBEF, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xFAAA, 0xFD55, 0xF800, 0xFD55, 0xFFFF, 0xFEBA, 0xFD55, 0xF800, 0xFAAA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xFAAA, 0xFD55, 0xF800, 0xFD55, 0xFFFF, 0xFEBA, 0xFD55, 0xF800, 0xFAAA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xFAAA, 0xFD55, 0xF800, 0xFD55, 0xFFFF, 0xFEBA, 0xFD55, 0xF800, 0xFAAA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xFAAA, 0xFD55, 0xF800, 0xFD55, 0xFFFF, 0xFEBA, 0xFD55, 0xF800, 0xFAAA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xFAAA, 0xFD55, 0xF800, 0xFD55, 0xFFFF, 0xFEBA, 0xFD55, 0xF800, 0xFAAA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xFAAA, 0xFD55, 0xF800, 0xFD55, 0xFFFF, 0xFEBA, 0xFD55, 0xF800, 0xFAAA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xFAAA, 0xFD55, 0xF800, 0xFD55, 0xFFFF, 0xFEBA, 0xFD55, 0xF800, 0xFAAA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xFAAA, 0xFD55, 0xF800, 0xFD55, 0xFFFF, 0xFEBA, 0xFD55, 0xF800, 0xFAAA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xFAAA, 0xFD55, 0xF800, 0xFD55, 0xFFFF, 0xFEBA, 0xFD55, 0xF800, 0xFAAA, 0xFFFF, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xFFFF, 0xFFFF, 0xFEBA, 0xFD55, 0xFD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xFFFF, 0xFFFF, 0xFEBA, 0xFD55, 0xFD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xFFFF, 0xFFFF, 0xFEBA, 0xFD55, 0xFD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xFFFF, 0xFFFF, 0xFEBA, 0xFD55, 0xFD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xFFFF, 0xFFFF, 0xFEBA, 0xFD55, 0xFD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xFFFF, 0xFFFF, 0xFEBA, 0xFD55, 0xFD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xFFFF, 0xFFFF, 0xFEBA, 0xFD55, 0xFD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xFFFF, 0xFFFF, 0xFEBA, 0xFD55, 0xFD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xFFFF, 0xFFFF, 0xFEBA, 0xFD55, 0xFD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 
0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 
0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xEEBD, 0xD55A, 0xEEBD, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x9152, 0xD55A, 0x9152, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0x8010, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0x8010, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xBBF7, 0x8010, 0xBBF7, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xBBF7, 0x8010, 0xBBF7, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xBBF7, 0x8010, 0xBBF7, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xBBF7, 0x8010, 0xBBF7, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFBEF, 0xF800, 0xFBEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFBEF, 0xF800, 0xFBEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0xFFFF, 0x8010, 0xFFFF, 0x8010, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xBBF7, 0x8010, 0xBBF7, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0x8010, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xBBF7, 0x8010, 0xBBF7, 0xFFFF, 0xBBF7, 0x8010, 0xBBF7, 0xFFFF, 0xBBF7, 0x8010, 0xBBF7, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xEEBD, 0xAAB5, 0xBBF7, 0xAAB5, 0xBBF7, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xEEBD, 0xAAB5, 0xBBF7, 0xAAB5, 0xBBF7, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD55A, 0xAAB5, 0xD55A, 0xAAB5, 0xD55A, 0xFFFF, 0xFFFF, 0xFFFF, 0xD55A, 0xAAB5, 0xD55A, 0xAAB5, 0xD55A, 0xFFFF, 0xFFFF, 0xFFFF, 0xD55A, 0xAAB5, 0xD55A, 0xAAB5, 0xD55A, 0xFFFF, 0xFFFF, 0xFFFF, 0xD55A, 0xAAB5, 0xD55A, 0xAAB5, 0xD55A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xFAAA, 0xFD55, 0xFAAA, 0xFD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xFAAA, 0xFD55, 0xFAAA, 0xFD55, 0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0xBBF7, 0x8010, 0xBBF7, 0x8010, 0xEEBD, 0xD55A, 0xEEBD, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD55A, 0xAAB5, 0xD55A, 0xAAB5, 0xD55A, 0xFFFF, 0xFFFF, 0xEEBD, 0xAAB5, 0xBBF7, 0xAAB5, 0xBBF7, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD55A, 0xAAB5, 0xD55A, 0xAAB5, 0xD55A, 0xAAB5, 0xD55A, 0xAAB5, 0xD55A, 0xAAB5, 0xD55A, 0xAAB5, 0xD55A, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xBBF7, 0xFFFF, 0x9152, 0xAA95, 0xBBF7, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xBBF7, 0xFFFF, 0x9152, 0xAA95, 0xBBF7, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0xD55A, 0x8010, 0xD55A, 0x8010, 0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0xD55A, 0x8010, 0xD55A, 0x8010, 0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0xD55A, 0x8010, 0xD55A, 0x8010, 0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0xD55A, 0x8010, 0xD55A, 0x8010, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xFD55, 0xF800, 0xFD55, 0xF800, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xFD55, 0xF800, 0xFD55, 0xF800, 0xFFFF, 0xFFFF, 0xFFFF, 0xD55A, 0x9152, 0x8010, 0x9152, 0xD55A, 0x9152, 0xD55A, 0x9152, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0xD55A, 0x8010, 0xD55A, 0x8010, 0xFFFF, 0xFFFF, 0xBBF7, 0xFFFF, 0x9152, 0xAA95, 0xBBF7, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0xD55A, 0x8010, 0xD55A, 0x8010, 0xD55A, 0x8010, 0xD55A, 0x8010, 0xD55A, 0x8010, 0xD55A, 0x8010, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xBBF7, 0x8010, 0xBBF7, 0xFFFF, 0x8010, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xBBF7, 0x8010, 0xBBF7, 0xFFFF, 0x8010, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0xBBF7, 0x8010, 0xBBF7, 0x8010, 0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0xBBF7, 0x8010, 0xBBF7, 0x8010, 0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0xBBF7, 0x8010, 0xBBF7, 0x8010, 0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0xBBF7, 0x8010, 0xBBF7, 0x8010, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xFBEF, 0xF800, 0xFBEF, 0xF800, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xFBEF, 0xF800, 0xFBEF, 0xF800, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xBBF7, 0x8010, 0xBBF7, 0x8010, 0xFFFF, 0x8010, 0xFFFF, 0x8010, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0xBBF7, 0x8010, 0xBBF7, 0x8010, 0xFFFF, 0xFFFF, 0xBBF7, 0x8010, 0xBBF7, 0xFFFF, 0x8010, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0xBBF7, 0x8010, 0xBBF7, 0x8010, 0xBBF7, 0x8010, 0xBBF7, 0x8010, 0xBBF7, 0x8010, 0xBBF7, 0x8010, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xEEBD, 0xAAB5, 0xAAB5, 0xD55A, 0xAAB5, 0xAAB5, 0xEEBD, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAAB5, 0x8010, 0x8010, 0xD55A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAAB5, 0x8010, 0x8010, 0xD55A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x9152, 0x8010, 0x9152, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x9152, 0x8010, 0x9152, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x9152, 0x8010, 0x9152, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x9152, 0x8010, 0x9152, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF945, 0xF800, 0xF945, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF945, 0xF800, 0xF945, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0xBBF7, 0x8010, 0xBBF7, 0x8010, 0xEEBD, 0xD55A, 0xEEBD, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAAB5, 0x8010, 0xAAB5, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAAB5, 0x9152, 0xAAB5, 0xD55A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x9152, 0x8010, 0x9152, 0xFFFF, 0x9152, 0x8010, 0x9152, 0xFFFF, 0x9152, 0x8010, 0x9152, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xBBF7, 0xAA95, 0xD55A, 0x8010, 0xD55A, 0xAA95, 0xBBF7, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD55A, 0xD55A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD55A, 0xD55A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xEEBD, 0xD55A, 0xEEBD, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xEEBD, 0xD55A, 0xEEBD, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xEEBD, 0xD55A, 0xEEBD, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xEEBD, 0xD55A, 0xEEBD, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFEBA, 0xFD55, 0xFEBA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFEBA, 0xFD55, 0xFEBA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD55A, 0x9152, 0x8010, 0x9152, 0xD55A, 0x9152, 0xD55A, 0x9152, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD55A, 0x8010, 0xD55A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x9152, 0xAA95, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xEEBD, 0xD55A, 0xEEBD, 0xFFFF, 0xEEBD, 0xD55A, 0xEEBD, 0xFFFF, 0xEEBD, 0xD55A, 0xEEBD, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0xBBF7, 0x8010, 0x8010, 0x8010, 0x8010, 0x8010, 0xBBF7, 0x8010, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xBBF7, 0x8010, 0xBBF7, 0x8010, 0xFFFF, 0x8010, 0xFFFF, 0x8010, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0xFFFF, 0x8010, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0xBBF7, 0x8010, 0xBBF7, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xBBF7, 0xD55A, 0xBBF7, 0xD55A, 0xD3F5, 0xA80A, 0xD3F5, 0xD55A, 0xBBF7, 0xD55A, 0xBBF7, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xF945, 0xF800, 0xFEBA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFAAA, 0xFAAA, 0xFAAA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xEEBD, 0xD55A, 0xEEBD, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xEEBD, 0xD55A, 0xEEBD, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0xBBF7, 0x8010, 0xBBF7, 0x8010, 0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0xEEBD, 0x8010, 0xEEBD, 0x8010, 0xFFFF, 0xFFFF, 0xBBF7, 0xFFFF, 0xAAB5, 0xD55A, 0xBBF7, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFAAA, 0xFAAA, 0xFAAA, 0xFFFF, 0xFAAA, 0xFAAA, 0xFAAA, 0xFFFF, 0xFAAA, 0xFAAA, 0xFAAA, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xBBF7, 0xD55A, 0x9152, 0xD55A, 0xF945, 0xFD55, 0xF945, 0xD55A, 0x9152, 0xD55A, 0xBBF7, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xFD55, 0xFBEF, 0xFD55, 0xFBEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFA8A, 0xFD55, 0xFA8A, 0xFD55, 0xFA8A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x9152, 0xD55A, 0x9152, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x9152, 0xD55A, 0x9152, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD55A, 0x9152, 0x8010, 0x9152, 0xD55A, 0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0xBBF7, 0x8010, 0xBBF7, 0x8010, 0xFFFF, 0xFFFF, 0xBBF7, 0xAA95, 0xAAB5, 0xD55A, 0x9152, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFA8A, 0xFD55, 0xFA8A, 0xFD55, 0xFA8A, 0xFD55, 0xFA8A, 0xFD55, 0xFA8A, 0xFD55, 0xFA8A, 0xFD55, 0xFA8A, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0xFFFF, 0xBBF7, 0xF800, 0xFFFF, 0xF800, 0xFFFF, 0xF800, 0xBBF7, 0xFFFF, 0x8010, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFBEF, 0xFFFF, 0xF800, 0xF800, 0xFBEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xFBEF, 0xF800, 0xFBEF, 0xF800, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0xFFFF, 0x8010, 0xFFFF, 0x8010, 0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0xFFFF, 0x8010, 0xFFFF, 0x8010, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xBBF7, 0x8010, 0xBBF7, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0x8010, 0x8010, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0x8010, 0x8010, 0xBBF7, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xFBEF, 0xF800, 0xFBEF, 0xF800, 0xFBEF, 0xF800, 0xFBEF, 0xF800, 0xFBEF, 0xF800, 0xFBEF, 0xF800, 0xFFFF, 
0xFFFF, 0xFFFF, 0xAAB5, 0xAAB5, 0xAAB5, 0x9152, 0xF800, 0xFBEF, 0xF800, 0xFBEF, 0xF800, 0x9152, 0xAAB5, 0xAAB5, 0xAAB5, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xF800, 0xFAAA, 0xFD55, 0xF945, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFAAA, 0xFAAA, 0xF800, 0xFAAA, 0xFAAA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0xBBF7, 0x8010, 0xBBF7, 0x8010, 0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0xBBF7, 0x8010, 0xBBF7, 0x8010, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFEBA, 0xFD55, 0xFEBA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xFD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xEEBD, 0x8010, 0xEEBD, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAAB5, 0xD55A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFAAA, 0xFAAA, 0xF800, 0xFAAA, 0xFAAA, 0xFAAA, 0xF800, 0xFAAA, 0xFAAA, 0xFAAA, 0xF800, 0xFAAA, 0xFAAA, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xAAB5, 0xFFFF, 0x9152, 0xFD55, 0xF945, 0xF800, 0xF945, 0xFD55, 0x9152, 0xFFFF, 0xAAB5, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xF800, 0xF800, 0xFEBA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFAAA, 0xF800, 0xFAAA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD55A, 0x9152, 0x8010, 0x9152, 0xD55A, 0xFFFF, 0xFFFF, 0xFFFF, 0xD55A, 0x9152, 0x8010, 0x9152, 0xD55A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF945, 0xFD55, 0xF945, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFA8A, 0xFAAA, 0xF800, 0xFD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x9152, 0xD55A, 0x9152, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAA95, 0xAAB5, 0x8010, 0xD55A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFAAA, 0xF800, 0xFAAA, 0xFFFF, 0xFAAA, 0xF800, 0xFAAA, 0xFFFF, 0xFAAA, 0xF800, 0xFAAA, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xBBF7, 0x8010, 0xBBF7, 0x8010, 0xFBEF, 0xF800, 0xFBEF, 0x8010, 0xBBF7, 0x8010, 0xBBF7, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xBBF7, 0x8010, 0xBBF7, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xBBF7, 0x8010, 0xBBF7, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xFFFF, 0xF800, 0xFFFF, 0xF800, 0xFFFF, 0xFFFF, 0xFBEF, 0xFFFF, 0xFBEF, 0xFFFF, 0xFBEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0xFFFF, 0x8010, 0xFFFF, 0x8010, 0xFFFF, 0xFFFF, 0xBBF7, 0xFFFF, 0xBBF7, 0xFFFF, 0xBBF7, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xD55A, 0xD55A, 0xBBF7, 0xD55A, 0xAAB5, 0x8010, 0xAAB5, 0xD55A, 0xBBF7, 0xD55A, 0xD55A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD55A, 0xD55A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD55A, 0xD55A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xEEBD, 0xD55A, 0xEEBD, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xEEBD, 0xD55A, 0xEEBD, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xEEBD, 0xD55A, 0xEEBD, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xEEBD, 0xD55A, 0xEEBD, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xEEBD, 0xD55A, 0xEEBD, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xEEBD, 0xD55A, 0xEEBD, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xFBEF, 0xF800, 0xFBEF, 0xF800, 0xFFFF, 0xFFFF, 0xFBEF, 0xFD55, 0xF945, 0xFAAA, 0xFAAA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0xBBF7, 0x8010, 0xBBF7, 0x8010, 0xFFFF, 0xFFFF, 0xBBF7, 0xD55A, 0x9152, 0xAAB5, 0xAAB5, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xEEBD, 0xD55A, 0xEEBD, 0xFFFF, 0xEEBD, 0xD55A, 0xEEBD, 0xFFFF, 0xEEBD, 0xD55A, 0xEEBD, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD55A, 0xBBF7, 0x8010, 0xD55A, 0x8010, 0xD55A, 0x8010, 0xBBF7, 0xD55A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAA95, 0xAAB5, 0x8010, 0xD55A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAA95, 0xAAB5, 0x8010, 0xD55A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x9152, 0xD55A, 0x9152, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x9152, 0xD55A, 0x9152, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x9152, 0xD55A, 0x9152, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x9152, 0xD55A, 0x9152, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x9152, 0xD55A, 0x9152, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x9152, 0xD55A, 0x9152, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xF945, 0xF800, 0xF945, 0xFD55, 0xFFFF, 0xFFFF, 0xFEBA, 0xF800, 0xF945, 0xFA8A, 0xFAAA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD55A, 0x9152, 0x8010, 0x9152, 0xD55A, 0xFFFF, 0xFFFF, 0xEEBD, 0x8010, 0x9152, 0xAA95, 0xAAB5, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x9152, 0xD55A, 0x9152, 0xFFFF, 0x9152, 0xD55A, 0x9152, 0xFFFF, 0x9152, 0xD55A, 0x9152, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xBBF7, 0xFFFF, 0x8010, 0x8010, 0x8010, 0xFFFF, 0xBBF7, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xBBF7, 0xFFFF, 0xBBF7, 0xFFFF, 0xBBF7, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xBBF7, 0xFFFF, 0xBBF7, 0xFFFF, 0xBBF7, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0xFFFF, 0x8010, 0xFFFF, 0x8010, 0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0xFFFF, 0x8010, 0xFFFF, 0x8010, 0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0xFFFF, 0x8010, 0xFFFF, 0x8010, 0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0xFFFF, 0x8010, 0xFFFF, 0x8010, 0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0xFFFF, 0x8010, 0xFFFF, 0x8010, 0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0xFFFF, 0x8010, 0xFFFF, 0x8010, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFBEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xBBF7, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0xFFFF, 0x8010, 0xFFFF, 0x8010, 0xFFFF, 0x8010, 0xFFFF, 0x8010, 0xFFFF, 0x8010, 0xFFFF, 0x8010, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD55A, 0xFFFF, 0xD55A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xBBF7, 0xD55A, 0x9152, 0xAAB5, 0xAAB5, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xBBF7, 0xD55A, 0x9152, 0xAAB5, 0xAAB5, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0xBBF7, 0x8010, 0xBBF7, 0x8010, 0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0xBBF7, 0x8010, 0xBBF7, 0x8010, 0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0xBBF7, 0x8010, 0xBBF7, 0x8010, 0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0xBBF7, 0x8010, 0xBBF7, 0x8010, 0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0xBBF7, 0x8010, 0xBBF7, 0x8010, 0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0xBBF7, 0x8010, 0xBBF7, 0x8010, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFAAA, 0xFAAA, 0xFAAA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xF945, 0xF800, 0xFEBA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAAB5, 0xAAB5, 0xAAB5, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD55A, 0x9152, 0x8010, 0xEEBD, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0xBBF7, 0x8010, 0xBBF7, 0x8010, 0xBBF7, 0x8010, 0xBBF7, 0x8010, 0xBBF7, 0x8010, 0xBBF7, 0x8010, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xEEBD, 0x8010, 0x9152, 0xAA95, 0xAAB5, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xEEBD, 0x8010, 0x9152, 0xAA95, 0xAAB5, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD55A, 0x9152, 0x8010, 0x9152, 0xD55A, 0xFFFF, 0xFFFF, 0xFFFF, 0xD55A, 0x9152, 0x8010, 0x9152, 0xD55A, 0xFFFF, 0xFFFF, 0xFFFF, 0xD55A, 0x9152, 0x8010, 0x9152, 0xD55A, 0xFFFF, 0xFFFF, 0xFFFF, 0xD55A, 0x9152, 0x8010, 0x9152, 0xD55A, 0xFFFF, 0xFFFF, 0xFFFF, 0xD55A, 0x9152, 0x8010, 0x9152, 0xD55A, 0xFFFF, 0xFFFF, 0xFFFF, 0xD55A, 0x9152, 0x8010, 0x9152, 0xD55A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFA8A, 0xFD55, 0xFA8A, 0xFD55, 0xFA8A, 0xFFFF, 0xFFFF, 0xFD55, 0xFD55, 0xFBEF, 0xFD55, 0xFBEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAA95, 0xD55A, 0xAA95, 0xD55A, 0xAA95, 0xFFFF, 0xFFFF, 0xD55A, 0xD55A, 0xBBF7, 0xD55A, 0xBBF7, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD55A, 0x9152, 0x8010, 0x9152, 0xD55A, 0x9152, 0x8010, 0x9152, 0xD55A, 0x9152, 0x8010, 0x9152, 0xD55A, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0x8010, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0x8010, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xBBF7, 0x8010, 0xBBF7, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xBBF7, 0x8010, 0xBBF7, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xBBF7, 0x8010, 0xBBF7, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xBBF7, 0x8010, 0xBBF7, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xBBF7, 0x8010, 0xBBF7, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xBBF7, 0x8010, 0xBBF7, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xFBEF, 0xF800, 0xFBEF, 0xF800, 0xFFFF, 0xFFFF, 0xFBEF, 0xFFFF, 0xF800, 0xF800, 0xFBEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8010, 0xBBF7, 0x8010, 0xBBF7, 0x8010, 0xFFFF, 0xFFFF, 0xBBF7, 0xFFFF, 0x8010, 0x8010, 0xBBF7, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xBBF7, 0x8010, 0xBBF7, 0xFFFF, 0xBBF7, 0x8010, 0xBBF7, 0xFFFF, 0xBBF7, 0x8010, 0xBBF7, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFAAA, 0xFAAA, 0xF800, 0xFAAA, 0xFAAA, 0xFFFF, 0xFFFF, 0xFD55, 0xF800, 0xFAAA, 0xFD55, 0xF945, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAAB5, 0xAAB5, 0x8010, 0xAAB5, 0xAAB5, 0xFFFF, 0xFFFF, 0xD55A, 0x8010, 0xAAB5, 0xD55A, 0x9152, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFAAA, 0xF800, 0xFAAA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xF800, 0xF800, 0xFEBA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAAB5, 0x8010, 0xAAB5, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD55A, 0x8010, 0x8010, 0xEEBD, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 
0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 
0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFEBA, 0xFD55, 0xFEBA, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xFA8A, 0xFBEF, 0xFD55, 0xFBEF, 0xFA8A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x554A, 0x554A, 0x554A, 0xAEB5, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x554A, 0x554A, 0x554A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x554A, 0x554A, 0x554A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x554A, 0x554A, 0x554A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x554A, 0x554A, 0x554A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x554A, 0x554A, 0x554A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x554A, 0x554A, 0x554A, 0xFFFF, 0x554A, 0x554A, 0x554A, 0xFFFF, 0x554A, 0x554A, 0x554A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFA8A, 0xFA8A, 0xFA8A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x554A, 0x554A, 0x554A, 0xFFFF, 0xAEB5, 0x554A, 0xAEB5, 0xFFFF, 0x554A, 0x554A, 0x554A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x554A, 0x554A, 0x554A, 0xFFFF, 0xFA8A, 0xFA8A, 0xFA8A, 0xFFFF, 0x554A, 0x554A, 0x554A, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xFBEF, 0xFFFF, 0xF800, 0xF800, 0xF800, 0xF800, 0xFBEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xF800, 0xF800, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0x7DEF, 0x0400, 0x7DEF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xF800, 0xF800, 0xF800, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFBEF, 0xFD55, 0xFAAA, 0xF800, 0xF945, 0xF800, 0xFAAA, 0xF800, 0xF945, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFAAA, 0xFD55, 0xFAAA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xD75A, 0x554A, 0xD75A, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x554A, 0xAEB5, 0x554A, 0xFFFF, 0xFAAA, 0xFD55, 0xFAAA, 0xFFFF, 0x554A, 0xAEB5, 0x554A, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFBEF, 0xF800, 0xF800, 0xFD55, 0xFBEF, 0xFD55, 0xFAAA, 0xF800, 0xF945, 0xFA8A, 0xFD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xF800, 0xF800, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0x554A, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xF800, 0xF800, 0xF800, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xFBEF, 0xF800, 0xFBEF, 0xFFFF, 0xFBEF, 0xFFFF, 0xFBEF, 0xF800, 0xFBEF, 0xFFFF, 0xFBEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFBEF, 0xFFFF, 0xFBEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0x0400, 0xFFFF, 0x0400, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xFBEF, 0xFFFF, 0xFBEF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFAAA, 0xF800, 0xFBEF, 0xF800, 0xFBEF, 0xF800, 0xFBEF, 0xFAAA, 0xFAAA, 0xFAAA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x554A, 0x2CA5, 0x0400, 0xAEB5, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x2CA5, 0x554A, 0x2CA5, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x2CA5, 0x554A, 0x2CA5, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x2CA5, 0x554A, 0x2CA5, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x2CA5, 0x554A, 0x2CA5, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x2CA5, 0x554A, 0x2CA5, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x2CA5, 0x554A, 0x2CA5, 0xFFFF, 0x2CA5, 0x554A, 0x2CA5, 0xFFFF, 0x2CA5, 0x554A, 0x2CA5, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xF800, 0xF800, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x2CA5, 0x554A, 0x2CA5, 0xAEB5, 0x2CA5, 0xFFFF, 0x2CA5, 0xAEB5, 0x2CA5, 0x554A, 0x2CA5, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x554A, 0x0400, 0x0400, 0xFFFF, 0xF800, 0xF800, 0xF800, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xFBEF, 0xFD55, 0xFBEF, 0xF800, 0xFBEF, 0xFA8A, 0xFAAA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xFA8A, 0xFA8A, 0xFA8A, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xFD55, 0xFD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0xFFFF, 0x2CA5, 0xAEB5, 0x7DEF, 0xFFFF, 0x7DEF, 0xAEB5, 0x2CA5, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAEB5, 0xAEB5, 0xAEB5, 0xFFFF, 0xFD55, 0xFD55, 0xFD55, 0xFFFF, 0xAEB5, 0xAEB5, 0xAEB5, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFBEF, 0xFFFF, 0xFBEF, 0xF800, 0xFBEF, 0xF800, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xF800, 0xF800, 0xF800, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0x0000, 0x0000, 0x0000, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xF800, 0xF800, 0xF800, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAEB5, 0xFFFF, 0xFD55, 0xF800, 0xFBEF, 0xFAAA, 0xFAAA, 0xFFFF, 0x7DEF, 0xAEB5, 0xD75A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFBEF, 0xFFFF, 0xFBEF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x2CA5, 0x554A, 0x2CA5, 0xFFFF, 0x2945, 0x52AA, 0x2945, 0xFFFF, 0x2CA5, 0x554A, 0x2CA5, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x2CA5, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x2CA5, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x2CA5, 0x554A, 0x2CA5, 0xFFFF, 0xF945, 0xFAAA, 0xF945, 0xFFFF, 0x2CA5, 0x554A, 0x2CA5, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x554A, 0xAEB5, 0x554A, 0xFFFF, 0xF800, 0xFBEF, 0xFA8A, 0xAC0A, 0x554A, 0x2CA5, 0x0400, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAEB5, 0xAEB5, 0xAEB5, 0xD75A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAEB5, 0xAEB5, 0xAEB5, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAEB5, 0xAEB5, 0xAEB5, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAEB5, 0xAEB5, 0xAEB5, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAEB5, 0xAEB5, 0xAEB5, 0xFFFF, 0xFBEF, 0xFFFF, 0xFBEF, 0xFFFF, 0xAEB5, 0xAEB5, 0xAEB5, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAEB5, 0xAEB5, 0xAEB5, 0xFFFF, 0xAEB5, 0xAEB5, 0xAEB5, 0xFFFF, 0xAEB5, 0xAEB5, 0xAEB5, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x2CA5, 0x554A, 0x2CA5, 0xFFFF, 0x2945, 0x528A, 0x2945, 0xFFFF, 0x2CA5, 0x554A, 0x2CA5, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAEB5, 0xAEB5, 0xD75A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD75A, 0xAEB5, 0xAEB5, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x2CA5, 0x554A, 0x2CA5, 0xFFFF, 0xF945, 0xFA8A, 0xF945, 0xFFFF, 0x2CA5, 0x554A, 0x2CA5, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x7BEF, 0xFFFF, 0x7DEF, 0xF800, 0xFBEF, 0x0400, 0x0400, 0xFFFF, 0x0400, 0x0400, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xF800, 0xF800, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0x0000, 0x0000, 0x0000, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xF800, 0xF800, 0xF800, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFEBA, 0xFAAA, 0x554A, 0xFFFF, 0x7DEF, 0xFFFF, 0x52A2, 0x0400, 0x2CA5, 0x0400, 0x7DEF, 0x0400, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xF945, 0xFAAA, 0xF945, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x554A, 0xAEB5, 0x554A, 0xFFFF, 0x52AA, 0xAD55, 0x52AA, 0xFFFF, 0x554A, 0xAEB5, 0x554A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x554A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x554A, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x554A, 0xAEB5, 0x554A, 0xFFFF, 0xFAAA, 0xFD55, 0xFAAA, 0xFFFF, 0x554A, 0xAEB5, 0x554A, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFEBA, 0xFFFF, 0x554A, 0xFFFF, 0x7DEF, 0x554A, 0x0402, 0x0400, 0x2CA5, 0xAEB5, 0x7DEF, 0x0400, 0xD75A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAEB5, 0x554A, 0x0400, 0xD75A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x554A, 0xAEB5, 0x554A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x554A, 0xAEB5, 0x554A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x554A, 0xAEB5, 0x554A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x554A, 0xAEB5, 0x554A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x554A, 0xAEB5, 0x554A, 0xFFFF, 0xFBEF, 0xFFFF, 0xFBEF, 0xFFFF, 0x554A, 0xAEB5, 0x554A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x554A, 0xAEB5, 0x554A, 0xFFFF, 0x554A, 0xAEB5, 0x554A, 0xFFFF, 0x554A, 0xAEB5, 0x554A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0x0000, 0x0000, 0x0000, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x554A, 0xAEB5, 0x554A, 0x554A, 0xFFFF, 0xFFFF, 0xFFFF, 0x554A, 0x554A, 0xAEB5, 0x554A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xF800, 0xF800, 0xF800, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0x0400, 0x7DEF, 0x0400, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xFBEF, 0xFFFF, 0xFBEF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0xFFFF, 0x0400, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0x0400, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 
0xFFFF, 0xAEB7, 0xAEB5, 0xAEB5, 0xFFFF, 0x7DEF, 0xFFFF, 0x554A, 0x0400, 0x0400, 0x0400, 0x7DEF, 0xAEB5, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAEB5, 0x554A, 0x0400, 0xD75A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x554A, 0xAEB5, 0x554A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x554A, 0xAEB5, 0x554A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x554A, 0xAEB5, 0x554A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x554A, 0xAEB5, 0x554A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x554A, 0xAEB5, 0x554A, 0xFFFF, 0xF800, 0xF800, 0xF800, 0xFFFF, 0x554A, 0xAEB5, 0x554A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x554A, 0xAEB5, 0x554A, 0xFFFF, 0x554A, 0xAEB5, 0x554A, 0xFFFF, 0x554A, 0xAEB5, 0x554A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0x0000, 0x0000, 0x0000, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x554A, 0xAEB5, 0x554A, 0x554A, 0x554A, 0xFFFF, 0x554A, 0x554A, 0x554A, 0xAEB5, 0x554A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xF800, 0xF800, 0xF800, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 
0xFFFF, 0x554D, 0xAEB5, 0x0400, 0x554A, 0x2CA5, 0xFFFF, 0xFFFF, 0xAEB5, 0x5540, 0x0400, 0x2CA5, 0x0400, 0xD75A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFD55, 0xFD55, 0xFD55, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x554A, 0xAEB5, 0x554A, 0xFFFF, 0x52AA, 0xAD55, 0x52AA, 0xFFFF, 0x554A, 0xAEB5, 0x554A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0x0400, 0xFFFF, 0x0400, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x554A, 0xAEB5, 0x554A, 0xFFFF, 0xFAAA, 0xFD55, 0xFAAA, 0xFFFF, 0x554A, 0xAEB5, 0x554A, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0x0400, 0x7DEF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0x7DEF, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0x0000, 0x0000, 0x0000, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0x0400, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xF800, 0xF800, 0xF800, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0x0400, 0x0400, 0x0400, 0x7DEF, 0xFFFF, 0xD75A, 0x0400, 0x0400, 0x554A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x2CA5, 0x554A, 0x2CA5, 0xFFFF, 0x2945, 0x52AA, 0x2945, 0xFFFF, 0x2CA5, 0x554A, 0x2CA5, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xAEB5, 0xAEB5, 0xAEB5, 0xFFFF, 0x7DEF, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x2CA5, 0x554A, 0x2CA5, 0xFFFF, 0xF945, 0xFAAA, 0xF945, 0xFFFF, 0x2CA5, 0x554A, 0x2CA5, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xD75A, 0x0400, 0x0400, 0x0400, 0x2CA5, 0x554A, 0x7DEF, 0xAEB5, 0xABEA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x554A, 0x2CA5, 0x0400, 0xAEB5, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x2CA5, 0x554A, 0x2CA5, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x2CA5, 0x554A, 0x2CA5, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x2CA5, 0x554A, 0x2CA5, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x2CA5, 0x554A, 0x2CA5, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x2CA5, 0x554A, 0x2CA5, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x2CA5, 0x554A, 0x2CA5, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x2CA5, 0x554A, 0x2CA5, 0xFFFF, 0x2CA5, 0x554A, 0x2CA5, 0xFFFF, 0x2CA5, 0x554A, 0x2CA5, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x2CA5, 0x554A, 0x2CA5, 0xFFFF, 0x2945, 0x528A, 0x2945, 0xFFFF, 0x2CA5, 0x554A, 0x2CA5, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x2CA5, 0x554A, 0x2CA5, 0xFFFF, 0xAEB5, 0x0400, 0xAEB5, 0xFFFF, 0x2CA5, 0x554A, 0x2CA5, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x2CA5, 0x554A, 0x2CA5, 0xFFFF, 0xF945, 0xFA8A, 0xF945, 0xFFFF, 0x2CA5, 0x554A, 0x2CA5, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0xFFFF, 0xFFFF, 0xF800, 0xFFFF, 0xFFFF, 0xFBEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0x0000, 0x0000, 0x0000, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0x7DEF, 0x0400, 0x7DEF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xF800, 0xF800, 0xF800, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xFEBA, 0xFFFF, 0xFAAA, 0xFD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFA8A, 0xF800, 0xFBEF, 0xFA8A, 0xFAAA, 0xFD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 
0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 
0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xFA8A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xBDF7, 0x0000, 0xBDF7, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7BEF, 0x0000, 0x7BEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xF800, 0xFBEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFBEF, 0xF800, 0xFBEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFBEF, 0xF800, 0xFBEF, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0000, 0x7BEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD6BA, 0x0000, 0x10A2, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xEF5D, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAEB5, 0xD75A, 0xFFFF, 0x554A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF945, 0xF800, 0xF945, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0xFFFF, 0xFFFF, 0xFD55, 0xFAAA, 0xFD55, 0xFAAA, 0xFD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xFAAA, 0xFD55, 0xFAAA, 0xFD55, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0000, 0x2945, 0x528A, 0xAD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0000, 0x6B4D, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAD55, 0x528A, 0x528A, 0x39E7, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAEB5, 0x0400, 0x2CA5, 0xFFFF, 0x0405, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFEBA, 0xF800, 0xFBEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0xFFFF, 0xFFFF, 0xF800, 0xFD55, 0xF800, 0xFD55, 0xF800, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xFD55, 0xF800, 0xFD55, 0xF800, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0000, 0x0000, 0x0000, 0x7BEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xBDF7, 0x0000, 0xBDF7, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x4208, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0000, 0x8410, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0x0400, 0x0400, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFBEF, 0xF800, 0xFBEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0xFFFF, 0xFFFF, 0xF800, 0xFBEF, 0xF800, 0xFBEF, 0xF800, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xFBEF, 0xF800, 0xFBEF, 0xF800, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAD55, 0xAD55, 0x0000, 0x0000, 0x94B2, 0xD6BA, 0xEF5D, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7BEF, 0x0000, 0xAD55, 0x0000, 0xAD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAD55, 0xAD55, 0xAD55, 0x52AA, 0x10A2, 0x52AA, 0x8410, 0xFFFF, 0xAD55, 0x52AA, 0x52AA, 0xAD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAD55, 0x52AA, 0xD6BA, 0xFFFF, 0x7BEF, 0x0000, 0xBDF7, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD75A, 0xAEB5, 0xD75A, 0xAEB5, 0x7DEF, 0xAEB5, 0x7DF5, 0xFFFF, 0x554A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFEBA, 0xF800, 0xFFFF, 0xFFFF, 0xFEBA, 0xFD55, 0xFFFF, 0xFFFF, 0xFFFF, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0xFFFF, 0xFFFF, 0xFFFF, 0xF945, 0xF800, 0xF945, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF945, 0xF800, 0xF945, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0000, 0xAD55, 0xAD55, 0x0000, 0x39E7, 0x2945, 0x39E7, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x52AA, 0x0000, 0x0000, 0x52AA, 0xD6BA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x52AA, 0x0000, 0x2945, 0xAD55, 0xC618, 0xFFFF, 0xFFFF, 0xAD55, 0xAD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD6BA, 0x0000, 0x7BEF, 0xFFFF, 0x7BEF, 0x0000, 0xEF5D, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0x0400, 0xD75A, 0x0400, 0xD75A, 0xAEB5, 0x2CAA, 0xFFFF, 0x554A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFEBA, 0xF800, 0xFA8A, 0xFA8A, 0xF945, 0xF800, 0xFD55, 0xFFFF, 0xFFFF, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFEBA, 0xFD55, 0xFEBA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFEBA, 0xFD55, 0xFEBA, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xDEFB, 0x0000, 0x4208, 0xFFFF, 0x0000, 0x0000, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7BEF, 0x0000, 0x0000, 0x8410, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0000, 0x7BEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0000, 0x7BEF, 0xFFFF, 0x7BEF, 0x0000, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0x7DEF, 0x0400, 0x7DEF, 0x0400, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFBEF, 0xF800, 0xF800, 0xFFFF, 0xFFFF, 0xF800, 0xF800, 0xFFFF, 0xFFFF, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD6BA, 0xD6BA, 0x52AA, 0x52AA, 0x0000, 0xBDF7, 0xD6BA, 0x2945, 0x0000, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x2945, 0xFFFF, 0xD6BA, 0x52AA, 0xD6BA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD6BA, 0x52AA, 0x0000, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xEF5D, 0xFFFF, 0xFFFF, 0x0000, 0x7BEF, 0xFFFF, 0x7BEF, 0x2945, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAEB5, 0x2CA5, 0xFFFF, 0xFFFF, 0x0400, 0x7DEF, 0x554A, 0x554A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFAAA, 0xFD55, 0xFD55, 0xF800, 0xF800, 0xF800, 0xFFFF, 0xFFFF, 0xFBEF, 0xF800, 0xF945, 0xFFFF, 0xFFFF, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFAAA, 0xFAAA, 0xFAAA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8410, 0x7BEF, 0xAD55, 0x528A, 0x0000, 0x10A2, 0x2945, 0x0000, 0xAD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7BEF, 0xFFFF, 0x7BEF, 0x0000, 0x7BEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD6BA, 0xFFFF, 0xAD55, 0xFFFF, 0x0000, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x39E7, 0x528A, 0xFFFF, 0x0000, 0x7BEF, 0xFFFF, 0x7BEF, 0xD6BA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0xD75A, 0x554A, 0xFFFF, 0x0400, 0xD75A, 0xFFFF, 0x554A, 0x554A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xF800, 0xFD55, 0xFD55, 0xFD55, 0xF800, 0xFFFF, 0xFFFF, 0xF945, 0xF800, 0xFEBA, 0xFFFF, 0xFFFF, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFA8A, 0xFD55, 0xFA8A, 0xFD55, 0xFA8A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0000, 0xFFFF, 0xFFFF, 0x0000, 0xBDF7, 0xFFFF, 0x0000, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7BEF, 0x0000, 0xBDF7, 0xFFFF, 0x7BEF, 0x0000, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8410, 0x7BEF, 0xFFFF, 0x7BEF, 0xFFFF, 0x0000, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7BEF, 0x0000, 0xBDF7, 0x0000, 0x7BEF, 0xFFFF, 0x7BEF, 0xFFFF, 0xFFFF, 0x0000, 0x7BEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0x0400, 0x7DEF, 0x0400, 0x7DEF, 0x0400, 0x7DEF, 0x0400, 0xFFFF, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFBEF, 0xF800, 0xFBEF, 0xFFFF, 0xFBEF, 0xF800, 0xFFFF, 0xF800, 0xF800, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xFBEF, 0xF800, 0xFBEF, 0xF800, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x2104, 0x52AA, 0xD6BA, 0x0000, 0x7BEF, 0x0000, 0x52AA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x10A2, 0x0000, 0x6B4D, 0xAD55, 0x0000, 0x0000, 0xAD55, 0xD6BA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0000, 0xAD55, 0x52AA, 0x52AA, 0x10A2, 0x52AA, 0x4208, 0xD6BA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAD55, 0x0000, 0x7BEF, 0x0000, 0x7BEF, 0xFFFF, 0x52AA, 0xAD55, 0x52AA, 0x52AA, 0xAD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAEB5, 0x554A, 0xFFFF, 0x554A, 0x0400, 0xD75A, 0x554A, 0x2CA5, 0xAEB5, 0xAEB5, 0xAEB5, 0x554A, 0x554A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xF800, 0xFAAA, 0xFD55, 0xFD55, 0xF800, 0xF800, 0xF800, 0xFBEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFAAA, 0xFAAA, 0xF800, 0xFAAA, 0xFAAA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xA50E, 0x0000, 0x2945, 0x0000, 0x0000, 0xAD55, 0xD6BA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x10A2, 0x0000, 0x10A2, 0x0000, 0x52AA, 0xAD55, 0x8410, 0x2945, 0xAD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x528A, 0xFFFF, 0x528A, 0x0000, 0x0000, 0x8410, 0x0000, 0x6B4D, 0xFFFF, 0x6B4D, 0x2945, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAD55, 0xD6BA, 0x0000, 0x52AA, 0x528A, 0x2945, 0x0000, 0xAD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAEB5, 0xAEB5, 0x554A, 0x0400, 0xAEB5, 0xD75A, 0xFFFF, 0x2CA5, 0x0400, 0x0400, 0xAEB5, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xF800, 0xF800, 0xFAAA, 0xF800, 0xFD55, 0xFD55, 0xFEBA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFAAA, 0xF800, 0xFAAA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xC618, 0x0000, 0x0000, 0x7BEF, 0x0000, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0000, 0x0000, 0x0000, 0x8410, 0x7BEF, 0x0000, 0x0000, 0xFFFF, 0xFFFF, 0x8410, 0x0000, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0000, 0x0000, 0x0000, 0x4208, 0x0000, 0xFFFF, 0x0000, 0xBDF7, 0xFFFF, 0x7BEF, 0x0000, 0x7BEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0000, 0x0000, 0xFFFF, 0x7BEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x0400, 0x0400, 0xFFFF, 0x7DEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD6BA, 0x0000, 0xAD55, 0x0000, 0xFFFF, 0x2945, 0x2945, 0xAD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x10A2, 0xFFFF, 0xFFFF, 0x52AA, 0x0000, 0x0000, 0xBDF7, 0xD6BA, 0xFFFF, 0x52AA, 0x10A2, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0000, 0x6B4D, 0xFFFF, 0xAD55, 0x0000, 0xEF5D, 0x0000, 0xFFFF, 0xFFFF, 0x6B4D, 0x0000, 0xAD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD6BA, 0x7BEF, 0x0000, 0xAD55, 0xFFFF, 0x94B2, 0x0000, 0xAD55, 0xAD55, 0xAD55, 0xD6BA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAEB5, 0x0400, 0xAEB5, 0xFFFF, 0x2CA5, 0xFFFF, 0x2CA5, 0xFFFF, 0x7DEF, 0xAEB5, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xF800, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFEBA, 0xFD55, 0xFEBA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFEBA, 0xFD55, 0xFEBA, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x52AA, 0x52AA, 0xFFFF, 0x0000, 0xFFFF, 0xD6BA, 0x0000, 0x0000, 0x528A, 0xAD55, 0xD6BA, 0xFFFF, 0xFFFF, 0xFFFF, 0x6B4D, 0x528A, 0xD6BA, 0x528A, 0x0000, 0x0000, 0x10A2, 0x2945, 0xAD55, 0x0000, 0x52AA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0000, 0x10A2, 0xFFFF, 0xFFFF, 0xAD55, 0x94B2, 0xAD55, 0xFFFF, 0xFFFF, 0x10A2, 0x0000, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x528A, 0x528A, 0x2945, 0x2945, 0xAD55, 0xFFFF, 0xFFFF, 0xEF5D, 0x52AA, 0x0000, 0x0000, 0x0000, 0x2945, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0xAEB5, 0xFFFF, 0x554A, 0x7DEF, 0x554A, 0x7DEF, 0xFFFF, 0xD75A, 0x0400, 0xAEBA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xF800, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0xFFFF, 0xFFFF, 0xFFFF, 0xF945, 0xFD55, 0xF945, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF945, 0xFD55, 0xF945, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0000, 0x4208, 0xFFFF, 0xFFFF, 0x0000, 0xFFFF, 0xFFFF, 0x7BEF, 0x0000, 0x0000, 0x0000, 0x7BEF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7BEF, 0x0000, 0x7BEF, 0x8410, 0x7BEF, 0x8410, 0xFFFF, 0xFFFF, 0xBDF7, 0x0000, 0x7BEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0000, 0x8410, 0xFFFF, 0xFFFF, 0x7BEF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0000, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xBDF7, 0x0000, 0x0000, 0x0000, 0xBDF7, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xBDF7, 0x8410, 0x0000, 0x8410, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7DEF, 0x0400, 0xFFFF, 0x0400, 0xFFFF, 0xFFFF, 0x7DEF, 0x0400, 0x0400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0xFFFF, 0xFFFF, 0xF800, 0xFFFF, 0xF800, 0xFFFF, 0xF800, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xFFFF, 0xF800, 0xFFFF, 0xF800, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0x52AA, 0x52AA, 0xD6BA, 0xFFFF, 0xBDF7, 0x0000, 0xAD55, 0xFFFF, 0xFFFF, 0xAD55, 0x8410, 0xAD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x9CF3, 0x0000, 0xAD55, 0xFFFF, 0x7BEF, 0xFFFF, 0xFFFF, 0xFFFF, 0x6B4D, 0x0000, 0xD6BA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x2945, 0x0000, 0xAD55, 0xAD55, 0x0000, 0x0000, 0x0000, 0x0000, 0x2945, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD6BA, 0x52AA, 0x52AA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0400, 0x554A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAEB5, 0x554A, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xF800, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0xFFFF, 0xFFFF, 0xF800, 0xFBEF, 0xF800, 0xFBEF, 0xF800, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xFBEF, 0xF800, 0xFBEF, 0xF800, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xAD55, 0xFFFF, 0xFFFF, 0xFFFF, 0x4208, 0x0000, 0x7BEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF7BE, 0x52AA, 0xAD55, 0xFFFF, 0xD6BA, 0xFFFF, 0x94B2, 0x528A, 0x10A2, 0x52AA, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD6BA, 0x0000, 0x8410, 0xAD55, 0xAD55, 0xAD55, 0x52AA, 0x0000, 0x7BF5, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xAEB5, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0xFFFF, 0xFFFF, 0xFD55, 0xF945, 0xF800, 0xF945, 0xFD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xF945, 0xF800, 0xF945, 0xFD55, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7BEF, 0x0000, 0x7BEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7BEF, 0x0000, 0x0000, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFBEF, 0xF800, 0xFBEF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFBEF, 0xF800, 0xFBEF, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x7BEF, 0x0000, 0x9CF9, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xF800, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 
0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xD6BA, 0xAD55, 0xF7BE, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFD55, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 
0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001, 0x0001, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x8400, 0x0001, 0x0001, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0x0001
};

uint16_t *pai_bmp;

uint16_t title_str16[]={0x3664,0x324f,0x2179,0x4b63,0x3f7d,0x0000};

uint16_t gamestart_str16[]={0x2532,0x213c,0x2560,0x2539,0x253f,0x213c,0x2548,0x0000};

uint16_t settei_str16[]={0x405f,0x446a,0x0000};

uint16_t calc_str16[]={0x4540,0x3f74,0x3757,0x3b3b,0x0000};

uint16_t seki_str16[]={0x404a,0x3768,0x2461,0x0000};

uint16_t erabu_str16[]={0x255c,0x253f,0x2573,0x2127,0x2428,0x2469,0x2456,0x0000};
uint16_t modoru_str16[]={0x255c,0x253f,0x2573,0x2127,0x2462,0x2449,0x246b,0x0000};
uint16_t tugi_str16[]={0x255c,0x253f,0x2573,0x2127,0x2444,0x242e,0x244b,0x2439,0x2439,0x2460,0x0000};

uint16_t aite_str16[]={0x416a,0x3c6a,0x244e,0x362f,0x2435,0x0000};
uint16_t tuyoi_str16[]={0x362f,0x2424,0x0000};
uint16_t futu_str16[]={0x2455,0x2444,0x2426,0x0000};
uint16_t yowai_str16[]={0x3c65,0x2424,0x0000};

uint16_t ten_str16[]={0x4540,0x0000};
uint16_t han_str16[]={0x664c,0x0000};
uint16_t point_str16[]={0x255d,0x2524,0x2573,0x2548,0x0000};

uint16_t anata_str16[]={0x2422,0x244a,0x243f,0x0000};
uint16_t simo_str16[]={0x2537,0x2562,0x2541,0x2563,0x0000};
uint16_t toi_str16[]={0x2548,0x2524,0x2561,0x2573,0x0000};
uint16_t kami_str16[]={0x252b,0x255f,0x2541,0x2563,0x0000};

uint16_t tumo_str16[]={0x2544,0x2562,0x0000};
uint16_t ron_str16[]={0x256d,0x2573,0x0000};
uint16_t ryukyoku_str16[]={0x4e2e,0x3649,0x0000};
uint16_t tenpai_str16[]={0x2546,0x2573,0x2551,0x2524,0x0000};
uint16_t noten_str16[]={0x254e,0x213c,0x2546,0x2573,0x0000};
uint16_t ryanhan_str16[]={0x2332,0x664c,0x477b,0x246a,0x0000};
uint16_t sentaku_str16[]={0x243b,0x2473,0x243f,0x242f,0x0000};

uint16_t richi_str16[]={0x256a,0x213c,0x2541,0x0000};
uint16_t richi1_str16[]={0x256a,0x213c,0x2541,0x306c,0x482f,0x0000};
uint16_t dblrichi_str16[]={0x2540,0x2556,0x256b,0x256a,0x213c,0x2541,0x0000};
uint16_t dblrichi0_str16[]={0x2540,0x2556,0x256b,0x0000};
uint16_t dblrichi1_str16[]={0x2540,0x2556,0x256b,0x306c,0x482f,0x0000};
uint16_t ippatu_str16[]={0x306c,0x482f,0x0000};
uint16_t haitei_str16[]={0x254f,0x2524,0x2546,0x2524,0x0000};
uint16_t haiteiron_str16[]={0x324f,0x446c,0x256d,0x2573,0x0000};
uint16_t haiteitumo_str16[]={0x3324,0x446c,0x2544,0x2562,0x0000};
uint16_t haiteitumok_str16[]={0x3324,0x446c,0x4036,0x3c2b,0x4c4e,0x4f42,0x0000};
uint16_t haku_str16[]={0x4772,0x0000};
uint16_t hatu_str16[]={0x482f,0x0000};
uint16_t chun_str16[]={0x4366,0x0000};
uint16_t tonton_str16[]={0x456c,0x456c,0x0000};
uint16_t nannan_str16[]={0x466e,0x466e,0x0000};
uint16_t shasha_str16[]={0x403e,0x403e,0x0000};
uint16_t pepe_str16[]={0x4b4c,0x4b4c,0x0000};
uint16_t ton_str16[]={0x456c,0x0000};
uint16_t nan_str16[]={0x466e,0x0000};
uint16_t sha_str16[]={0x403e,0x0000};
uint16_t pe_str16[]={0x4b4c,0x0000};
uint16_t tanyao_str16[]={0x4347,0x2878,0x3665,0x0000};
uint16_t chitoitu_str16[]={0x3c37,0x4250,0x3b52,0x0000};
uint16_t toitoi_str16[]={0x4250,0x2139,0x4f42,0x0000};
uint16_t menzentumo_str16[]={0x4c67,0x4130,0x4036,0x3c2b,0x4c4e,0x4f42,0x0000};
uint16_t chinitu_str16[]={0x4036,0x306c,0x3f27,0x0000};
uint16_t honitu_str16[]={0x3a2e,0x306c,0x3f27,0x0000};
uint16_t sanshokudoujyun_str16[]={0x3b30,0x3f27,0x4631,0x3d67,0x0000};
uint16_t sanshokudoukou_str16[]={0x3b30,0x3f27,0x4631,0x396f,0x0000};
uint16_t ittu_str16[]={0x306c,0x3524,0x444c,0x3453,0x0000};
uint16_t ipeko_str16[]={0x306c,0x4756,0x387d,0x0000};
uint16_t ryanpeko_str16[]={0x4673,0x4756,0x387d,0x0000};
uint16_t pinfu_str16[]={0x4a3f,0x4f42,0x0000};
uint16_t sankantu_str16[]={0x3b30,0x5c4a,0x3b52,0x0000};
uint16_t sukantu_str16[]={0x3b4d,0x5c4a,0x3b52,0x0000};
uint16_t sananko_str16[]={0x3b30,0x3045,0x396f,0x0000};
uint16_t suanko_str16[]={0x3b4d,0x3045,0x396f,0x0000};
uint16_t junchan_str16[]={0x3d63,0x4134,0x4253,0x2878,0x3665,0x0000};
uint16_t chanta_str16[]={0x3a2e,0x4134,0x4253,0x2878,0x3665,0x0000};
uint16_t kokusi_str16[]={0x3971,0x3b4e,0x4c35,0x4150,0x0000};
uint16_t tenho_str16[]={0x4537,0x4f42,0x0000};
uint16_t chiho_str16[]={0x434f,0x4f42,0x0000};
uint16_t renho_str16[]={0x3f4d,0x4f42,0x0000};
uint16_t dai3gen_str16[]={0x4267,0x3b30,0x3835,0x0000};
uint16_t sho3gen_str16[]={0x3e2e,0x3b30,0x3835,0x0000};
uint16_t daisusi_str16[]={0x4267,0x3b4d,0x346e,0x0000};
uint16_t shosusi_str16[]={0x3e2e,0x3b4d,0x346e,0x0000};
uint16_t tuiso_str16[]={0x3b7a,0x306c,0x3f27,0x0000};
uint16_t ryuiso_str16[]={0x4e50,0x306c,0x3f27,0x0000};
uint16_t chinroto_str16[]={0x4036,0x4f37,0x462c,0x0000};
uint16_t honroto_str16[]={0x3a2e,0x4f37,0x462c,0x0000};
uint16_t sisanputo_str16[]={0x3d3d,0x3b30,0x4954,0x4563,0x0000};
uint16_t rinshan_str16[]={0x4e66,0x3e65,0x332b,0x3256,0x0000};
uint16_t nagasi_str16[]={0x244a,0x242c,0x2437,0x4b7e,0x3453,0x0000};
uint16_t churenpoto_str16[]={0x3665,0x256c,0x2573,0x255d,0x2526,0x2548,2526,0x0000};
uint16_t daisharin_str16[]={0x2540,0x2524,0x2537,0x2563,0x256a,0x2573,0x0000};

uint16_t dora_str16[]={0x2549,0x2569,0x0000};
uint16_t chonbo_str16[]={0x2441,0x2467,0x2473,0x245c,0x0000};
uint16_t furiten_str16[]={0x2455,0x246a,0x2446,0x2473,0x0000};

struct h_pai pai[4][19];
struct h_pai sute[4][24];
struct h_pai machi[19];
struct h_yaku tensu[8][10];
int  points[4];
int  pnt_add[4];
struct h_pai latest_sute;
struct h_pai latest_tumo;
struct h_pai *latest_pointer;
struct h_pai dora[19];
struct h_pai dora_draw[8];
struct h_pai no_pai;
int kan_count;
int richi[4];
int richi_no[4];
int richi_cnt[4];
struct h_sikou ply_think[4];
int think_level[9]={0x11131, 0x10101, 0x10121, 0x00121, 0x10001, 0x12220, 0x11120, 0x10020, 0x10000};
int sel_mem;
int now_richi;
int open_mode;
int gm_mode[10]={
  0,//  gm_mode[0]:オープンモード
  1,//  gm_mode[1]:食いタン有り
  0,//  gm_mode[2]:十三不塔有り
  1,//  gm_mode[3]:裏ドラ有り
  1,//  gm_mode[4]:カン裏有り
  1,//  gm_mode[5]:２飜しばり有り
  1,//  gm_mode[6]:テンパイ連荘
  1,//  gm_mode[7]:南場ノーテン連荘
  0,
  0};;

int can_dblrichi;
int can_13puto;
int haitei;
int rinshankaiho;
int tenpai[4];
struct h_member agari_yaku;

int yama[136];
int yama_count;
int px, py, px_max;
int game_mode;

int kyoku;
int oya_position;
int ban;
int nakazu;
int agari;
int hon_ba;
int richi_bo_old;
int richi_bo_old2;
int richi_bo_now;
int richi_stop;
static int dlv_count=-1;
int chi_no[3];
int kan_no;
int top_no,top_mem[4];
int smenu[9];
int smenu_num;
int smenu_no;

int ycount;
int ytcount;
struct h_pai yaku[32][19];
struct h_yaku yakutxt[32][10];
struct h_pai yakutumo[32][19];
int keisan_mode[5];
int nagasi_agari;
int yaku_max;
int point_max,ten_max,han_max;
struct h_pai calc_pai[19];
struct h_pai tensu_pai[38];
int tensu_richi;
int tensu_tumo;
int tensu_ba;
int tensu_kaze;
int tensu_rinshan;
int point_oya[3];
int point_ko[3];

void setup()
{
  int x, y;
  int i, j;

  Serial.begin(115200);

  tft.begin(40000000);
  tft.setRotation(0);
  tft.clearDisplay();
  _width=tft.width();
  _height=tft.height();
  tft.drawPixel(2, 2, 0xFFFF);
  tft.display();
    
  ts.begin();
  ts.setRotation(0);

  pinMode(ButtonAPin, INPUT_PULLUP);
  pinMode(ButtonBPin, INPUT_PULLUP);

  // Make pai_bmp
  pai_bmp=(uint16_t *)malloc(144*96*sizeof(uint16_t));
  for(y=0;y<4;y++){
    for(x=0;x<9;x++){
      for(j=0;j<24;j++){
        for(i=0;i<16;i++){
          pai_bmp[(y*9+x)*16*24+j*16+i]=pai_mem[(y*24+j)*144+(x*16+i)];
        }
      }
    }
  }
  game_mode = 0;
  open_mode = 0;
  for(i=0;i<38;i++)
    tensu_pai[i].type=-1;
  tensu_richi=0;
  tensu_tumo=0;
  tensu_ba=0;
  tensu_kaze=0;
  tensu_rinshan=0;
}

int key_u, key_d, key_l, key_r, key_a, key_b;

void loop(){
  int i;
  int n;
  int move_step;
  char str[32];

  // Key detect
  StickX = analogRead(StickXPin)/4;
  StickY = analogRead(StickYPin)/4;
  ButtonA = digitalRead(ButtonAPin);
  ButtonB = digitalRead(ButtonBPin);

  if (StickX<256){
    key_l++;
    if (key_l>3)
      key_l=1;
    key_r=0;
  }else if (StickX>768){
    key_l=0;
    key_r++;
    if (key_r>3)
      key_r=1;
  }else{
    key_l=0;
    key_r=0;
  }

  if (StickY>768){
    key_u++;
    if (key_u>3)
      key_u=1;
    key_d=0;
  }else if (StickY<256){
    key_u=0;
    key_d++;
    if (key_d>3)
      key_d=1;
  }else{
    key_u=0;
    key_d=0;
  }

  if (ButtonA==0){
    key_a++;
    if (key_a>255)
      key_a=255;
  }else{
    key_a=0;
  }

  if (ButtonB==0){
    key_b++;
    if (key_b>255)
      key_b=255;
  }else{
    key_b=0;
  }

  // Title
  if (game_mode==0){
    show_title();
    if (key_u==1)
      py--;
    else if (key_d==1)
      py++;
    if (py<0)
      py=2;
    else if (py>2)
      py=0;
    if (key_a==1 || key_b==1){
      // Game start
      if (py==0){
        px=0;
        for(i=0;i<9;i++)
          smenu[i]=0;
        smenu_num=0;
        game_mode=1;
        tone(SoundPin, NOTE_G5, 50);
        delay(50);
        tone(SoundPin, NOTE_A6, 50);
        delay(50);
        tone(SoundPin, NOTE_G5, 50);
        delay(50);
        tone(SoundPin, NOTE_A6, 50);
      // Configuration
      }else if (py==1){
        game_mode=30;
      // Tensu calculation
      }else{
        game_mode=40;
      }
    }
  // Computer strength select
  }else if (game_mode==1){
    if (key_l==1)
      px--;
    else if (key_r==1)
      px++;
    if (px<0)
      px=2;
    if (px>2)
      px=0;
    if (key_a==1 || key_b==1){
      n=random(0, 3);
      ply_think[0].think=think_level[px*3+n];
      n=(n+1) % 3;
      ply_think[1].think=think_level[px*3+n];
      n=(n+1) % 3;
      ply_think[2].think=think_level[px*3+n];
      px=0;
      game_mode=2;
      tone(SoundPin, NOTE_C5, 50);
    }
    show_aite(px);
  // Oya select
  }else if (game_mode==2){
    if (key_l==1)
      px--;
    else if (key_r==1)
      px++;
    if (px<0)
      px=3;
    if (px>3)
      px=0;
    if (key_a==1 || key_b==1){
      game_mode=3;
      tone(SoundPin, NOTE_C5, 50);
    }
    show_seki(px);
  // Oya fix
  }else if (game_mode==3){
    if (key_a==1 || key_b==1){
      kyoku=0;
      hon_ba=0;
      richi_bo_now=0;
      richi_bo_old=0;
      richi_bo_old2=0;
      richi_stop=0;
      for(i=0;i<4;i++)
        points[i]=27000;
      game_mode=10;
      tone(SoundPin, NOTE_C5, 50);
    }
    oya_position=(3-show_seki(px+4)) % 4;
  // Game start
  }else if (game_mode==10){    
    dlv_count=-1;
    kan_count=-1;
    agari=-1;
    px=13;
    py=0;
    ban=0;
    now_richi=0;
    can_dblrichi=1;
    richi_bo_old2=richi_bo_old;
    chi_no[0]=-1;
    kan_no=-1;
    rinshankaiho=0;
    haitei=0;
    ban=oya_position*6;
    latest_sute.type=-1;
    latest_sute.group=-1;
    latest_sute.who=-1;
    no_pai.type=-1;
    no_pai.naki=0;
    no_pai.group=0;
    for(i=0;i<4;i++){
      pnt_add[i]=0;
      richi[i]=0;
      richi_no[i]=-1;
      richi_cnt[i]=0;
    }
    open_mode=gm_mode[0];
    can_13puto=gm_mode[2];
    if (deliver(oya_position)<0){
      shuffle();
      init_deliver();
    }
    for(;;){
      if(deliver(oya_position)==1){
        kan_count=0;
        sort_pai(pai[0]);
        sort_pai(pai[1]);
        sort_pai(pai[2]);
        sort_pai(pai[3]);
        game_mode=11;
        break;
      }
      show_table(0);
    }
  // Game
  }else if (game_mode==11){
    // Get pai
    if (ban % 6==0){
      richi_stop=0;
      get_1pai(ban/6);
      ban++;
    }else if (ban % 6==1){
      for(i=0;i<9;i++)
        smenu[i]=0;
      smenu[1]=1;
      smenu_num=1;
      if (can_richi(3)==1){
        smenu[2]=1;
        smenu_num++;
      }
      if (can_kan(3, no_pai)==1){
        smenu[5]=1;
        smenu_num++;
      }
      if (can_tumo(3)==1){
        smenu[7]=1;
        smenu_num++;
      }
      py=0;
      set_px(3);
      ban++;
    // Thinking
    }else if (ban % 6==2){
      // Computer
      if (ban<18){
        n=thinking(ban/6,pai[ban/6],sute[ban/6],&latest_sute);
        if (n==10){
          agari=ban/6;
          can_agari(agari, latest_tumo, 0);
          richi_bo_old2=richi_bo_old;
          set_point(agari, -1, 0);
          game_mode=12;
          tone(SoundPin, NOTE_C5, 50);
          delay(50);
          tone(SoundPin, NOTE_E5, 50);
          delay(50);
          tone(SoundPin, NOTE_G5, 50);
          delay(50);
          tone(SoundPin, NOTE_A6, 50);
          delay(50);
          tone(SoundPin, NOTE_C6, 50);
        }else{
          tone(SoundPin, NOTE_C3, 50);          
        }
        ban++;
      }else{
        if (debug==1 || richi[3]==0 || richi_stop==1){
          if (key_l==1)
            px--;
          else if (key_r==1)
            px++;
          if (px<0)
            px=px_max-1;
          if (px>=px_max)
            px=0;
        }
        if (key_u==1)
          py--;
        else if (key_d==1)
          py++;
        if (smenu_num==0)
          py=0;
        else if (py<0)
          py=smenu_num-1;
        else if (py>=smenu_num)
          py=0;
        // if (key_a==1 || key_b==1){
        if (key_a==1){
          if (smenu_no<=1){
            do_sute(3, pai_sel(3, px));
            if (richi[3]>0 && chk_tenpai(pai[3])==0){
              richi[3]=0;
              richi_no[3]=-1;
              richi_bo_now--;
              points[3]+=1000;
              richi_cnt[3]=0;
            }
            ban++;
            smenu_num=0;
            tone(SoundPin, NOTE_C3, 50);
          }
          if (smenu_no==2){
            richi[3]=can_dblrichi*2+1;
            for(i=0;sute[3][i].type>=0;i++);
            richi_no[3]=i;
            richi_bo_now++;
            points[3]-=1000;
            richi_cnt[3]=5;
            smenu[2]=0;
            smenu_num--;
            py=0;
            richi_stop=1;
            tone(SoundPin, NOTE_C5, 50);
            delay(50);
            tone(SoundPin, NOTE_E5, 50);
            delay(50);
            tone(SoundPin, NOTE_G5, 50);
          }
          if (smenu_no==5){
            chk_kan(latest_tumo, 3);
            do_kan(latest_tumo, 3, 3);
            ban=18;
          }
          if (smenu_no==7){
            agari=3;
            can_agari(agari, latest_tumo, 0);
            richi_bo_old2=richi_bo_old;
            set_point(agari, -1, 0);
            game_mode=12;
            tone(SoundPin, NOTE_C5, 50);
            delay(50);
            tone(SoundPin, NOTE_E5, 50);
            delay(50);
            tone(SoundPin, NOTE_G5, 50);
            delay(50);
            tone(SoundPin, NOTE_A6, 50);
            delay(50);
            tone(SoundPin, NOTE_C6, 50);
          }else{
            tone(SoundPin, NOTE_C3, 50);
          }
        }
        if (debug==0 && key_b==1){
          if (richi_stop==1 && richi[3]>0){
            richi[3]=0;
            richi_no[3]=-1;
            richi_bo_now--;
            points[3]+=1000;
            richi_cnt[3]=0;
            smenu[2]=1;
            smenu_num++;
            py=0;
          }
        }
        if (debug==1 && key_b==1){
          n=pai_sel(3, px);
          pai[3][n].type++;
          if (pai[3][n].type<0x30 && (pai[3][n].type % 16)>=9)
            pai[3][n].type+=7;
          if (pai[3][n].type>=0x30 && (pai[3][n].type % 16)>=7)
            pai[3][n].type=0;
        }
      }
    // Ron
    }else if (ban % 6==3){
      rinshankaiho=0;
      if (ban<18){
        for(i=0;i<9;i++)
          smenu[i]=0;
        if (richi[3]==0 && can_pon(3, latest_sute)==1){
          smenu[0]=1;
          smenu[3]=1;
        }
        if (ban>=12 && richi[3]==0 && can_chi(3, latest_sute)==1){
          smenu[0]=1;
          smenu[4]=1;
        }
        if (richi[3]==0 && can_kan(3, latest_sute)==1){
          smenu[0]=1;
          smenu[5]=1;
        }
        if (can_ron(3, latest_sute)>=1){
          smenu[0]=1;
          smenu[6]=1;
        }
        smenu_num=0;
        for(i=0;i<9;i++)
          if (smenu[i]>0)
            smenu_num++;
        py=0;
      }
      ban++;
    // Pon
    }else if (ban % 6==4){
      if (smenu_num>0){
        if (key_l==1)
          px--;
        else if (key_r==1)
          px++;
        if (px<0)
          px=0;
        if (px>13)
          px=13;
        if (key_u==1)
          py--;
        else if (key_d==1)
          py++;
        if (smenu_num==0)
          py=0;
        else if (py<0)
          py=smenu_num-1;
        else if (py>=smenu_num)
          py=0;
        if (key_a==1 || key_b==1){
          if (smenu_no==3){
            do_pon(latest_sute, 3, ban/6);
            set_px(3);
            ban=3*6+1;
          }
          if (smenu_no==4){
            chk_chi(latest_sute, 3);
            do_chi(latest_sute, 3, ban/6);
            set_px(3);
            ban=3*6+1;
          }
          if (smenu_no==5){
            do_kan(latest_sute, 3, ban/6);
            ban=18;
          }
          if (smenu_no==6){
            agari=3;
            can_agari(agari, latest_sute, 1);
            richi_bo_old2=richi_bo_old;
            set_point(agari, ban/6, 1);
            game_mode=12;
            tone(SoundPin, NOTE_C5, 50);
            delay(50);
            tone(SoundPin, NOTE_E5, 50);
            delay(50);
            tone(SoundPin, NOTE_G5, 50);
            delay(50);
            tone(SoundPin, NOTE_A6, 50);
            delay(50);
            tone(SoundPin, NOTE_C6, 50);
          }
          smenu_num=0;
        }
      }else{
        // Computer
        for(i=0;i<3;i++){
          n=think_naki(i, ban/6, &latest_sute);
          if (n==10){
            agari=i;
            can_agari(agari, latest_sute, 2);
            richi_bo_old2=richi_bo_old;
            set_point(agari, ban/6, 1);
            game_mode=12;
            tone(SoundPin, NOTE_C5, 50);
            delay(50);
            tone(SoundPin, NOTE_E5, 50);
            delay(50);
            tone(SoundPin, NOTE_G5, 50);
            delay(50);
            tone(SoundPin, NOTE_A6, 50);
            delay(50);
            tone(SoundPin, NOTE_C6, 50);
            break;
          }else if (n>0){
            ban=i*6;
            break;
          }
        }
        ban++;
      }
    // Chi
    }else{
      for(i=0;i<4;i++){
        if (richi_cnt[i]>0)
          richi_cnt[i]--;
      }
      ban++;
      if (ban>=24)
        ban=0;
      if (ban==oya_position*6){
        can_dblrichi=0;
        can_13puto=0;
      }
      if (haitei==1){
        game_mode=15;
      }
    }
    show_table(0);
  // Open
  }else if (game_mode==12){
    show_table(2);
    if (key_a==1 || key_b==1){
      game_mode=13;
    }
  // Result
  }else if (game_mode==13){
    show_result(agari, calc_pai);
    if (key_a==1 || key_b==1){
      game_mode=14;
    }
  // Next
  }else if (game_mode==14){
    add_point();
    if (agari==oya_position){
      hon_ba++;
      game_mode=10;
    }else{
      kyoku++;
      oya_position++;
      if (oya_position>3)
        oya_position=0;
      hon_ba=0;
      if (kyoku>=8)
        game_mode=22;
      else
        game_mode=10;
    }
  // Ryukyoku
  }else if (game_mode==15){
    for(i=0;i<4;i++)
      tenpai[i]=chk_tenpai(pai[i]);
    richi_bo_old2=richi_bo_old;
    set_point(0, 0, -1);
    game_mode=16;
    tone(SoundPin, NOTE_G4, 50);
    delay(50);
    tone(SoundPin, NOTE_E4, 50);
    delay(50);
    tone(SoundPin, NOTE_C4, 50);
  // Show Ryukyoku
  }else if (game_mode==16){
    show_table(3);
    if (key_a==1 || key_b==1){
      game_mode=20;
    }
  // Result
  }else if (game_mode==20){
    show_ryukyoku();
    if (key_a==1 || key_b==1){
      game_mode=21;
    }
  // Next
  }else if (game_mode==21){
    add_point();
    if (kyoku>=4 && gm_mode[7]==1){
      hon_ba++;
      game_mode=10;
    }else if (gm_mode[6]==1 && tenpai[oya_position]>0){
      hon_ba++;
      game_mode=10;
    }else{
      kyoku++;
      oya_position++;
      if (oya_position>3)
        oya_position=0;
      hon_ba++;
      if (kyoku>=8)
        game_mode=22;
      else
        game_mode=10;
    }
  // Finish
  }else if (game_mode==22){
    top_no=0;
    for(i=1;i<4;i++){
      if (points[i]>=points[top_no])
        top_no=i;
    }
    points[top_no]=points[top_no]+12000+richi_bo_old*1000+richi_bo_now*1000;
    game_mode=23;
  }else if (game_mode==23){
    show_finish(top_no);
    if (key_a==1 || key_b==1){
      px=0;
      py=0;
      game_mode=0;
    }
  // Configuration
  }else if (game_mode==30){
    px=0;
    py=0;
    game_mode=31;
  }else if (game_mode==31){
    show_config();
    if (key_u==1)
      py--;
    else if (key_d==1)
      py++;
    if (py<0)
      py=7;
    else if (py>7)
      py=0;
    if (key_l==1 || key_r==1){
      if (gm_mode[py]==0)
        gm_mode[py]=1;
      else
        gm_mode[py]=0;
    }
    if (key_a==1 || key_b==1){
      px=0;
      py=0;
      game_mode=0;
    }
  // Calculation
  }else if (game_mode==40){
    px=0;
    py=0;
    game_mode=41;
  }else if (game_mode==41){
    show_tensu();
    if (key_l==1)
      px--;
    else if (key_r==1)
      px++;
    if (px<0)
      px=42;
    else if (px>42)
      px=0;
    if (18<=px && px<30){
      if (px % 3==1)
        px=px+2;
      if (px % 3==2)
        px=px-2;
    }
    if (key_u==1){
      if (0<=px && px<38){
        tensu_pai[px].type++;
        if (tensu_pai[px].type % 16>8)
          tensu_pai[px].type=(tensu_pai[px].type & 0xf0)+0x10;
        if (tensu_pai[px].type>0x36)
          tensu_pai[px].type=-1;
      }else if (px==38){
        tensu_richi--;
        if (tensu_richi<0)
          tensu_richi=4;
      }else if (px==39){
        tensu_tumo--;
        if (tensu_tumo<0)
          tensu_tumo=3;
      }else if (px==40){
        tensu_rinshan--;
        if (tensu_rinshan<0)
          tensu_rinshan=1;
      }else if (px==41){
        tensu_ba--;
        if (tensu_ba<0)
          tensu_ba=3;
      }else if (px==42){
        tensu_kaze--;
        if (tensu_kaze<0)
          tensu_kaze=3;
      }
    }else if (key_d==1){
      if (0<=px && px<38){
        tensu_pai[px].type--;
        if (tensu_pai[px].type<-1)
          tensu_pai[px].type=0x36;
        if (tensu_pai[px].type % 16>8)
          tensu_pai[px].type=tensu_pai[px].type & 0xf0+8;
      }else if (px==38){
        tensu_richi++;
        if (tensu_richi>4)
          tensu_richi=0;
      }else if (px==39){
        tensu_tumo++;
        if (tensu_tumo>3)
          tensu_tumo=0;
      }else if (px==40){
        tensu_rinshan++;
        if (tensu_rinshan>1)
          tensu_rinshan=0;
      }else if (px==41){
        tensu_ba++;
        if (tensu_ba>3)
          tensu_ba=0;
      }else if (px==42){
        tensu_kaze++;
        if (tensu_kaze>3)
          tensu_kaze=0;
      }
    }
    if (key_a==1){
      if ((0<=px && px<14) || (18<=px && px<30)){
        if (tensu_pai[px].type>=0 &&
            (tensu_pai[px].type & 0xf0)<0x30 &&
            (tensu_pai[px].type & 0x0f)<7 &&
            tensu_pai[px].type==tensu_pai[px+1].type &&
            tensu_pai[px].type==tensu_pai[px+2].type){
          tensu_pai[px+1].type=tensu_pai[px].type+1;
          tensu_pai[px+2].type=tensu_pai[px].type+2;
        }else{
          tensu_pai[px+1].type=tensu_pai[px].type;
          tensu_pai[px+2].type=tensu_pai[px].type;
        }
      }
    }
    if (key_b==1){
      game_mode=42;
    }
  // Calculation detail
  }else if (game_mode==42){
    tensu_result(0, calc_pai);
    if (key_a==1){
      px=0;
      py=0;
      game_mode=0;
    }
    if (key_b==1){
      game_mode=41;
    }
  }else{
    game_mode=0;
  }

  delay(20);
}

void chk_kan(struct h_pai getpai, int ply)
{
  int i,j,k,x;
  int kno;
  int ankan;
  char  kan_pai[4];

  kan_no=-1;
  //  カンできる牌を探す
  kno=0;
  for(i=0;pai[ply][i].type>=0;i++){
    kan_pai[kno]=pai[ply][i].type;
    k=0;
    for(j=i;pai[ply][j].type>=0;j++){
      if((pai[ply][j].naki<=1 || pai[ply][j].naki==4) && pai[ply][j].type==kan_pai[kno]){
        k++;
      }
    }
    if(k==4){
      kno++;
    }
  }
  if (kno==0){
    kan_no=-1;
    return;
  }
  if (kno==1){
    kan_no=kan_pai[0];
    return;
  }

  x=0;
  for(;;){
    // Key detect
    StickX = analogRead(StickXPin)/4;
    StickY = analogRead(StickYPin)/4;
    ButtonA = digitalRead(ButtonAPin);
    ButtonB = digitalRead(ButtonBPin);

    if (StickX<256){
      key_l++;
      if (key_l>3)
        key_l=1;
      key_r=0;
    }else if (StickX>768){
      key_l=0;
      key_r++;
      if (key_r>3)
        key_r=1;
    }else{
      key_l=0;
      key_r=0;
    }

    if (ButtonA==0){
      key_a++;
      if (key_a>255)
        key_a=255;
    }else{
      key_a=0;
    }

    if (ButtonB==0){
      key_b++;
      if (key_b>255)
        key_b=255;
    }else{
      key_b=0;
    }

    if (key_l==1)
      x--;
    if (key_r==1)
      x++;
    if (x<0)
      x=kno-1;
    if (x>=kno)
      x=0;

    if (key_a==1 || key_b==1)
      break;
    chi_no[0]=kan_pai[x];
    chi_no[1]=-1;
    chi_no[2]=-1;
    show_table(1);
    delay(20);
  }
  key_l=0;
  key_r=0;
  key_a=0;
  key_b=0;
  kan_no=kan_pai[x];
  return;
}

void chk_chi(struct h_pai getpai,int ply)
{
  int i, x;
  int have_pai;

  have_pai=0;
  for(i=0;pai[ply][i].type>=0;i++){
    if (pai[ply][i].type==getpai.type-2 && pai[ply][i].naki==0)
      have_pai|=0x1;
    if (pai[ply][i].type==getpai.type-1 && pai[ply][i].naki==0)
      have_pai|=0x2;
    if (pai[ply][i].type==getpai.type+1 && pai[ply][i].naki==0)
      have_pai|=0x4;
    if (pai[ply][i].type==getpai.type+2 && pai[ply][i].naki==0)
      have_pai|=0x8;
  }
  if (have_pai==0x3 || have_pai==0xb || have_pai==0x6 ||
      have_pai==0xc || have_pai==0xd){
    chi_no[0]=-1;
    return;
  }

  x=0;
  for(;;){
    // Key detect
    StickX = analogRead(StickXPin)/4;
    StickY = analogRead(StickYPin)/4;
    ButtonA = digitalRead(ButtonAPin);
    ButtonB = digitalRead(ButtonBPin);

    if (StickX<256){
      key_l++;
      if (key_l>3)
        key_l=1;
      key_r=0;
    }else if (StickX>768){
      key_l=0;
      key_r++;
      if (key_r>3)
        key_r=1;
    }else{
      key_l=0;
      key_r=0;
    }

    if (ButtonA==0){
      key_a++;
      if (key_a>255)
        key_a=255;
    }else{
      key_a=0;
    }

    if (ButtonB==0){
      key_b++;
      if (key_b>255)
        key_b=255;
    }else{
      key_b=0;
    }

    if (key_l==1)
      x--;
    if (key_r==1)
      x++;
    if (x<0)
      x=2;
    if (x>2)
      x=0;

    if (have_pai==0x7){
      if (x==0){
        chi_no[0]=getpai.type-2;
        chi_no[1]=getpai.type-1;
        chi_no[2]=-1;
      }else{
        chi_no[0]=getpai.type-1;
        chi_no[1]=getpai.type+1;
        chi_no[2]=-1;
        x=1;        
      }
    }else if (have_pai==0xe){
      if (x==0){
        chi_no[0]=getpai.type-1;
        chi_no[1]=getpai.type+1;
        chi_no[2]=-1;
      }else{
        chi_no[0]=getpai.type+1;
        chi_no[1]=getpai.type+2;
        chi_no[2]=-1;
        x=1;        
      }
    }else{
      if (x==0){
        chi_no[0]=getpai.type-2;
        chi_no[1]=getpai.type-1;
        chi_no[2]=-1;
      }else if (x==1){
        chi_no[0]=getpai.type-1;
        chi_no[1]=getpai.type+1;
        chi_no[2]=-1;
      }else{
        chi_no[0]=getpai.type+1;
        chi_no[1]=getpai.type+2;
        chi_no[2]=-1;
      }
    }
    if (key_a==1 || key_b==1)
      break;
    show_table(1);
    delay(20);
  }
  key_l=0;
  key_r=0;
  key_a=0;
  key_b=0;
  return;
}

void show_title()
{
  int x, y;
  char str[16];

  tft.clearDisplay();
  tft.fillScreen(ILI9341_GREEN);
  
  x=(XMAX-5*16)/2;
  draw_font_bold(x, 50, title_str16, ILI9341_BLUE);

  tft.setTextSize(1);
  tft.setTextColor(ILI9341_BLACK);
  x=(XMAX-8*6)/2;
  tft.setCursor(x, 70);
  sprintf(str, "Ver.%d.%02d", ver/100, ver % 100);
  tft.print(str);

  for(y=0;y<4;y++){
    for(x=0;x<9;x++){
      draw_pai_xy((XMAX-SIZEX*9)/2+x*SIZEX,
        (YMAX-SIZEY*4)/2+y*SIZEY, x, y, 0, 0);
    }
  }

  draw_font_bold(64, YMAX-92,
      gamestart_str16, ILI9341_BLACK);
  draw_font_bold(64, YMAX-76,
      settei_str16, ILI9341_BLACK);
  draw_font_bold(64, YMAX-60,
      calc_str16, ILI9341_BLACK);

  tft.fillTriangle(60, YMAX-84+16*py, 50, YMAX-90+16*py, 50, YMAX-78+16*py, ILI9341_RED);

  draw_font_bold((XMAX-13*12)/2, YMAX-32,
      erabu_str16, ILI9341_RED);

  tft.display();
}

void show_aite(int n)
{
  int x, y;

  tft.clearDisplay();
  tft.fillScreen(ILI9341_GREEN);

  draw_font_bold(88, 64, aite_str16, ILI9341_BLUE);

  draw_font(40, 128, tuyoi_str16, ILI9341_BLUE);
  draw_font(96, 128, futu_str16, ILI9341_BLUE);
  draw_font(168, 128, yowai_str16, ILI9341_BLUE);

  x=56+n*64;
  y=146;
  tft.fillTriangle(x, y, x-5, y+7, x+5, y+7, ILI9341_RED);
  tft.display();
  return;
}

int oya_pai[4];

int show_seki(int n)
{
  int x, y;

  tft.clearDisplay();
  tft.fillScreen(ILI9341_GREEN);

  draw_font_bold(96, 64, seki_str16, ILI9341_BLUE);

  if (n<4){
    for(x=0;x<4;x++){
      draw_pai_xy((XMAX-SIZEX*8)/2+x*SIZEX*2,
        YMAX/2, 7, 3, 0, 0);
    }
    for(x=0;x<4;x++){
      oya_pai[x]=random(0, 4);
      for(;;){
        for(y=0;y<x;y++){
          if (oya_pai[x]==oya_pai[y])
            break;
        }
        if (x==y)
          break;
        oya_pai[x]=random(0, 4);
      }
    }
  }else{
    for(x=0;x<4;x++){
      draw_pai_xy((XMAX-SIZEX*8)/2+x*SIZEX*2,
        YMAX/2, oya_pai[x], 3, 0, 0);
    }
    n=n-4;
  }
  x=(XMAX-SIZEX*8)/2+n*SIZEX*2+SIZEX/2;
  y=YMAX/2+SIZEY;
  tft.fillTriangle(x, y, x-5, y+7, x+5, y+7, ILI9341_RED);
  tft.display();
  return(oya_pai[n]);
}

void show_table(int fin)
{
  int x, y, i;
  int pai_x;
  int n;
  char str[32];
  
  tft.clearDisplay();
  tft.fillScreen(ILI9341_GREEN);

  // Line
  for(y=1;y<=4;y++){
    tft.drawLine(0, y*74-2, XMAX-1, y*74-2, ILI9341_BLACK);
    tft.drawLine(0, y*74-1, XMAX-1, y*74-1, ILI9341_BLACK);
  }
  for(y=0;y<4;y++){
    // Kaze
    tft.drawBitmap(0 , 32+y*74, dir_font(y+4-oya_position), 16, 16, ILI9341_BLUE);
    // Sute
    pai_x=16;
    for(x=0;x<13;x++){
      if (sute[y][x].type>=0){
        if (richi_no[y]==x){
          if (sute[y][x].naki==0)
            draw_pai(pai_x ,8+y*74, sute[y][x].type, 0, 1);
          else
            draw_pai(pai_x ,8+y*74, sute[y][x].type, 1, 1);
          pai_x+=SIZEY;
        }else{
          if (sute[y][x].naki==0)
            draw_pai(pai_x, y*74, sute[y][x].type, 0, 0);
          else
            draw_pai(pai_x, y*74, sute[y][x].type, 1, 0);
          pai_x+=SIZEX;
        }
      }
    }
    pai_x=16;
    for(x=13;x<24;x++){
      if (sute[y][x].type>=0){
        if (richi_no[y]==x){
          if (sute[y][x].naki==0)
            draw_pai(pai_x, 32+y*74, sute[y][x].type, 0, 1);
          else
            draw_pai(pai_x, 32+y*74, sute[y][x].type, 1, 1);
          pai_x+=SIZEY;
        }else{
          if (sute[y][x].naki==0)
            draw_pai(pai_x, 24+y*74, sute[y][x].type, 0, 0);
          else
            draw_pai(pai_x, 24+y*74, sute[y][x].type, 1, 0);
          pai_x+=SIZEX;
        }
      }
    }
    // Pai (naki)
    pai_x=SIZEX;
    for(i=1;i<=4;i++){
      n=0;
      for(x=18;x>=0;x--){
        if (pai[y][x].group==i){
          if (n>=3){
            draw_pai(XMAX-pai_x+28 ,
              32+y*74, pai[y][x].type, 0, 1);
          }else if (pai[y][x].naki==2 && (n==0 || n==2)){
            draw_pai_xy(XMAX-pai_x ,
              48+y*74, 7, 3, 0, 0);
            pai_x+=SIZEX;
          }else{
            draw_pai(XMAX-pai_x ,
              48+y*74, pai[y][x].type, 0, 0);
            pai_x+=SIZEX;
          }
          n++;
        }
      }
    }
    // Pai (tehai)
    pai_x=0;
    for(x=0;x<19;x++){
      if (pai[y][x].type>=0 && pai[y][x].group<=0){
        if (fin<=1 && open_mode==0 && y<3)
          draw_pai_xy(pai_x ,
            48+y*74, 7, 3, 0, 0);
        else
          draw_pai(pai_x ,
            48+y*74, pai[y][x].type, 0, 0);
        pai_x+=SIZEX;
      }
    }
  }
  // Dora
  for(x=0;x<4;x++){
    if(x<=kan_count)
      draw_pai(32+x*SIZEX ,
        YMAX-24, dora_draw[x].type, 0, 0);
    else
      draw_pai_xy(32+x*SIZEX ,
        YMAX-24, 7, 3, 0, 0);
  }
  // Kyoku
  tft.drawBitmap(0 , YMAX-16, dir_font(kyoku/4), 16, 16, ILI9341_RED);
  tft.drawBitmap(16, YMAX-16, jis_font(0x2300+'1'+kyoku % 4), 16, 16, ILI9341_RED);
  // Ten bo
  tft.drawRGBSprite(112 , YMAX-20, ten1000_bmp, 16, 5, 0);
  tft.drawRGBSprite(112 , YMAX-10, ten100_bmp, 16, 5, 0);
  tft.setTextSize(1);
  tft.setTextColor(ILI9341_BLACK);
  tft.setCursor(132, YMAX-22);
  sprintf(str, "x%d", richi_bo_old2);
  tft.print(str);
  tft.setCursor(132, YMAX-12);
  sprintf(str, "x%d", hon_ba);
  tft.print(str);
  tft.setCursor(96, YMAX-12);
  sprintf(str, "%2d", 136-16+kan_count-yama_count);
  tft.print(str);

  // Richi
  for(x=0;x<4;x++){
    if (richi[x]>0){
      draw_font(XMAX-48, 32+x*74, richi_str16, ILI9341_RED);
      tft.drawRGBSprite(160 , YMAX-24+x*6, ten1000_bmp, 16, 5, 0);
    }
  }

  // Select pai
  if (fin==1){
    n=0;
    for(x=0;pai[3][x].type>=0;x++){
      for(i=0;i<2;i++){
        if (chi_no[i]==pai[3][x].type && pai[3][x].naki==0){
          tft.drawRect(n*16, 48+3*74, 15, 23, ILI9341_RED);
          tft.drawRect(n*16-1, 47+3*74, 17, 25, ILI9341_RED);
          break;
        }
      }
      if (pai[3][x].naki==0)
        n++;
    }
  }else if (ban==20){
    tft.drawRect(px*16, 48+3*74, 15, 23, ILI9341_RED);
    tft.drawRect(px*16-1, 47+3*74, 17, 25, ILI9341_RED);
  }else{
    n=richi_no[latest_sute.who];
    if (0<=latest_sute.group && latest_sute.group<13){
      if (0<=n && n<latest_sute.group){
        tft.drawRect(24+SIZEX*latest_sute.group, latest_sute.who*74,
          15, 23, ILI9341_RED);
        tft.drawRect(23+SIZEX*latest_sute.group, latest_sute.who*74-1,
          17, 25, ILI9341_RED);
      }else if (n==latest_sute.group){
        tft.drawRect(16+SIZEX*latest_sute.group, 8+latest_sute.who*74,
          23, 15, ILI9341_RED);
        tft.drawRect(15+SIZEX*latest_sute.group, 7+latest_sute.who*74,
          25, 17, ILI9341_RED);
      }else{
        tft.drawRect(16+SIZEX*latest_sute.group, latest_sute.who*74,
          15, 23, ILI9341_RED);
        tft.drawRect(15+SIZEX*latest_sute.group, latest_sute.who*74-1,
          17, 25, ILI9341_RED);
      }
    }else if (0<=latest_sute.group){
      if (13<=n && n<latest_sute.group){
        tft.drawRect(24+SIZEX*(latest_sute.group-13), 24+latest_sute.who*74,
          15, 23, ILI9341_RED);
        tft.drawRect(23+SIZEX*(latest_sute.group-13), 23+latest_sute.who*74,
          17, 25, ILI9341_RED);
      }else if (n==latest_sute.group){
        tft.drawRect(16+SIZEX*(latest_sute.group-13), 32+latest_sute.who*74,
          23, 15, ILI9341_RED);
        tft.drawRect(15+SIZEX*(latest_sute.group-13), 31+latest_sute.who*74,
          25, 17, ILI9341_RED);
      }else{
        tft.drawRect(16+SIZEX*(latest_sute.group-13), 24+latest_sute.who*74,
          15, 23, ILI9341_RED);
        tft.drawRect(15+SIZEX*(latest_sute.group-13), 23+latest_sute.who*74,
          17, 25, ILI9341_RED);
      }
    }
  }

  // Normal
  if (fin==0){
    if (haitei==1)
      draw_font_bold( XMAX-96, YMAX-16, haitei_str16, ILI9341_RED);
    else if (hon_ba>=5 && gm_mode[5]==1)
      draw_font_bold( XMAX-96, YMAX-16, ryanhan_str16, ILI9341_RED);
  }
  // Chi select
  if (fin==1){
    draw_font_bold( XMAX-64, YMAX-16, sentaku_str16, ILI9341_RED);
  // Agari
  }else if (fin==2){
    if (ban/6==agari){
      draw_font_bold( 120, 32+agari*74, tumo_str16, ILI9341_RED);
    }else{
      draw_font_bold( 120, 32+agari*74, ron_str16, ILI9341_RED);
    }
  // Ryukyoku
  }else if (fin==3){
    draw_font_bold( XMAX-64, YMAX-16, ryukyoku_str16, ILI9341_RED);
    for(i=0;i<4;i++){
      if (tenpai[i]>0){
        draw_font_bold( 120, 32+i*74, tenpai_str16, ILI9341_RED);
      }else{
        draw_font_bold( 120, 32+i*74, noten_str16, ILI9341_RED);
      }
    }
  }else{
    draw_smenu(py);
  }

  tft.display();
}

void show_result(int ply, struct h_pai *pdata)
{
  int x;
  int i, n;
  int dx, dy;
  char str[32];
  tft.clearDisplay();
  tft.fillScreen(ILI9341_GREEN);

  // Sute
  dx=16;
  for(x=0;x<13;x++){
    if (sute[ply][x].type>=0){
      if (richi_no[ply]==x){
        if (sute[ply][x].naki==0)
          draw_pai(dx , 8, sute[ply][x].type, 0, 1);
        else
          draw_pai(dx , 8, sute[ply][x].type, 1, 1);
        dx+=SIZEY;
      }else{
        if (sute[ply][x].naki==0)
          draw_pai(dx , 0, sute[ply][x].type, 0, 0);
        else
          draw_pai(dx , 0, sute[ply][x].type, 1, 0);
        dx+=SIZEX;
      }
    }
  }
  dx=16;
  for(x=13;x<24;x++){
    if (sute[ply][x].type>=0){
      if (richi_no[ply]==x){
        if (sute[ply][x].naki==0)
          draw_pai(dx, 8+SIZEY, sute[ply][x].type, 0, 1);
        else
          draw_pai(dx, 8+SIZEY, sute[ply][x].type, 1, 1);
        dx+=SIZEY;
      }else{
        if (sute[ply][x].naki==0)
          draw_pai(dx, SIZEY, sute[ply][x].type, 0, 0);
        else
          draw_pai(dx, SIZEY, sute[ply][x].type, 1, 0);
        dx+=SIZEX;
      }
    }
  }

  // Pai (naki)
  dx=SIZEX;
  for(i=1;i<=4;i++){
    n=0;
    for(x=18;x>=0;x--){
      if (pdata[x].group==i){
        if (n>=3){
          draw_pai(XMAX-dx+28, 48, pdata[x].type, 0, 1);
        }else if (pdata[x].naki==2 && (n==0 || n==2)){
          draw_pai_xy(XMAX-dx, 64, 7, 3, 0, 0);
          dx+=SIZEX;
        }else{
          draw_pai(XMAX-dx, 64, pdata[x].type, 0, 0);
          dx+=SIZEX;
        }
        n++;
      }
    }
  }
  // Pai (tehai)
  dx=0;
  for(x=0;x<19;x++){
    if (pdata[x].type>=0 && pdata[x].group<=0){
      draw_pai(dx , 64, pdata[x].type, 0, 0);
      dx+=SIZEX;
    }
  }

  // Dora
  for(x=0;x<4;x++){
    if(x<=kan_count){
      draw_pai(x*SIZEX, 96, dora[x].type, 0, 0);
      if (dora[x+kan_count+1].type>=0)
        draw_pai(x*SIZEX, 120, dora[x+kan_count+1].type, 0, 0);
    }else{
      draw_pai_xy(x*SIZEX, 96, 7, 3, 0, 0);
    }
  }

  // Kaze
  tft.drawBitmap(0 , 48, dir_font(ply+4-oya_position), 16, 16, ILI9341_BLUE);
  // Kyoku
  tft.drawBitmap(0 , 144, dir_font(kyoku/4), 16, 16, ILI9341_RED);
  tft.drawBitmap(16, 144, jis_font(0x2300+'1'+kyoku % 4), 16, 16, ILI9341_RED);

  // Ten bo
  tft.drawRGBSprite(32 , 146, ten1000_bmp, 16, 5, 0);
  tft.drawRGBSprite(32 , 156, ten100_bmp, 16, 5, 0);
  tft.setTextSize(1);
  tft.setTextColor(ILI9341_BLACK);
  tft.setCursor(52, 144);
  sprintf(str, "x%d", richi_bo_old2);
  tft.print(str);
  tft.setCursor(52, 154);
  sprintf(str, "x%d", hon_ba);
  tft.print(str);
  // Richi
  for(x=0;x<4;x++){
    if (richi[x]>0)
      tft.drawRGBSprite(32 , 166+x*6, ten1000_bmp, 16, 5, 0);
  }

  dy=96;
  if (ycount<0){
    draw_font( 80, dy, furiten_str16, ILI9341_BLACK);
    point_max=-8000;
    ten_max=0;
    han_max=0;
    dy+=16;
  }else if (ycount==0 || point_max<=0){
    draw_font( 80, dy, chonbo_str16, ILI9341_BLACK);
    if (hon_ba>=5)
      draw_font( 80, dy+16, ryanhan_str16, ILI9341_BLACK);
    point_max=-8000;
    ten_max=0;
    han_max=0;
    dy+=16;
  }else{
    for(i=0;yakutxt[yaku_max][i].han>0;i++){
      draw_font( 80, dy, yakutxt[yaku_max][i].name, ILI9341_BLACK);
      draw_font_num(192, dy, yakutxt[yaku_max][i].han, ILI9341_BLACK);
      dy+=16;
    }
  }
  if (dy<192)
    dy=192;
  draw_font_num(0, dy, ten_max, ILI9341_BLACK);
  draw_font( 32, dy, ten_str16, ILI9341_BLACK);
  if (han_max>=10)
    draw_font_num(48, dy, han_max, ILI9341_BLACK);
  else
    draw_font_num(64, dy, han_max, ILI9341_BLACK);
  draw_font( 80, dy, han_str16, ILI9341_BLACK);
  if (point_max<=-10000)
    draw_font_num(112, dy, point_max, ILI9341_BLACK);
  else if (point_max>=10000 || point_max<0)
    draw_font_num(128, dy, point_max, ILI9341_BLACK);
  else
    draw_font_num(144, dy, point_max, ILI9341_BLACK);
  draw_font( 208, dy, ten_str16, ILI9341_BLACK);

  // Member and points
  for(x=0;x<4;x++){
    if (pnt_add[x]==0){
      sprintf(str, "%7d", points[x]);
      draw_font_str(64, YMAX-80+x*16, str, ILI9341_BLACK);
    }else if (pnt_add[x]>0){
      sprintf(str, "%7d+%d", points[x], pnt_add[x]);
      draw_font_str(64, YMAX-80+x*16, str, ILI9341_BLUE);
    }else{
      sprintf(str, "%7d-%d", points[x], abs(pnt_add[x]));
      draw_font_str(64, YMAX-80+x*16, str, ILI9341_RED);
    }

    if (x==0)
      draw_font(0, YMAX-80+x*16, simo_str16, ILI9341_BLACK);
    if (x==1)
      draw_font(0, YMAX-80+x*16, toi_str16, ILI9341_BLACK);
    if (x==2)
      draw_font(0, YMAX-80+x*16, kami_str16, ILI9341_BLACK);
    if (x==3)
      draw_font(0, YMAX-80+x*16, anata_str16, ILI9341_BLACK);
  }

  draw_font_bold((XMAX-13*12)/2, YMAX-16,
      tugi_str16, ILI9341_RED);

  tft.display();
}

void show_ryukyoku()
{
  int x;
  int i, j, n;
  int dx, dy;
  char str[32];
  tft.clearDisplay();
  tft.fillScreen(ILI9341_GREEN);

  for(j=0;j<4;j++){
    // Kaze
    tft.drawBitmap(0 , j*48, dir_font(j+4-oya_position), 16, 16, ILI9341_BLUE);
    // Pai (naki)
    dx=SIZEX;
    for(i=1;i<=4;i++){
      n=0;
      for(x=18;x>=0;x--){
        if (pai[j][x].group==i){
          if (n>=3){
            draw_pai(XMAX-dx+28, j*48, pai[j][x].type, 0, 1);
          }else if (pai[j][x].naki==2 && (n==0 || n==2)){
            draw_pai_xy(XMAX-dx, j*48+16, 7, 3, 0, 0);
            dx+=SIZEX;
          }else{
            draw_pai(XMAX-dx, j*48+16, pai[j][x].type, 0, 0);
            dx+=SIZEX;
          }
          n++;
        }
      }
    }
    // Pai (tehai)
    dx=0;
    for(x=0;x<19;x++){
      if (pai[j][x].type>=0 && pai[j][x].group<=0){
        draw_pai(dx , j*48+16, pai[j][x].type, 0, 0);
        dx+=SIZEX;
      }
    }
  }

  // Member and points
  for(x=0;x<4;x++){
    if (pnt_add[x]==0){
      sprintf(str, "%7d", points[x]);
      draw_font_str(64, YMAX-80+x*16, str, ILI9341_BLACK);
    }else if (pnt_add[x]>0){
      sprintf(str, "%7d+%d", points[x], pnt_add[x]);
      draw_font_str(64, YMAX-80+x*16, str, ILI9341_BLUE);
    }else{
      sprintf(str, "%7d-%d", points[x], abs(pnt_add[x]));
      draw_font_str(64, YMAX-80+x*16, str, ILI9341_RED);
    }

    if (x==0)
      draw_font(0, YMAX-80+x*16, simo_str16, ILI9341_BLACK);
    if (x==1)
      draw_font(0, YMAX-80+x*16, toi_str16, ILI9341_BLACK);
    if (x==2)
      draw_font(0, YMAX-80+x*16, kami_str16, ILI9341_BLACK);
    if (x==3)
      draw_font(0, YMAX-80+x*16, anata_str16, ILI9341_BLACK);
  }

  draw_font_bold((XMAX-13*12)/2, YMAX-16,
      tugi_str16, ILI9341_RED);

  tft.display();
}

void show_finish(int top_ply)
{
  int x, y;
  char str[32];

  tft.clearDisplay();
  tft.fillScreen(ILI9341_GREEN);

  for(x=0;x<4;x++){
    sprintf(str, "%7d", points[x]);
    if (x==top_ply)
      draw_font_str_bold(80, 96+x*32, str, ILI9341_RED);
    else
      draw_font_str(80, 96+x*32, str, ILI9341_BLACK);
    draw_font(168, 96+x*32, ten_str16, ILI9341_BLACK);
    if (x==0)
      draw_font(0, 96+x*32, simo_str16, ILI9341_BLACK);
    if (x==1)
      draw_font(0, 96+x*32, toi_str16, ILI9341_BLACK);
    if (x==2)
      draw_font(0, 96+x*32, kami_str16, ILI9341_BLACK);
    if (x==3)
      draw_font(0, 96+x*32, anata_str16, ILI9341_BLACK);
  }

  draw_font_bold((XMAX-13*12)/2, YMAX-50,
      tugi_str16, ILI9341_RED);

  tft.display();
}

uint16_t conf0_str16[]={0x252a,0x213c,0x2557,0x2573,0x2562,0x213c,0x2549,0x0000};
uint16_t conf1_str16[]={0x3f29,0x2424,0x4347,0x0000};
uint16_t conf2_str16[]={0x3d3d,0x3b30,0x4954,0x4563,0x0000};
uint16_t conf3_str16[]={0x4e22,0x2549,0x2569,0x0000};
uint16_t conf4_str16[]={0x252b,0x2573,0x4e22,0x2549,0x2569,0x0000};
uint16_t conf5_str16[]={0x2332,0x664c,0x477b,0x246a,0x0000};
uint16_t conf6_str16[]={0x2546,0x2573,0x2551,0x2524,0x4f22,0x4171,0x0000};
uint16_t conf7_str16[]={0x466e,0x3e6c,0x254e,0x213c,0x2546,0x2573,0x4f22,0x4171,0x0000};
uint16_t ari_str16[]={0x2422,0x246a,0x0000};
uint16_t nasi_str16[]={0x244a,0x2437,0x0000};

void show_config()
{
  int x, y;
  tft.clearDisplay();
  tft.fillScreen(ILI9341_GREEN);

  draw_font_bold(104, 32,
      settei_str16, ILI9341_BLACK);

  draw_font(32, 80, conf0_str16, ILI9341_BLACK);
  draw_font(32, 104,conf1_str16, ILI9341_BLACK);
  draw_font(32, 128,conf2_str16, ILI9341_BLACK);
  draw_font(32, 152,conf3_str16, ILI9341_BLACK);
  draw_font(32, 176,conf4_str16, ILI9341_BLACK);
  draw_font(32, 200,conf5_str16, ILI9341_BLACK);
  draw_font(32, 224,conf6_str16, ILI9341_BLACK);
  draw_font(32, 248,conf7_str16, ILI9341_BLACK);

  for(x=0;x<8;x++){
    if (gm_mode[x]==1)
      tft.fillRect(160, 80+x*24, 32, 16, ILI9341_RED);
    else
      tft.fillRect(200, 80+x*24, 32, 16, ILI9341_RED);
    draw_font(160, 80+x*24, ari_str16, ILI9341_BLACK);
    draw_font(200, 80+x*24, nasi_str16, ILI9341_BLACK);
  }

  tft.fillTriangle(28, 88+24*py, 18, 82+24*py, 18, 94+24*py, ILI9341_RED);

  draw_font_bold((XMAX-13*12)/2, YMAX-32,
      modoru_str16, ILI9341_RED);

  tft.display();
}

uint16_t agarihai_str16[]={0x3e65,0x242c,0x246a,0x4757,0x0000};
uint16_t naki_str16[]={0x244a,0x242d,0x0000};
uint16_t calc_a_str16[]={0x2341,0x255c,0x253f,0x2573,0x2127,0x2333,0x4757,0x253b,0x2543,0x2548,0x0000};
uint16_t calc_b_str16[]={0x2342,0x255c,0x253f,0x2573,0x2127,0x3e5c,0x3a59,0x0000};
uint16_t oya_str16[]={0x3f46,0x0000};
uint16_t ko_str16[]={0x3b52,0x0000};

void show_tensu()
{
  int x, y;
  int cx, cy;
  int sx, sy;
  int pai_cnt, pai_group;
  char str[8];

  tft.clearDisplay();
  tft.fillScreen(ILI9341_GREEN);

  draw_font_bold(96, 0, calc_str16, ILI9341_BLUE);
  draw_font(0, 0, agarihai_str16, ILI9341_RED);
  draw_font(0, 80, naki_str16, ILI9341_RED);
  draw_font(0, 172, dora_str16, ILI9341_RED);

  // Tehai
  for(x=0;x<14;x++){
    if (tensu_pai[x].type<0)
      continue;
    calc_cursor(x, &cx, &cy, &sx, &sy);
    draw_pai(cx, cy, tensu_pai[x].type, 0, 0);
  }

  // Ankan hai
  for(x=0;x<4;x++){
    if (tensu_pai[x+14].type<0)
      continue;
    calc_cursor(x+14, &cx, &cy, &sx, &sy);
    draw_pai_xy(cx, cy+16, 7, 3, 0, 0);
    draw_pai(cx+16, cy+16, tensu_pai[x+14].type, 0, 0);
    draw_pai_xy(cx+32, cy+16, 7, 3, 0, 0);
    draw_pai(cx+12, cy, tensu_pai[x+14].type, 0, 1);
  }

  // Naki hai
  for(y=0;y<4;y++){
    for(x=0;x<3;x++){
      if (tensu_pai[y*3+x+18].type<0)
        continue;
      calc_cursor(y*3+x+18, &cx, &cy, &sx, &sy);
      draw_pai(cx, cy, tensu_pai[y*3+x+18].type, 0, 0);
    }
  }

  // Minkan hai
  for(x=0;x<4;x++){
    if (tensu_pai[x+30].type<0)
      continue;
    calc_cursor(x+30, &cx, &cy, &sx, &sy);
    draw_pai(cx, cy+16, tensu_pai[x+30].type, 0, 0);
    draw_pai(cx+16, cy+16, tensu_pai[x+30].type, 0, 0);
    draw_pai(cx+32, cy+16, tensu_pai[x+30].type, 0, 0);
    draw_pai(cx+12, cy, tensu_pai[x+30].type, 0, 1);
  }

  // Dora
  for(x=0;x<4;x++){
    if (tensu_pai[x+34].type<0)
      continue;
    calc_cursor(x+34, &cx, &cy, &sx, &sy);
    draw_pai(cx, cy, tensu_pai[x+34].type, 0, 0);
  }

  // Richi
  tft.fillRect(0, 208+tensu_richi*16, 80, 16, ILI9341_RED);
  draw_font(0, 208, nasi_str16, ILI9341_BLACK);
  draw_font(0, 224, richi_str16, ILI9341_BLACK);
  draw_font(0, 240, richi1_str16, ILI9341_BLACK);
  draw_font(0, 256, dblrichi0_str16, ILI9341_BLACK);
  draw_font(0, 272, dblrichi1_str16, ILI9341_BLACK);

  // Tumo
  tft.fillRect(80, 208+tensu_tumo*16, 64, 16, ILI9341_RED);
  draw_font(80, 208, ron_str16, ILI9341_BLACK);
  draw_font(80, 224, tumo_str16, ILI9341_BLACK);
  draw_font(80, 240, haiteiron_str16, ILI9341_BLACK);
  draw_font(80, 256, haiteitumo_str16, ILI9341_BLACK);

  // Rinshan
  tft.fillRect(144, 208+tensu_rinshan*16, 64, 16, ILI9341_RED);
  draw_font(144, 208, nasi_str16, ILI9341_BLACK);
  draw_font(144, 224, rinshan_str16, ILI9341_BLACK);

  // Ba
  tft.fillRect(208, 208+tensu_ba*16, 16, 16, ILI9341_RED);
  for(x=0;x<4;x++)
    tft.drawBitmap(208, 208+x*16, dir_font(x), 16, 16, ILI9341_BLACK);

  // Kaze
  tft.fillRect(224, 208+tensu_kaze*16, 16, 16, ILI9341_RED);
  for(x=0;x<4;x++)
    tft.drawBitmap(224, 208+x*16, dir_font(x), 16, 16, ILI9341_BLACK);

  // Waku
  for(x=0;x<38;x++){
    calc_cursor(x, &cx, &cy, &sx, &sy);
    tft.drawRect(cx, cy, sx, sy, ILI9341_BLACK);
  }

  // Draw cursor
  calc_cursor(px, &cx, &cy, &sx, &sy);
  if (sx>0 && sy>0){
    tft.drawRect( cx, cy, sx, sy, ILI9341_RED);
    tft.drawRect( cx+1, cy+1, sx-2, sy-2, ILI9341_RED);
  }else{
    tft.fillTriangle(cx+8, cy-2, cx+2, cy-12, cx+14, cy-12, ILI9341_RED);
  }

  // Ten
  draw_font_bold(104, 162, oya_str16, ILI9341_RED);
  draw_font_bold(104, 178, ko_str16, ILI9341_RED);

  init_deliver();
  pai_cnt=0;
  pai_group=1;
  for(x=1;x<14;x++){
    if (tensu_pai[x].type>=0){
      pai[0][pai_cnt].type=tensu_pai[x].type;
      pai[0][pai_cnt].naki=0;
      pai[0][pai_cnt].group=-1;
      pai_cnt++;
    }
  }
  for(x=14;x<18;x++){
    if (pai_cnt>18){
      pai_cnt=20;
      break;
    }
    if (tensu_pai[x].type>=0){
      for(y=0;y<4;y++){
        if (pai_cnt>18){
          pai_cnt=20;
          break;
        }
        pai[0][pai_cnt].type=tensu_pai[x].type;
        pai[0][pai_cnt].naki=2;
        pai[0][pai_cnt].group=pai_group;
        pai_cnt++;
      }
      pai_group++;
    }
  }
  for(x=18;x<30;x+=3){
    if (pai_cnt>18){
      pai_cnt=20;
      break;
    }
    if (tensu_pai[x].type>=0 && tensu_pai[x].type!=tensu_pai[x+2].type){
      for(y=0;y<3;y++){
        pai[0][pai_cnt].type=tensu_pai[x+y].type;
        pai[0][pai_cnt].naki=3;
        pai[0][pai_cnt].group=pai_group;
        pai_cnt++;
      }
      pai_group++;
    }else if (tensu_pai[x].type>=0){
      for(y=0;y<3;y++){
        pai[0][pai_cnt].type=tensu_pai[x+y].type;
        pai[0][pai_cnt].naki=4;
        pai[0][pai_cnt].group=pai_group;
        pai_cnt++;
      }
      pai_group++;
    }
  }
  for(x=30;x<34;x++){
    if (pai_cnt>18){
      pai_cnt=20;
      break;
    }
    if (tensu_pai[x].type>=0){
      for(y=0;y<4;y++){
        if (pai_cnt>18){
          pai_cnt=20;
          break;
        }
        pai[0][pai_cnt].type=tensu_pai[x].type;
        pai[0][pai_cnt].naki=5;
        pai[0][pai_cnt].group=pai_group;
        pai_cnt++;
      }
      pai_group++;
    }
  }

  if (pai_cnt<18){
    pai[0][pai_cnt].type=tensu_pai[0].type;
    pai[0][pai_cnt].naki=1;
    pai_cnt++;
    pai[0][pai_cnt].type=-1;
  }
  pai[0][18].type=-1;
  latest_sute.type=tensu_pai[0].type;
  latest_tumo.type=tensu_pai[0].type;
  
  y=0;
  for(x=0;x<4;x++){
    if(tensu_pai[34+x].type>=0){
      dora[y].type=tensu_pai[34+x].type;
      y++;
    }
  }
  for(x=y;x<5;x++)
    dora[x].type=-1;
  richi[0]=tensu_richi;
  haitei=tensu_tumo/2;
  kyoku=tensu_ba*4;
  rinshankaiho=tensu_rinshan;

  // Ron
  if (14<=pai_cnt && pai_cnt<=17 && (tensu_tumo & 1)==0){
    oya_position=0;
    y=tensu_point(0, latest_sute, 1);
    if (y>0){
      set_point(0, 1, 1);
      tft.setTextSize(1);
      tft.setTextColor(ILI9341_BLUE);
      tft.setCursor(120, 166);
      sprintf(str, "%6d", pnt_add[0]);
      tft.print(str);
      tft.setTextColor(ILI9341_RED);
      tft.setCursor(160, 166);
      sprintf(str, "%6d", pnt_add[1]);
      tft.print(str);
      point_oya[0]=pnt_add[0];
      point_oya[1]=pnt_add[1];
      point_oya[2]=pnt_add[2];
    }

    oya_position=1;
    y=tensu_point(0, latest_sute, 1);
    if (y>0){
      set_point(0, 1, 1);
      tft.setTextSize(1);
      tft.setTextColor(ILI9341_BLUE);
      tft.setCursor(120, 182);
      sprintf(str, "%6d", pnt_add[0]);
      tft.print(str);
      tft.setTextColor(ILI9341_RED);
      tft.setCursor(160, 182);
      sprintf(str, "%6d", pnt_add[1]);
      tft.print(str);
      point_ko[0]=pnt_add[0];
      point_ko[1]=pnt_add[1];
      point_ko[2]=pnt_add[2];
    }
  // Tumo
  }else if(14<=pai_cnt && pai_cnt<=17){
    oya_position=0;
    y=tensu_point(0, latest_tumo, 0);
    if (y>0){
      set_point(0, 1, 0);
      tft.setTextSize(1);
      tft.setTextColor(ILI9341_BLUE);
      tft.setCursor(120, 166);
      sprintf(str, "%6d", pnt_add[0]);
      tft.print(str);
      tft.setTextColor(ILI9341_RED);
      tft.setCursor(160, 166);
      sprintf(str, "%6d", pnt_add[1]);
      tft.print(str);
      point_oya[0]=pnt_add[0];
      point_oya[1]=pnt_add[1];
      point_oya[2]=pnt_add[2];
    }

    oya_position=1;
    y=tensu_point(0, latest_tumo, 0);
    if (y>0){
      set_point(0, 1, 0);
      tft.setTextSize(1);
      tft.setTextColor(ILI9341_BLUE);
      tft.setCursor(120, 182);
      sprintf(str, "%6d", pnt_add[0]);
      tft.print(str);
      tft.setTextColor(ILI9341_RED);
      tft.setCursor(160, 182);
      sprintf(str, "%6d", pnt_add[1]);
      tft.print(str);
      tft.setCursor(200, 182);
      sprintf(str, "%6d", pnt_add[2]);
      tft.print(str);
      point_ko[0]=pnt_add[0];
      point_ko[1]=pnt_add[1];
      point_ko[2]=pnt_add[2];
    }
  }

  draw_font_bold((XMAX-13*12)/2, YMAX-32,
      calc_a_str16, ILI9341_RED);
  draw_font_bold((XMAX-13*12)/2, YMAX-16,
      calc_b_str16, ILI9341_RED);

  tft.display();
}

uint16_t result_a_str16[]={0x2341,0x255c,0x253f,0x2573,0x2127,0x2548,0x2543,0x2557,0x0000};
uint16_t result_b_str16[]={0x2342,0x255c,0x253f,0x2573,0x2127,0x4540,0x3f74,0x3757,0x3b3b,0x0000};

void tensu_result(int ply, struct h_pai *pdata)
{
  int x;
  int i, n;
  int dx, dy;
  char str[32];
  tft.clearDisplay();
  tft.fillScreen(ILI9341_GREEN);

  // Sute
  dx=16;
  for(x=0;x<13;x++){
    if (sute[ply][x].type>=0){
      if (richi_no[ply]==x){
        if (sute[ply][x].naki==0)
          draw_pai(dx , 8, sute[ply][x].type, 0, 1);
        else
          draw_pai(dx , 8, sute[ply][x].type, 1, 1);
        dx+=SIZEY;
      }else{
        if (sute[ply][x].naki==0)
          draw_pai(dx , 0, sute[ply][x].type, 0, 0);
        else
          draw_pai(dx , 0, sute[ply][x].type, 1, 0);
        dx+=SIZEX;
      }
    }
  }
  dx=16;
  for(x=13;x<24;x++){
    if (sute[ply][x].type>=0){
      if (richi_no[ply]==x){
        if (sute[ply][x].naki==0)
          draw_pai(dx, 8+SIZEY, sute[ply][x].type, 0, 1);
        else
          draw_pai(dx, 8+SIZEY, sute[ply][x].type, 1, 1);
        dx+=SIZEY;
      }else{
        if (sute[ply][x].naki==0)
          draw_pai(dx, SIZEY, sute[ply][x].type, 0, 0);
        else
          draw_pai(dx, SIZEY, sute[ply][x].type, 1, 0);
        dx+=SIZEX;
      }
    }
  }

  // Pai (naki)
  dx=SIZEX;
  for(i=1;i<=4;i++){
    n=0;
    for(x=18;x>=0;x--){
      if (pdata[x].group==i){
        if (n>=3){
          draw_pai(XMAX-dx+28, 48, pdata[x].type, 0, 1);
        }else if (pdata[x].naki==2 && (n==0 || n==2)){
          draw_pai_xy(XMAX-dx, 64, 7, 3, 0, 0);
          dx+=SIZEX;
        }else{
          draw_pai(XMAX-dx, 64, pdata[x].type, 0, 0);
          dx+=SIZEX;
        }
        n++;
      }
    }
  }
  // Pai (tehai)
  dx=0;
  for(x=0;x<19;x++){
    if (pdata[x].type>=0 && pdata[x].group<=0){
      draw_pai(dx , 64, pdata[x].type, 0, 0);
      dx+=SIZEX;
    }
  }

  // Dora
  for(x=0;x<4;x++){
    if (dora[x].type>=0)
      draw_pai(x*SIZEX, 120, dora[x].type, 0, 0);
    else
      draw_pai_xy(x*SIZEX, 96, 7, 3, 0, 0);
  }

  // Kaze
  tft.drawBitmap(0 , 48, dir_font(tensu_kaze), 16, 16, ILI9341_BLUE);
  // Kyoku
  tft.drawBitmap(0 , 144, dir_font(tensu_ba), 16, 16, ILI9341_RED);

  dy=96;
  if (ycount<0){
    draw_font( 80, dy, furiten_str16, ILI9341_BLACK);
    point_max=-8000;
    ten_max=0;
    han_max=0;
    dy+=16;
  }else if (ycount==0 || point_max<=0){
    draw_font( 80, dy, chonbo_str16, ILI9341_BLACK);
    point_max=-8000;
    ten_max=0;
    han_max=0;
    dy+=16;
  }else{
    for(i=0;yakutxt[yaku_max][i].han>0;i++){
      draw_font( 80, dy, yakutxt[yaku_max][i].name, ILI9341_BLACK);
      draw_font_num(192, dy, yakutxt[yaku_max][i].han, ILI9341_BLACK);
      dy+=16;
    }
  }
  if (dy<192)
    dy=192;
  draw_font_num(0, dy, ten_max, ILI9341_BLACK);
  draw_font( 32, dy, ten_str16, ILI9341_BLACK);
  if (han_max>=10)
    draw_font_num(48, dy, han_max, ILI9341_BLACK);
  else
    draw_font_num(64, dy, han_max, ILI9341_BLACK);
  draw_font( 80, dy, han_str16, ILI9341_BLACK);
  if (point_max<=-10000)
    draw_font_num(112, dy, point_max, ILI9341_BLACK);
  else if (point_max>=10000 || point_max<0)
    draw_font_num(128, dy, point_max, ILI9341_BLACK);
  else
    draw_font_num(144, dy, point_max, ILI9341_BLACK);
  draw_font( 208, dy, ten_str16, ILI9341_BLACK);

  // Points
  draw_font(0, YMAX-80, oya_str16, ILI9341_BLACK);
  sprintf(str, "%6d", point_oya[0]);
  draw_font_str(16, YMAX-80, str, ILI9341_BLUE);
  sprintf(str, "%6d", point_oya[1]);
  draw_font_str(92, YMAX-80, str, ILI9341_RED);
  if (point_oya[2]!=0){
    sprintf(str, "%6d", point_oya[2]);
    draw_font_str(168, YMAX-80, str, ILI9341_RED);
  }

  draw_font(0, YMAX-64, ko_str16, ILI9341_BLACK);
  sprintf(str, "%6d", point_ko[0]);
  draw_font_str(16, YMAX-64, str, ILI9341_BLUE);
  sprintf(str, "%6d", point_ko[1]);
  draw_font_str(92, YMAX-64, str, ILI9341_RED);
  if (point_ko[2]!=0){
    sprintf(str, "%6d", point_ko[2]);
    draw_font_str(168, YMAX-64, str, ILI9341_RED);
  }

  draw_font_bold(48, YMAX-32, result_a_str16, ILI9341_RED);
  draw_font_bold(48, YMAX-16, result_b_str16, ILI9341_RED);

  tft.display();
}

int tensu_point(int who, struct h_pai agarip, int ron)
{
  int i;
  int rc, rin;
  int ppoint,ten_point,han_point;
  struct h_pai tmp;
  struct h_pai tmppai[19];

  copy_pai(calc_pai, pai[who]);

  copy_pai(tmppai, calc_pai);
  tmp.type=agarip.type;
  i=bunkatu(tmppai, &tmp);
  if(i<=0){
    ten_max=0;
    han_max=0;
    point_max=0;
    return(0);
  }

  yaku_max=0;
  ten_max=0;
  han_max=0;
  point_max=0;
  if (richi_cnt[who]>0)
    rc=richi[who]+1;
  else
    rc=richi[who];
  rin=rinshankaiho+haitei*2;
  for(i=0;i<ycount;i++){
    if(ron>=1){
      ppoint=tensu_cal(yaku[i],dora,yakutxt[i],&han_point,&ten_point,
             rc,rin,0,tensu_ba,tensu_kaze);
    }else{
      ppoint=tensu_cal(yaku[i],dora,yakutxt[i],&han_point,&ten_point,
             rc,rin,1,tensu_ba,tensu_kaze);
    }
    if(ppoint>point_max){
      yaku_max=i;
      point_max=ppoint;
      ten_max=ten_point;
      han_max=han_point;
    }
  }
  return(han_max);
}

void calc_cursor(int x, int *cx, int *cy, int *sx, int *sy)
{
  if (x==0){
    *cx=8;
    *cy=16;
    *sx=SIZEX;
    *sy=SIZEY;
  }else if (x<14){
    *cx=16+x*SIZEX;
    *cy=16;
    *sx=SIZEX;
    *sy=SIZEY;
  }else if (x<18){
    *cx=(x-14)*(SIZEX*3+8);
    *cy=40;
    *sx=SIZEX*3;
    *sy=SIZEX+SIZEY;
  }else if (x<21){
    *cx=(x-18)*SIZEX;
    *cy=96;
    *sx=SIZEX;
    *sy=SIZEY;
  }else if (x<24){
    *cx=(x-18)*SIZEX+8;
    *cy=96;
    *sx=SIZEX;
    *sy=SIZEY;
  }else if (x<27){
    *cx=(x-18)*SIZEX+16;
    *cy=96;
    *sx=SIZEX;
    *sy=SIZEY;
  }else if (x<30){
    *cx=(x-18)*SIZEX+24;
    *cy=96;
    *sx=SIZEX;
    *sy=SIZEY;
  }else if (x<34){
    *cx=(x-30)*(SIZEX*3+8);
    *cy=120;
    *sx=SIZEX*3;
    *sy=SIZEX+SIZEY;
  }else if (x<38){
    *cx=(x-34)*SIZEX+32;
    *cy=168;
    *sx=SIZEX;
    *sy=SIZEY;
  }else if (x==38){
    *cx=32;
    *cy=208;
    *sx=0;
    *sy=0;
  }else if (x==39){
    *cx=104;
    *cy=208;
    *sx=0;
    *sy=0;
  }else if (x==40){
    *cx=168;
    *cy=208;
    *sx=0;
    *sy=0;
  }else if (x==41){
    *cx=208;
    *cy=208;
    *sx=0;
    *sy=0;
  }else if (x==42){
    *cx=224;
    *cy=208;
    *sx=0;
    *sy=0;
  }
}

void draw_smenu(int n)
{
  int i, j;
  int x;

  x=-1;
  j=0;
  for(i=0;i<9;i++){
    if (smenu[i]>0){
      if (j==n){
        x=i;
        break;
      }
      j++;
    }
  }
  smenu_no=x;
  // tugi
  if (x==0){
    tft.drawBitmap(XMAX-32,YMAX-16, jis_font(0x2444), 16, 16, ILI9341_WHITE, ILI9341_MAGENTA);
    tft.drawBitmap(XMAX-16,YMAX-16, jis_font(0x242E), 16, 16, ILI9341_WHITE, ILI9341_MAGENTA);
  }
  // sute
  if (x==1){
    tft.drawBitmap(XMAX-32,YMAX-16, jis_font(0x2439), 16, 16, ILI9341_WHITE, ILI9341_BLUE);
    tft.drawBitmap(XMAX-16,YMAX-16, jis_font(0x2446), 16, 16, ILI9341_WHITE, ILI9341_BLUE);
  }
  // richi
  if (x==2){
    tft.drawBitmap(XMAX-48,YMAX-16, jis_font(0x256a), 16, 16, ILI9341_WHITE, ILI9341_RED);
    tft.drawBitmap(XMAX-32,YMAX-16, jis_font(0x213c), 16, 16, ILI9341_WHITE, ILI9341_RED);
    tft.drawBitmap(XMAX-16,YMAX-16, jis_font(0x2541), 16, 16, ILI9341_WHITE, ILI9341_RED);
  }
  // pon
  if (x==3){
    tft.drawBitmap(XMAX-32,YMAX-16, jis_font(0x255d), 16, 16, ILI9341_WHITE, ILI9341_RED);
    tft.drawBitmap(XMAX-16,YMAX-16, jis_font(0x2573), 16, 16, ILI9341_WHITE, ILI9341_RED);
  }
  // chi
  if (x==4){
    tft.drawBitmap(XMAX-32,YMAX-16, jis_font(0x2541), 16, 16, ILI9341_WHITE, ILI9341_RED);
    tft.drawBitmap(XMAX-16,YMAX-16, jis_font(0x213c), 16, 16, ILI9341_WHITE, ILI9341_RED);
  }
  // kan
  if (x==5){
    tft.drawBitmap(XMAX-32,YMAX-16, jis_font(0x252b), 16, 16, ILI9341_WHITE, ILI9341_RED);
    tft.drawBitmap(XMAX-16,YMAX-16, jis_font(0x2573), 16, 16, ILI9341_WHITE, ILI9341_RED);
  }
  // ron
  if (x==6){
    tft.drawBitmap(XMAX-32,YMAX-16, jis_font(0x256d), 16, 16, ILI9341_WHITE, ILI9341_RED);
    tft.drawBitmap(XMAX-16,YMAX-16, jis_font(0x2573), 16, 16, ILI9341_WHITE, ILI9341_RED);
  }
  // tumo
  if (x==7){
    tft.drawBitmap(XMAX-32,YMAX-16, jis_font(0x2544), 16, 16, ILI9341_WHITE, ILI9341_RED);
    tft.drawBitmap(XMAX-16,YMAX-16, jis_font(0x2562), 16, 16, ILI9341_WHITE, ILI9341_RED);
  }
}

void draw_pai(int x, int y, int pai_type, int dark, int dir)
{
  int i;
  uint16_t dark_pai[SIZEX*SIZEY];
  uint16_t *tmp;
  uint16_t val;

  if (dark==0){
    tft.drawRGBSprite(x , y,
          pai_img(pai_type), SIZEX, SIZEY, dir);
  }else{
    tmp=pai_img(pai_type);
    for(i=0;i<SIZEX*SIZEY;i++){
      val=*(tmp++);
      val=((val & 0xf7de) >> 1)+((val & 0xe79c) >> 2);
      dark_pai[i]=val;
    }
    tft.drawRGBSprite(x , y,
          dark_pai, SIZEX, SIZEY, dir);
  }
}

void draw_pai_xy(int x, int y, int typex, int typey, int dark, int dir)
{
  int i;
  uint16_t dark_pai[SIZEX*SIZEY];
  uint16_t *tmp;
  uint16_t val;

  if (dark==0){
    tft.drawRGBSprite(x , y,
          pai_img_xy(typex, typey), SIZEX, SIZEY, dir);
  }else{
    tmp=pai_img_xy(typex, typey);
    for(i=0;i<SIZEX*SIZEY;i++){
      val=*(tmp++);
      val=((val & 0xf7de) >> 1)+((val & 0xe79c) >> 2);
      dark_pai[i]=val;
    }
    tft.drawRGBSprite(x , y,
          dark_pai, SIZEX, SIZEY, dir);
  }
}

void draw_font(int x, int y, uint16_t *str16, uint16_t c)
{
  int i, dx, dy;
  dx=x;
  dy=y;
  for(i=0; str16[i]!=0; i++){
    if (dx>XMAX-16){
      dy+=16;
      dx=0;
    }
    tft.drawBitmap(dx, dy, jis_font(str16[i]), 16, 16, c);
    dx+=16;
  }
}

void draw_font_bold(int x, int y, uint16_t *str16, uint16_t c)
{
  draw_font(x, y, str16, c);
  draw_font(x+1, y, str16, c);
}

void draw_font_num(int x, int y, int num, uint16_t c)
{
  int i, dx, dy;
  char str[32];

  sprintf(str, "%d", num);
  draw_font_str(x, y, str, c);
}

void draw_font_str(int x, int y, char *str, uint16_t c)
{
  int i, dx, dy;

  dx=x;
  dy=y;
  for(i=0; str[i]!=0; i++){
    if (dx>XMAX-12){
      dy+=16;
      dx=0;
    }
    if (str[i]==' ')
      tft.drawBitmap(dx, dy, jis_font(0x2121), 16, 16, c);
    else if (str[i]=='+')
      tft.drawBitmap(dx, dy, jis_font(0x215c), 16, 16, c);
    else if (str[i]=='-')
      tft.drawBitmap(dx, dy, jis_font(0x215d), 16, 16, c);
    else if (str[i]=='*')
      tft.drawBitmap(dx, dy, jis_font(0x215f), 16, 16, c);
    else if (str[i]=='/')
      tft.drawBitmap(dx, dy, jis_font(0x213f), 16, 16, c);
    else if (str[i]=='=')
      tft.drawBitmap(dx, dy, jis_font(0x2161), 16, 16, c);
    else if (str[i]=='(')
      tft.drawBitmap(dx, dy, jis_font(0x214a), 16, 16, c);
    else if (str[i]==')')
      tft.drawBitmap(dx, dy, jis_font(0x214b), 16, 16, c);
    else if (str[i]=='{')
      tft.drawBitmap(dx, dy, jis_font(0x2150), 16, 16, c);
    else if (str[i]=='}')
      tft.drawBitmap(dx, dy, jis_font(0x2151), 16, 16, c);
    else if (str[i]=='<')
      tft.drawBitmap(dx, dy, jis_font(0x2163), 16, 16, c);
    else if (str[i]=='>')
      tft.drawBitmap(dx, dy, jis_font(0x2164), 16, 16, c);
    else if (str[i]==',')
      tft.drawBitmap(dx, dy, jis_font(0x2124), 16, 16, c);
    else if (str[i]=='.')
      tft.drawBitmap(dx, dy, jis_font(0x2125), 16, 16, c);
    else if (str[i]==':')
      tft.drawBitmap(dx, dy, jis_font(0x2127), 16, 16, c);
    else if (str[i]==';')
      tft.drawBitmap(dx, dy, jis_font(0x2128), 16, 16, c);
    else if (str[i]=='?')
      tft.drawBitmap(dx, dy, jis_font(0x2129), 16, 16, c);
    else if (str[i]=='!')
      tft.drawBitmap(dx, dy, jis_font(0x212a), 16, 16, c);
    else
      tft.drawBitmap(dx, dy, jis_font(0x2300+str[i]), 16, 16, c);
    dx+=12;
  }
}

void draw_font_str_bold(int x, int y, char *str, uint16_t c)
{
  draw_font_str(x, y, str, c);
  draw_font_str(x+1, y, str, c);
}

uint16_t *pai_img(int x)
{
  int i, j;
  i=x % 16;
  j=x/16;
  if (i<0 || 9<=i)
    i=0;
  if (j<0 || 4<=j)
    j=0;
  return(&pai_bmp[(j*9+i)*16*24]);
}

uint16_t *pai_img_xy(int x, int y)
{
  return(&pai_bmp[(y*9+x)*16*24]);
}

const uint8_t *dir_font(int x)
{
  int n;
  n=x % 4;
  if (n==0)  return(jis456c);
  if (n==1)  return(jis466e);
  if (n==2)  return(jis403e);
  return(jis4b4c);
}

int pai_sel(int ply, int n)
{
  int i, m;
  
  m=0;
  px_max=0;
  for(i=0;i<18;i++){
    if (pai[ply][i].type>=0 && pai[ply][i].group<=0){
      if (px_max==n)
        m=i;
      px_max++;
    }
  }
  return(m);
}

void set_px(int ply)
{
  int i, m;
  px_max=0;
  for(i=0;i<18;i++){
    if (pai[ply][i].type>=0 && pai[ply][i].group<=0){
      px_max++;
    }
  }
  px=px_max-1;
}

//  Shuffle pai
void shuffle()
{
  int i,j,k,typ;
  
  for(i=0;i<136;i++)
    yama[i]=-1;
  for(i=0;i<4;i++){
    for(j=0;j<34;j++){
      typ=(j/9)*16+(j % 9);
      k=random(0, 136);
      if(yama[k]==-1){
        yama[k]=typ;
      }else{
        for(;;){
          k++;
          if(k>=136)
            k=0;
          if(yama[k]==-1){
            yama[k]=typ;
            break;
          }
        }
      }
    }
  }
  yama_count=0;
  // Dora
  for(i=0;i<8;i++)
    dora_draw[i].type=yama[128+i];
  return;
}
//  Deliver pai
void init_deliver()
{
  int i,j;
  for(i=0;i<4;i++){
    for(j=0;j<19;j++){
    pai[i][j].type=-1;
    pai[i][j].naki=0;
    pai[i][j].group=-1;
    pai[i][j].who=0;
    }
  }
  for(i=0;i<4;i++){
    for(j=0;j<24;j++){
    sute[i][j].type=-1;
    sute[i][j].naki=0;
    sute[i][j].group=-1;
    sute[i][j].who=0;
    }
  }
  dlv_count=0;
  return;
}
int deliver(int oyap)
{
  int j;
  int dlv_no;
  if(dlv_count>80 || dlv_count<0)
    return(-1);
  if((dlv_count%4)!=3){
    dlv_count++;
    return(dlv_count/64);
  }
  dlv_no=(dlv_count/4+oyap) % 4;
  if(dlv_count<16){
    for(j=0;j<4;j++){
      pai[dlv_no][j].type=yama[yama_count++];
    }
  }else if(dlv_count<32){
    for(j=4;j<8;j++){
      pai[dlv_no][j].type=yama[yama_count++];
    }
  }else if(dlv_count<48){
    for(j=8;j<12;j++){
      pai[dlv_no][j].type=yama[yama_count++];
    }
  }else if(dlv_count<64){
    pai[dlv_no][12].type=yama[yama_count++];
  }
  dlv_count++;
  if(dlv_count>64)
    dlv_count=64;
  return(dlv_count/64);
}
// Get pai
char get_1pai(int who)
{
  int x;
  char n;
  for(x=0;pai[who][x].type>=0;x++);
  n=yama[yama_count++];
  pai[who][x].type=n;
  pai[who][x].naki=0;
  pai[who][x].group=-1;
  latest_tumo.type=n;
  latest_tumo.naki=0;
  latest_tumo.group=-1;
  if(yama_count>=(136-16+kan_count))
    haitei=1;
  else
    haitei=0;
  return(n);
}
//  Sort pai
void sort_pai(struct h_pai *pdata)
{
  struct h_pai tmp[19];
  int i,j,min_no,max_pnt,pnt;
  copy_pai(tmp,pdata);
  j=0;
  for(;;){
    max_pnt=-1;
    for(i=0;i<19;i++){
    if(0<=tmp[i].group)
      pnt=(int)tmp[i].group*64+128;
    else
      pnt=64;
    if(0<=tmp[i].type)
      pnt=pnt-(int)tmp[i].type;
    else
      pnt=-1;
    if(max_pnt<pnt){
      min_no=i;
      max_pnt=pnt;
    }
    }
    if(max_pnt<0)
    break;
    pdata[j].type=tmp[min_no].type;
    pdata[j].naki=tmp[min_no].naki;
    pdata[j].group=tmp[min_no].group;
    pdata[j].who=tmp[min_no].who;
    tmp[min_no].type=-1;
    j++;
  }
  for(i=j;i<19;i++){
    pdata[i].type=-1;
    pdata[i].naki=0;
    pdata[i].group=-1;
    pdata[i].who=0;
  }
  return;
}
//  separate pai
int bunkatu(struct h_pai *paip,struct h_pai *tumo)
{
  int i,j,k;
  char tmp1;
  char gno,sgno;
  char tumo_type;
  char atama=0;
  struct h_pai tmp[19];
  struct h_pai pdata[19];
  //  流し満貫
  if(nagasi_agari==1){
    ycount=1;
    return(1);
  }
  tumo_type=tumo->type;
  copy_pai(pdata,paip);
  for(i=0;i<19;i++)
    if(pdata[i].naki==1)
      pdata[i].naki=0;
  sort_pai(pdata);
  ycount=0;
  //  七対子
  gno=1;
  tmp1=-1;
  for(i=0;i<7;i++){
    if(pdata[i*2].naki<3 && pdata[i*2+1].naki<3 && 0<=pdata[i*2].type &&
       pdata[i*2].type==pdata[i*2+1].type && pdata[i*2].type!=tmp1){
      yaku[ycount][i*2].type=pdata[i*2].type;
      yaku[ycount][i*2].naki=0;
      yaku[ycount][i*2].group=gno;
      yaku[ycount][i*2].who=0;
      yaku[ycount][i*2+1].type=pdata[i*2+1].type;
      yaku[ycount][i*2+1].naki=0;
      yaku[ycount][i*2+1].group=gno;
      yaku[ycount][i*2+1].who=0;
      tmp1=pdata[i*2].type;
      gno++;
    }else{
      break;
    }
  }
  if(i==7 && pdata[14].type==-1){
    for(j=14;j<19;j++){
      yaku[ycount][j].type=-1;
      yaku[ycount][j].naki=0;
      yaku[ycount][j].group=-1;
      yaku[ycount][j].who=0;
    }
    ycount++;
  }
  //  国士無双
  copy_pai(yaku[ycount],pdata);
  k=0;
  for(i=0;i<14;i++){
    if(yaku[ycount][i].naki<3){
    if(yaku[ycount][i].type==0)
      k=k | 0x0001;
    if(yaku[ycount][i].type==8)
      k=k | 0x0002;
    if(yaku[ycount][i].type==16)
      k=k | 0x0004;
    if(yaku[ycount][i].type==24)
      k=k | 0x0008;
    if(yaku[ycount][i].type==32)
      k=k | 0x0010;
    if(yaku[ycount][i].type==40)
      k=k | 0x0020;
    if(yaku[ycount][i].type==48)
      k=k | 0x0040;
    if(yaku[ycount][i].type==49)
      k=k | 0x0080;
    if(yaku[ycount][i].type==50)
      k=k | 0x0100;
    if(yaku[ycount][i].type==51)
      k=k | 0x0200;
    if(yaku[ycount][i].type==52)
      k=k | 0x0400;
    if(yaku[ycount][i].type==53)
      k=k | 0x0800;
    if(yaku[ycount][i].type==54)
      k=k | 0x1000;
    if(yaku[ycount][i].type<48 && (yaku[ycount][i].type % 16)!=0 &&
       (yaku[ycount][i].type % 16)!=8)
      k=k | 0x2000;   //  国士無双でない
    }
  }
  if(k==0x1FFF && yaku[ycount][14].type==-1){
    ycount++;
  }
  //  十三不塔
  gno=0;
  copy_pai(yaku[ycount],pdata);
  gno=-10;
  for(i=0;i<19;i++){
    if(yaku[ycount][i].group==-1 && yaku[ycount][i].type>=0){
      //  Find atama
      for(j=i+1;j<19;j++){
        if(yaku[ycount][j].naki<3 && yaku[ycount][i].type==yaku[ycount][j].type){
          atama=yaku[ycount][i].type;
          yaku[ycount][i].group=0;
          yaku[ycount][j].group=0;
          gno=1;
          i=19;
          break;
        }
      }
    }
  }
  for(i=0;i<19;i++){
    if(yaku[ycount][i].group==-1 && yaku[ycount][i].type>=0 && yaku[ycount][i].naki<3){
      tmp1=1;
      for(j=i+1;j<19;j++){
        if(yaku[ycount][j].type==yaku[ycount][i].type)
          tmp1=0;
      }
      if(yaku[ycount][i].type<48){
        for(j=i+1;j<19;j++){
          if(yaku[ycount][j].type>=0 && abs(yaku[ycount][j].type-yaku[ycount][i].type)<=2)
            tmp1=0;
        }
      }
      if(yaku[ycount][i].type==atama){
        tmp1=0;
      }
      if(tmp1==1){
        yaku[ycount][i].group=gno;
        gno++;
      }
    }
  }
  if(can_13puto==1 && gno==13 && tumo_type>=0){
    ycount++;
  }
  // others
  kantu(pdata);
  sgno=1;
  for(i=0;i<19;i++)
    if(sgno<=pdata[i].group)
      sgno=pdata[i].group+1;
  for(i=0;i<19;i++){
    gno=sgno;
    copy_pai(yaku[ycount],pdata);
    if(yaku[ycount][i].group==-1 && yaku[ycount][i].type>=0){
      //  Find atama
      for(j=i+1;j<19;j++)
        if(yaku[ycount][j].naki<3 && yaku[ycount][i].type==yaku[ycount][j].type){
          yaku[ycount][i].group=0;
          yaku[ycount][j].group=0;
        }
      if(yaku[ycount][i].group!=0)
        continue;
      copy_pai(tmp,yaku[ycount]);
loop_koutu:
      k=koutu(yaku[ycount],gno);
      if(k==2){
        if(ycount==0 || eq_pai(yaku[ycount-1],yaku[ycount])==0)
          ycount++;
        if(ycount>=8){
          return(ycount);
        }
        goto loop_next;
      }else if(k==1){
        gno++;
        goto loop_koutu;
      }
      k=juntu(yaku[ycount],gno);
      if(k==2){
        if(ycount==0 || eq_pai(yaku[ycount-1],yaku[ycount])==0)
          ycount++;
        if(ycount>=8){
          return(ycount);
        }
      }else if(k==1){
        gno++;
        goto loop_koutu;
      }
loop_next:
      gno=sgno;
      copy_pai(yaku[ycount],tmp);
loop_juntu:
      k=juntu(yaku[ycount],gno);
      if(k==2){
        if(ycount==0 || eq_pai(yaku[ycount-1],yaku[ycount])==0)
          ycount++;
        if(ycount>=8){
          return(ycount);
        }
        continue;
      }else if(k==1){
        gno++;
        goto loop_juntu;
      }
      k=koutu(yaku[ycount],gno);
      if(k==2){
        if(ycount==0 || eq_pai(yaku[ycount-1],yaku[ycount])==0)
          ycount++;
        if(ycount>=8){
          return(ycount);
        }
        continue;
      }else if(k==1){
        gno++;
        goto loop_juntu;
      }
    }
  }
  //  ツモ牌の設定
  ytcount=0;
  for(i=0;i<ycount;i++){
    set_tumopai(yaku[i],tumo_type);
  }
  for(i=0;i<ytcount;i++){
    for(j=0;j<19;j++){
      yaku[i][j].type=yakutumo[i][j].type;
      yaku[i][j].naki=yakutumo[i][j].naki;
      yaku[i][j].group=yakutumo[i][j].group;
      yaku[i][j].who=yakutumo[i][j].who;
    }
  }
  ycount=ytcount;
  return(ycount);
}
//  ツモ牌の設定
void set_tumopai(struct h_pai *pdata,char tumo_type)
{
  int i,j;
  int gmax,flg;
  int gno[6];
  gmax=0;
  for(i=0;i<19;i++){
    if(pdata[i].naki==0 && pdata[i].type==tumo_type){
      flg=1;
      for(j=0;j<gmax;j++){
        if(pdata[i].group==gno[j])
          flg=0;
      }
      if(flg==1){
        gno[gmax]=pdata[i].group;
        gmax++;
      }
    }
  }
  //  tumo_typeがダミーの場合
  if(gmax==0){
    for(j=0;j<19;j++){
      yakutumo[ytcount][j].type=pdata[j].type;
      yakutumo[ytcount][j].group=pdata[j].group;
      yakutumo[ytcount][j].who=pdata[j].who;
      yakutumo[ytcount][j].naki=pdata[j].naki;
    }
    ytcount++;
    return;
  }
  for(i=0;i<gmax;i++){
    flg=0;
    for(j=0;j<19;j++){
      yakutumo[ytcount][j].type=pdata[j].type;
      yakutumo[ytcount][j].group=pdata[j].group;
      yakutumo[ytcount][j].who=pdata[j].who;
      if(flg==0 && gno[i]==pdata[j].group && tumo_type==pdata[j].type){
        yakutumo[ytcount][j].naki=1;
        flg=1;
      }else{
        yakutumo[ytcount][j].naki=pdata[j].naki;
      }
    }
    ytcount++;
  }
  return;
}
int kantu(struct h_pai *pdata)
{
  int i,j;
    int kan_num;
    int gno;
    gno=1;
    kan_num=0;
  for(i=0;i<19;i++){
      if(0<=pdata[i].type)
        kan_num++;
      if(gno<=pdata[i].group)
        gno=pdata[i].group+1;
    }
    kan_num-=14;
    if(kan_num<=0)
      return(0);
  for(i=0;i<19;i++){
    if(pdata[i].group==-1 && 0<=pdata[i].type){
    j=pdata[i].type;
    if(pdata[i+1].group==-1 && pdata[i+1].type==j &&
       pdata[i+2].group==-1 && pdata[i+2].type==j &&
       pdata[i+3].group==-1 && pdata[i+3].type==j){
      pdata[i].group=gno;
      pdata[i+1].group=gno;
      pdata[i+2].group=gno;
      pdata[i+3].group=gno;
      pdata[i].naki=2;
      pdata[i+1].naki=2;
      pdata[i+2].naki=2;
      pdata[i+3].naki=2;
          gno++;
          kan_num--;
        }
      }
      if(kan_num<=0)
        return(1);
  }
  return(1);
}
int koutu(struct h_pai *pdata,int gno)
{
  int i,j;
  for(i=0;i<19;i++){
    if(pdata[i].group==-1 && 0<=pdata[i].type){
    j=pdata[i].type;
    if(pdata[i+1].group==-1 && pdata[i+1].type==j &&
       pdata[i+2].group==-1 && pdata[i+2].type==j){
      pdata[i].group=gno;
      pdata[i+1].group=gno;
      pdata[i+2].group=gno;
      //  Check all bunkatu
      for(j=0;j<19;j++)
      if(pdata[j].type>=0 && pdata[j].group<0)
        break;
      if(j==19)
      return(2);
      return(1);
    }else
      return(0);
    }
  }
  return(2);
}
int juntu(struct h_pai *pdata,int gno)
{
  int i,j,k;
  int jun1,jun2;
  for(i=0;i<19;i++){
    if(pdata[i].group==-1){
    if(0<=pdata[i].type && pdata[i].type<48){
      j=pdata[i].type;
      jun1=-1;
      jun2=-1;
      for(k=i+1;k<19;k++){
      if(pdata[k].group==-1 && pdata[k].type==j+1)
        jun1=k;
      if(pdata[k].group==-1 && pdata[k].type==j+2)
        jun2=k;
      }
      if(jun1>0 && jun2>0){
      pdata[i].group=gno;
      pdata[jun1].group=gno;
      pdata[jun2].group=gno;
      //  Check all bunkatu
      for(j=0;j<19;j++)
        if(pdata[j].type>=0 && pdata[j].group<0)
        break;
      if(j==19)
        return(2);
      return(1);
      }else
      return(0);
    }else
      return(0);
    }
  }
  return(2);
}
int agari_pai(struct h_pai *pdata,struct h_pai *adata)
{
  int i,j;
  int acount;
  int tmp13puto;
  struct h_pai tmp[19],btmp[19];
  char str[64];
  j=0;
  for(i=0;i<19;i++){
    if(pdata[i].type>=0){
    tmp[j].type=pdata[i].type;
    tmp[j].naki=pdata[i].naki;
    tmp[j].group=pdata[i].group;
    tmp[j].who=pdata[i].who;
    j++;
    }
  }
  for(i=j;i<19;i++){
    tmp[i].type=-1;
    tmp[i].naki=0;
    tmp[i].group=-1;
    tmp[i].who=0;
  }
  acount=0;
  tmp13puto=can_13puto;
  can_13puto=0;
  for(i=0;i<=8;i++){
    tmp[j].type=i;
    copy_pai(btmp,tmp);
    if(bunkatu(btmp,&tmp[j])>0){
    adata[acount].type=i;
    adata[acount].naki=0;
    adata[acount].group=-1;
    adata[acount].who=0;
    acount++;
    }
  }
  for(i=16;i<=24;i++){
    tmp[j].type=i;
    copy_pai(btmp,tmp);
    if(bunkatu(btmp,&tmp[j])>0){
    adata[acount].type=i;
    adata[acount].naki=0;
    adata[acount].group=-1;
    adata[acount].who=0;
    acount++;
    }
  }
  for(i=32;i<=40;i++){
    tmp[j].type=i;
    copy_pai(btmp,tmp);
    if(bunkatu(btmp,&tmp[j])>0){
    adata[acount].type=i;
    adata[acount].naki=0;
    adata[acount].group=-1;
    adata[acount].who=0;
    acount++;
    }
  }
  for(i=48;i<=54;i++){
    tmp[j].type=i;
    copy_pai(btmp,tmp);
    if(bunkatu(btmp,&tmp[j])>0){
    adata[acount].type=i;
    adata[acount].naki=0;
    adata[acount].group=-1;
    adata[acount].who=0;
    acount++;
    }
  }
  adata[acount].type=-1;
  adata[acount].naki=0;
  adata[acount].group=-1;
  adata[acount].who=0;
  can_13puto=tmp13puto;
  return(acount);
}
int furiten(struct h_pai *pdata,struct h_pai *sutedata)
{
  struct h_pai apai[16];
  struct h_pai tmp[19];
  int i,j,acount;
  j=0;
  for(i=0;pdata[i].type>=0;i++){
    if(pdata[i].naki!=1){
    tmp[j].type=pdata[i].type;
    tmp[j].naki=pdata[i].naki;
    tmp[j].group=pdata[i].group;
    tmp[j].who=pdata[i].who;
    j++;
    }
  }
  for(i=j;i<19;i++){
    tmp[i].type=-1;
    tmp[i].naki=0;
    tmp[i].group=-1;
    tmp[i].who=0;
  }
  acount=agari_pai(tmp,apai);
  for(i=0;sutedata[i].type>=0;i++){
    for(j=0;j<acount;j++){
    if(sutedata[i].type==apai[j].type)
      return(1);
    }
  }
  return(0);
}

void copy_pai(struct h_pai *dis,struct h_pai *org)
{
  int i;
  for(i=0;i<19;i++){
    dis[i].type=org[i].type;
    dis[i].naki=org[i].naki;
    dis[i].group=org[i].group;
    dis[i].who=org[i].who;
  }
  return;
}

int eq_pai(struct h_pai *dis,struct h_pai *org)
{
  int i;
  for(i=0;i<19;i++){
    if(0<=org[i].type && (dis[i].type!=org[i].type ||
     dis[i].group!=org[i].group)){
    break;
    }
  }
  if(i==19)
    return(1);
  return(0);
}

uint16_t *str16cpy(uint16_t *dist, uint16_t *src)
{
  uint16_t *dpt, *spt;
  dpt=dist;
  spt=src;
  do{
    *(dpt++)=*spt;
  }while(*(spt++)!=0);
  return(dist);
}

int tensu_cal(struct h_pai *pdata,struct h_pai *dorap,struct h_yaku *ydata,
        int *han,int *ten,int richi_n,int rinshan,int tumo,int ba,int kaze)
{
  int i,j,flg,flg2,flg3,flg4;
  int xo0,xo1,xo2;
  int ycnt,hcnt,tcnt,pcnt;
  int naki;
  int chitoitu;
  int pinf;
  int typ1;
  //  上がり役の初期化
  yaku_clear(0);
  //  流し満貫
  if(nagasi_agari==1){
//    strcpy(ydata[0].name,"流し満貫");
    str16cpy(ydata[0].name, nagasi_str16);
    ydata[0].han=4;
    ycnt=1;
    agari_yaku.nagasi=1;
    *han=4;
    agari_yaku.fan=4;
    *ten=30;
    ydata[ycnt].han=-1; //  データの最後を示す
    pcnt=8000;
    return(pcnt);
  }
  //  点数計算メイン
  sort_pai(pdata);
  naki=0;
  for(i=0;pdata[i].type>=0;i++){
    if(pdata[i].naki>=3){
      naki=1;
      break;
    }
  }
  *ten=0;
  ycnt=0;
  pinf=0;
  //  十三不塔
  flg=0;
  for(i=0;i<19;i++){
    if(pdata[i].type>=0)
    if(flg<pdata[i].group)
      flg=pdata[i].group;
  }
  if(flg==12 && (tumo % 2)==1){
//    strcpy(ydata[ycnt].name,"十三不塔");
    str16cpy(ydata[ycnt].name, sisanputo_str16);
    ydata[ycnt].han=16;
    ycnt++;
    agari_yaku.puto13=1;
  }
  //  国士無双
  flg=0;
  for(i=0;pdata[i].type>=0;i++){
    if((pdata[i].type % 16)==0 && pdata[i].type<48)
    flg=flg | (1 << (pdata[i].type/16));
    if((pdata[i].type % 16)==8 && pdata[i].type<48)
    flg=flg | (8 << (pdata[i].type/16));
    if(pdata[i].type>=48)
    flg=flg | (64 << (pdata[i].type-48));
  }
  if(flg==0x1fff){
//    strcpy(ydata[ycnt].name,"国士無双");
    str16cpy(ydata[ycnt].name, kokusi_str16);
    ydata[ycnt].han=16;
    ycnt++;
    agari_yaku.kokusimuso=1;
  }
  //  リーチ
  //if(richi_n>0){
  //  richi_bo_now=richi_bo_now+richi_bo_old;
  //  richi_bo_old=0;
  //}
  if(richi_n==1){
//    strcpy(ydata[ycnt].name,"リーチ");
    str16cpy(ydata[ycnt].name, richi_str16);
    ydata[ycnt].han=1;
    ycnt++;
    agari_yaku.richi=1;
  }else if(richi_n==2){
//    strcpy(ydata[ycnt].name,"リーチ");
    str16cpy(ydata[ycnt].name, richi_str16);
    ydata[ycnt].han=1;
    ycnt++;
    agari_yaku.richi=1;
//    strcpy(ydata[ycnt].name,"一発");
    str16cpy(ydata[ycnt].name, ippatu_str16);
    ydata[ycnt].han=1;
    ycnt++;
    agari_yaku.ipatu=1;
  }else if(richi_n==3){
//    strcpy(ydata[ycnt].name,"ダブルリーチ");
    str16cpy(ydata[ycnt].name, dblrichi_str16);
    ydata[ycnt].han=2;
    ycnt++;
    agari_yaku.dbl_richi=1;
  }else if(richi_n==4){
//    strcpy(ydata[ycnt].name,"ダブルリーチ");
    str16cpy(ydata[ycnt].name, dblrichi_str16);
    ydata[ycnt].han=2;
    ycnt++;
    agari_yaku.dbl_richi=1;
//    strcpy(ydata[ycnt].name,"一発");
    str16cpy(ydata[ycnt].name, ippatu_str16);
    ydata[ycnt].han=1;
    ycnt++;
    agari_yaku.ipatu=1;
  }
  if(naki==0 && tumo==1){
//    strcpy(ydata[ycnt].name,"門前清摸和");
    str16cpy(ydata[ycnt].name, menzentumo_str16);
    ydata[ycnt].han=1;
    ycnt++;
    agari_yaku.tumo=1;
  }else if(tumo==3 && agari_yaku.puto13!=1){
//    strcpy(ydata[ycnt].name,"天和");
    str16cpy(ydata[ycnt].name, tenho_str16);
    ydata[ycnt].han=16;
    ycnt++;
    agari_yaku.tenho=1;
  }else if((tumo==4 || tumo==5) && agari_yaku.puto13!=1){
//    strcpy(ydata[ycnt].name,"地和");
    str16cpy(ydata[ycnt].name, chiho_str16);
    ydata[ycnt].han=16;
    ycnt++;
    agari_yaku.chiho=1;
  }else if(tumo==6){
//    strcpy(ydata[ycnt].name,"人和");
    str16cpy(ydata[ycnt].name, renho_str16);
    ydata[ycnt].han=8;
    ycnt++;
    agari_yaku.renho=1;
  }
  if(rinshan==1 || rinshan==3){
//    strcpy(ydata[ycnt].name,"嶺上開花");
    str16cpy(ydata[ycnt].name, rinshan_str16);
    ydata[ycnt].han=1;
    ycnt++;
    agari_yaku.rinshan=1;
    if(rinshan==3){
//    strcpy(ydata[ycnt].name,"海底清摸和");
    str16cpy(ydata[ycnt].name, haiteitumok_str16);
    ydata[ycnt].han=1;
    ycnt++;
    agari_yaku.haitei_tumo=1;
    }
  }else if(rinshan==2 && tumo<=0){
//    strcpy(ydata[ycnt].name,"河底振り込み");
    str16cpy(ydata[ycnt].name, haiteiron_str16);
    ydata[ycnt].han=1;
    ycnt++;
    agari_yaku.haitei_ron=1;
  }else if(rinshan==2 && tumo>0){
//    strcpy(ydata[ycnt].name,"海底清摸和");
    str16cpy(ydata[ycnt].name, haiteitumok_str16);
    ydata[ycnt].han=1;
    ycnt++;
    agari_yaku.haitei_tumo=1;
  }
  //  飜牌
  //  大三元／小三元
  flg=0;
  flg2=0;
  for(i=0;i<19;i++){
    if(pdata[i].group==0)
    flg2=pdata[i].type;
    if(0<=pdata[i].type && pdata[i].type==pdata[i+2].type &&
     pdata[i].group==pdata[i+2].group){
    if(pdata[i].type==52){
//      strcpy(ydata[ycnt].name,"白");
      str16cpy(ydata[ycnt].name, haku_str16);
      ydata[ycnt].han=1;
      ycnt++;
      agari_yaku.fanpai++;
      flg=flg | 0x10;
    }
    if(pdata[i].type==53){
//      strcpy(ydata[ycnt].name,"発");
      str16cpy(ydata[ycnt].name, hatu_str16);
      ydata[ycnt].han=1;
      ycnt++;
      agari_yaku.fanpai++;
      flg=flg | 0x20;
    }
    if(pdata[i].type==54){
//      strcpy(ydata[ycnt].name,"中");
      str16cpy(ydata[ycnt].name, chun_str16);
      ydata[ycnt].han=1;
      ycnt++;
      agari_yaku.fanpai++;
      flg=flg | 0x40;
    }
    i+=2;
    }
  }
  if((flg & 0x70)==0x70){
//    strcpy(ydata[ycnt].name,"大三元");
    str16cpy(ydata[ycnt].name, dai3gen_str16);
    ydata[ycnt].han=16;
    ycnt++;
    agari_yaku.dai3gen=1;
  }else if(((flg & 0x60)==0x60 && flg2==52) ||
       ((flg & 0x50)==0x50 && flg2==53) ||
       ((flg & 0x30)==0x30 && flg2==54)){
//    strcpy(ydata[ycnt].name,"小三元");
    str16cpy(ydata[ycnt].name, sho3gen_str16);
    ydata[ycnt].han=2;
    ycnt++;
    agari_yaku.shou3=1;
  }
  //  風牌
  //  大四喜／小四喜
  flg=0;
  for(i=0;i<19;i++){
    if(pdata[i].group==0){
    if(pdata[i].type==48)
      flg=flg | 0x01;
    if(pdata[i].type==49)
      flg=flg | 0x02;
    if(pdata[i].type==50)
      flg=flg | 0x04;
    if(pdata[i].type==51)
      flg=flg | 0x08;
    }
    if(0<=pdata[i].type && pdata[i].type==pdata[i+2].type &&
     pdata[i].group==pdata[i+2].group){
    if(pdata[i].type==48)
      flg=flg | 0x10;
    if(pdata[i].type==49)
      flg=flg | 0x20;
    if(pdata[i].type==50)
      flg=flg | 0x40;
    if(pdata[i].type==51)
      flg=flg | 0x80;
    if(ba==kaze){
      if(ba==0 && pdata[i].type==48){
//      strcpy(ydata[ycnt].name,"東東");
      str16cpy(ydata[ycnt].name, tonton_str16);
      ydata[ycnt].han=2;
      ycnt++;
      agari_yaku.fanpai+=2;
      }
      if(ba==1 && pdata[i].type==49){
//      strcpy(ydata[ycnt].name,"南南");
      str16cpy(ydata[ycnt].name, nannan_str16);
      ydata[ycnt].han=2;
      ycnt++;
      agari_yaku.fanpai+=2;
      }
      if(ba==2 && pdata[i].type==50){
//      strcpy(ydata[ycnt].name,"西西");
      str16cpy(ydata[ycnt].name, shasha_str16);
      ydata[ycnt].han=2;
      ycnt++;
      agari_yaku.fanpai+=2;
      }
      if(ba==3 && pdata[i].type==51){
//      strcpy(ydata[ycnt].name,"北北");
      str16cpy(ydata[ycnt].name, pepe_str16);
      ydata[ycnt].han=2;
      ycnt++;
      agari_yaku.fanpai+=2;
      }
    }else{
      if((ba==0 || kaze==0) && pdata[i].type==48){
//      strcpy(ydata[ycnt].name,"東");
      str16cpy(ydata[ycnt].name, ton_str16);
      ydata[ycnt].han=1;
      ycnt++;
      agari_yaku.fanpai++;
      }
      if((ba==1 || kaze==1) && pdata[i].type==49){
//      strcpy(ydata[ycnt].name,"南");
      str16cpy(ydata[ycnt].name, nan_str16);
      ydata[ycnt].han=1;
      ycnt++;
      agari_yaku.fanpai++;
      }
      if((ba==2 || kaze==2) && pdata[i].type==50){
//      strcpy(ydata[ycnt].name,"西");
      str16cpy(ydata[ycnt].name, sha_str16);
      ydata[ycnt].han=1;
      ycnt++;
      agari_yaku.fanpai++;
      }
      if((ba==3 || kaze==3) && pdata[i].type==51){
//      strcpy(ydata[ycnt].name,"北");
      str16cpy(ydata[ycnt].name, pe_str16);
      ydata[ycnt].han=1;
      ycnt++;
      agari_yaku.fanpai++;
      }
    }
    i+=2;
    }
  }
  if((flg & 0xF0)==0xF0){
//    strcpy(ydata[ycnt].name,"大四喜");
    str16cpy(ydata[ycnt].name, daisusi_str16);
    ydata[ycnt].han=16;
    ycnt++;
    agari_yaku.daisusi=1;
  }else if(((flg | (flg << 4)) & 0xF0)==0xF0){
//    strcpy(ydata[ycnt].name,"小四喜");
    str16cpy(ydata[ycnt].name, shosusi_str16);
    ydata[ycnt].han=16;
    ycnt++;
    agari_yaku.shosusi=1;
  }
  //  緑一色
  flg=1;
  for(i=0;i<19;i++){
    if(pdata[i].type>=0){
    if((33<=pdata[i].type && pdata[i].type<=35) || pdata[i].type==37 ||
       pdata[i].type==39 || pdata[i].type==53)
      flg=1;
    else{
      flg=0;
      break;
    }
    }
  }
  if(flg==1){
//    strcpy(ydata[ycnt].name,"緑一色");
    str16cpy(ydata[ycnt].name, ryuiso_str16);
    ydata[ycnt].han=16;
    ycnt++;
    agari_yaku.ryuiso=1;
  }
  //  タンヤオ
  flg=1;
  for(i=0;pdata[i].type>=0;i++){
    if((pdata[i].type % 16)==0 || (pdata[i].type % 16)==8 || 48<=pdata[i].type){
      flg=0;
      break;
    }
  }
  if((naki==0 || gm_mode[1]==1) && flg==1){
//    strcpy(ydata[ycnt].name,"断公九");
    str16cpy(ydata[ycnt].name, tanyao_str16);
    ydata[ycnt].han=1;
    ycnt++;
    agari_yaku.tanyao=1;
  }
  //  七対子
  typ1=-1;
  for(i=0;i<7;i++){
    if(pdata[i*2].type!=pdata[i*2+1].type ||
     pdata[i*2].type==typ1){
    break;
    }
    typ1=pdata[i*2].type;
  }
  chitoitu=0;
  if(naki==0 && i==7){
//    strcpy(ydata[ycnt].name,"七対子");
    str16cpy(ydata[ycnt].name, chitoitu_str16);
    ydata[ycnt].han=2;
    ycnt++;
    agari_yaku.chitoitu=1;
    chitoitu=1;
  }
  //  一盃口／二盃口
  flg=0;
  for(i=0;i<19;i++){
    if(0<=pdata[i].type && pdata[i].type==pdata[i+3].type &&
     pdata[i+1].type==pdata[i+4].type && pdata[i+2].type==pdata[i+5].type &&
     (pdata[i].type+2)==pdata[i+2].type && pdata[i].group==pdata[i+2].group){
    flg++;
    i=i+5;
    }
  }
  if(naki==0 && flg==1){
//    strcpy(ydata[ycnt].name,"一盃口");
    str16cpy(ydata[ycnt].name, ipeko_str16);
    ydata[ycnt].han=1;
    ycnt++;
    agari_yaku.ipeko=1;
  }
  if(naki==0 && flg==2){
//    strcpy(ydata[ycnt].name,"二盃口");
    str16cpy(ydata[ycnt].name, ryanpeko_str16);
    ydata[ycnt].han=3;
    ycnt++;
    agari_yaku.ryanpeko=1;
  }
  //  清老頭／字一色／全帯公／純全帯公
  flg=3;
  for(j=0;j<10;j++){
    flg2=4;
    for(i=0;i<19;i++){
    if(0<=pdata[i].type && pdata[i].group==j){
      if(48<=pdata[i].type){
      flg2=2;
      break;
      }else if((pdata[i].type % 16)==0 || (pdata[i].type % 16)==8){
      flg2=3;
      break;
      }else{
      flg2=1;
      }
    }
    }
    if(flg>=flg2)
    flg=flg2;
  }
  flg2=1;
  flg3=2;
  for(i=0;i<19;i++){
    if(0<=pdata[i].type){
    if(flg3>0 && 48<=pdata[i].type){
      flg3=1;
    }else if((pdata[i].type % 16)!=0 && (pdata[i].type % 16)!=8){
      flg2=0;
      flg3=0;
    }else{
      flg2=0;
    }
    }
  }
  if(flg3==2){
//    strcpy(ydata[ycnt].name,"清老頭");
    str16cpy(ydata[ycnt].name, chinroto_str16);
    ydata[ycnt].han=16;
    ycnt++;
    agari_yaku.chinroto=1;
  }else if(flg3==1){
    if(flg2==1){
//    strcpy(ydata[ycnt].name,"字一色");
    str16cpy(ydata[ycnt].name, tuiso_str16);
    ydata[ycnt].han=16;
    ycnt++;
    agari_yaku.tuiso=1;
    }else{
//    strcpy(ydata[ycnt].name,"混老頭");
    str16cpy(ydata[ycnt].name, honroto_str16);
    ydata[ycnt].han=2;
    ycnt++;
    agari_yaku.honroto=1;
    }
  }else if(flg==3){
//    strcpy(ydata[ycnt].name,"純全帯公");
    str16cpy(ydata[ycnt].name, junchan_str16);
    if(naki==0){
    ydata[ycnt].han=3;
    agari_yaku.junchan_m=1;
    }else{
    ydata[ycnt].han=2;
    agari_yaku.junchan=1;
    }
    ycnt++;
  }else if(flg==2){
//    strcpy(ydata[ycnt].name,"全帯公");
    str16cpy(ydata[ycnt].name, chanta_str16);
    if(naki==0){
    ydata[ycnt].han=2;
    agari_yaku.chanta_m=1;
    }else{
    ydata[ycnt].han=1;
    agari_yaku.chanta=1;
    }
    ycnt++;
  }
  //  混一色／清一色／九連宝燈／大車輪
  flg=0;
  typ1=-1;
  for(i=0;i<19;i++){
    if(0<=pdata[i].type){
      if(48<=pdata[i].type){
        flg=3;
      }else if(typ1<0 || (pdata[i].type/16)==typ1){
        if(flg<3)
          flg=2;
        typ1=pdata[i].type/16;
      }else{
        flg=0;
        break;
      }
    }
  }
  if(flg==2){
//    strcpy(ydata[ycnt].name,"清一色");
    str16cpy(ydata[ycnt].name, chinitu_str16);
    if(naki==0){
    ydata[ycnt].han=6;
    agari_yaku.chinitu_m=1;
    flg2=0;
    flg3=0;
    xo0=0;
    xo1=0;
    for(i=0;i<19;i++){
      if(0<=pdata[i].type){
      flg2=flg2 | (1 << (pdata[i].type % 16));
      if(16<=pdata[i].type && pdata[i].type<32)
        flg3=flg3+(1 << ((pdata[i].type % 16)*2));
      if((pdata[i].type % 16)==0)
        xo0++;
      if((pdata[i].type % 16)==8)
        xo1++;
      }
    }
    if(flg2==0x1FF && xo0>=3 && xo1>=3){
      ycnt++;
//      strcpy(ydata[ycnt].name,"九連宝燈");
    str16cpy(ydata[ycnt].name, churenpoto_str16);
      ydata[ycnt].han=16;
      agari_yaku.churenpoto=1;
    }
    if(flg3>0 && (flg3 % 0x2AAA)==0){
      ycnt++;
//      strcpy(ydata[ycnt].name,"大車輪");
    str16cpy(ydata[ycnt].name, daisharin_str16);
      ydata[ycnt].han=16;
      agari_yaku.daisharin=1;
    }
    }else{
    ydata[ycnt].han=5;
    agari_yaku.chinitu=1;
    }
    ycnt++;
  }
  if(flg==3){
//    strcpy(ydata[ycnt].name,"混一色");
    str16cpy(ydata[ycnt].name, honitu_str16);
    if(naki==0){
    ydata[ycnt].han=3;
    agari_yaku.honitu_m=1;
    }else{
    ydata[ycnt].han=2;
    agari_yaku.honitu=1;
    }
    ycnt++;
  }
  //  三色同順／一気通貫
  flg=0;
  flg2=0;
  flg3=0;
  xo0=0;
  xo1=0;
  xo2=0;
  for(i=0;i<19;i++){
    if(0<=pdata[i].type && (pdata[i].type+2)==pdata[i+2].type){
    typ1=pdata[i].type/16;
    if(typ1==0)
      xo0=xo0 | (1 << (int)(pdata[i].type % 16));
    else if(typ1==1)
      xo1=xo1 | (1 << (int)(pdata[i].type % 16));
    else if(typ1==2)
      xo2=xo2 | (1 << (int)(pdata[i].type % 16));
    for(j=i;j<i+3;j++){
      typ1=pdata[j].type/16;
      if(typ1==0)
      flg=flg | (1 << (int)(pdata[j].type % 16));
      else if(typ1==1)
      flg2=flg2 | (1 << (int)(pdata[j].type % 16));
      else if(typ1==2)
      flg3=flg3 | (1 << (int)(pdata[j].type % 16));
    }
    i+=2;
    }
  }
  if((flg==0x1ff && (xo0 & 0x49)==0x49) ||
     (flg2==0x1ff && (xo1 & 0x49)==0x49) ||
     (flg3==0x1ff && (xo2 & 0x49)==0x49)){
//    strcpy(ydata[ycnt].name,"一気通貫");
    str16cpy(ydata[ycnt].name, ittu_str16);
    if(naki==0){
    ydata[ycnt].han=2;
    agari_yaku.itu_m=1;
    }else{
    ydata[ycnt].han=1;
    agari_yaku.itu=1;
    }
    ycnt++;
  }
  if(((flg & flg2 & flg3)/7)>0 && ((flg & flg2 & flg3) % 7)==0 &&
     (xo0 & xo1 & xo2)!=0){
//    strcpy(ydata[ycnt].name,"三色同順");
    str16cpy(ydata[ycnt].name, sanshokudoujyun_str16);
    if(naki==0){
    ydata[ycnt].han=2;
    agari_yaku.shoku3_m=1;
    }else{
    ydata[ycnt].han=1;
    agari_yaku.shoku3=1;
    }
    ycnt++;
  }
  //  平和
  flg=0;
  for(i=0;i<19;i++){
    //  三元牌が頭、場風や自風が頭
    if(pdata[i].group==0 &&
     (pdata[i].type>=52 || pdata[i].type==(48+ba) || pdata[i].type==(48+kaze))){
    flg=-1;
    }
    //    頭をつもった
    if(pdata[i].group==0 && pdata[i].naki==1){
    flg=-1;
    }
    if(0<=pdata[i].type && pdata[i].group==pdata[i+2].group &&
     (pdata[i].type+2)==pdata[i+2].type){
    if(pdata[i+1].naki==1 ||
       (pdata[i].naki==1 && (pdata[i].type % 16)==6) ||
       (pdata[i+2].naki==1 && (pdata[i].type % 16)==0)){
      flg=-1;
    }else{
      flg++;
    }
    i+=2;
    }
  }
  if(naki==0 && flg==4){
//    strcpy(ydata[ycnt].name,"平和");
    str16cpy(ydata[ycnt].name, pinfu_str16);
    ydata[ycnt].han=1;
    ycnt++;
    agari_yaku.pinfu=1;
    pinf=1;
  }
  //  四暗刻、三暗刻、対々和
  flg=0;
  flg2=0;
  flg3=0;
  flg4=0;
  for(i=0;i<19;i++){
    if(0<=pdata[i].type && pdata[i].type==pdata[i+2].type &&
     pdata[i].group==pdata[i+2].group){
    flg++;
    if(pdata[i].naki==0 || pdata[i].naki==2 || (tumo>=1 && tumo<5 && pdata[i].naki==1))
      flg2++;
    if(pdata[i].type<48)
      flg3=flg3 + (1 << ((pdata[i].type % 16)*2));
    else
      flg3=flg3 + (1 << ((pdata[i].type-48+9)*2));
    if(pdata[i].naki==2 || pdata[i].naki==5)
      flg4++;
    i+=2;
    }
  }
  if(flg4==4){
//    strcpy(ydata[ycnt].name,"四槓子");
    str16cpy(ydata[ycnt].name, sukantu_str16);
    ydata[ycnt].han=16;
    ycnt++;
    agari_yaku.kantu4=1;
  }
  if(naki==0 && flg2==4){
//    strcpy(ydata[ycnt].name,"四暗刻");
    str16cpy(ydata[ycnt].name, suanko_str16);
    ydata[ycnt].han=16;
    ycnt++;
    agari_yaku.anko4=1;
  }
  if(flg4==3){
//    strcpy(ydata[ycnt].name,"三槓子");
    str16cpy(ydata[ycnt].name, sankantu_str16);
    ydata[ycnt].han=2;
    ycnt++;
    agari_yaku.kantu3=1;
  }else if(flg2==3){
//    strcpy(ydata[ycnt].name,"三暗刻");
    str16cpy(ydata[ycnt].name, sananko_str16);
    ydata[ycnt].han=2;
    ycnt++;
    agari_yaku.anko3=1;
  }
  if(flg==4){
//    strcpy(ydata[ycnt].name,"対々和");
    str16cpy(ydata[ycnt].name, toitoi_str16);
    ydata[ycnt].han=2;
    ycnt++;
    agari_yaku.toitoi=1;
  }
  j=0;
  for(i=0;i<16;i++)
    if((flg3 & (3 << (i*2)))==(3 << (i*2)))
    j++;
  if(j==1){
//    strcpy(ydata[ycnt].name,"三色同刻");
    str16cpy(ydata[ycnt].name, sanshokudoukou_str16);
    ydata[ycnt].han=2;
    ycnt++;
    agari_yaku.doko3=1;
  }
  //  ２飜しばり
  hcnt=0;
  for(i=0;i<ycnt;i++){
    hcnt=hcnt+ydata[i].han;
  }
  if(hon_ba>=5 && gm_mode[5]==1 && hcnt<2){
    ycnt=0;
  }
  //  ドラ
  flg=0;
  for(i=0;i<19;i++){
    if(pdata[i].type<0)
    continue;
    for(j=0;dorap[j].type>=0;j++){
    if(pdata[i].type==(dorap[j].type+1) && pdata[i].type!=52)
      flg++;
    if((dorap[j].type % 16)==8 && pdata[i].type==(dorap[j].type-8))
      flg++;
    if(dorap[j].type==51 && pdata[i].type==48)
      flg++;
    if(dorap[j].type==54 && pdata[i].type==52)
      flg++;
    }
  }
  if(ycnt>0 && flg>0){
//    strcpy(ydata[ycnt].name,"ドラ");
    str16cpy(ydata[ycnt].name, dora_str16);
    ydata[ycnt].han=flg;
    ycnt++;
    agari_yaku.dora=flg;
  }
  //  人和と役満の場合、他の役を削除する 
  flg=0;
  for(i=0;i<ycnt;i++){
    if(ydata[i].han>=8 && ydata[i].name[0]!=0x2549)
    flg=1;
  }
  if(flg==1){
    j=0;
    for(i=0;i<ycnt;i++){
    if(ydata[i].han>=8 && ydata[i].name[0]!=0x2549){
      str16cpy(ydata[j].name, ydata[i].name);
      ydata[j].han=ydata[i].han;
      j++;
    }
    }
    ycnt=j;
    yaku_clear(1);
  }
  hcnt=0;
  for(i=0;i<ycnt;i++){
    hcnt=hcnt+ydata[i].han;
  }
  *han=hcnt;
  agari_yaku.fan=hcnt;
  //  上がり点
  if(tumo>=1){      //  ツモ
    if(pinf==1 || rinshan==1 || rinshan==3)
    tcnt=20;
    else
    tcnt=22;
  }else if(naki==0) //  門前ロン
    tcnt=30;
  else        //  さらしロン
    tcnt=20;
  for(i=0;i<16;i++){
    flg=0;
    flg2=-1;
    flg3=-1;
    for(j=0;j<19;j++){
    if(pdata[j].group==i){
      if(flg2<0){
      if(pdata[j+2].group==i && pdata[j+2].type==(pdata[j].type+2) && pdata[j].type<48){
        if((pdata[j].naki==1 && (pdata[j].type % 16)==6) ||
         pdata[j+1].naki==1 ||
         (pdata[j+2].naki==1 && (pdata[j+2].type % 16)==2)){
        flg=99;
        }else
        flg++;
        j+=2;
        flg2=pdata[j].type;
      }else{
        flg++;
        flg2=pdata[j].type;
        flg3=pdata[j].naki;
      }
      }else if(pdata[j].type==flg2)
      flg++;
    }
    }
    //  単騎待ち
    if(flg>=99 || (flg==2 && flg3==1))
    tcnt+=2;
    //  頭の点
    if(flg==2){
    if(flg2>=52)
      tcnt+=2;
    if(flg2==48+ba)
      tcnt+=2;
    if(flg2==48+kaze)
      tcnt+=2;
    }
    //  コーツの点
    if(flg==3){
    if(flg2>=48 || (flg2 % 16)==0 || (flg2 % 16)==8){
      if(flg3<3)
      tcnt+=8;
      else
      tcnt+=4;
    }else{
      if(flg3<3)
      tcnt+=4;
      else
      tcnt+=2;
    }
    }
    //  カンツの点
    if(flg==4){
    if(flg2>=48 || (flg2 % 16)==0 || (flg2 % 16)==8){
      if(flg3<3)
      tcnt+=32;
      else
      tcnt+=16;
    }else{
      if(flg3<3)
      tcnt+=16;
      else
      tcnt+=8;
    }
    }
  }
  if(chitoitu==1)
    tcnt=25;
  *ten=tcnt;
  hcnt=hcnt+2;
  if(hcnt>=32)
    pcnt=64000;
  else if(hcnt>=16)
    pcnt=32000;
  else if(hcnt>=13)
    pcnt=24000;
  else if(hcnt>=10)
    pcnt=16000;
  else if(hcnt>=8)
    pcnt=12000;
  else if(hcnt>=7)
    pcnt=8000;
  else if((hcnt==6 && tcnt>30) || (hcnt==5 && tcnt>60))
    pcnt=8000;
  else{
    if(chitoitu==1)
    tcnt=25;
    else
    tcnt=((tcnt+9)/10)*10;
    pcnt=(1 << hcnt)*tcnt*4;
    pcnt=((pcnt+99)/100)*100;
  }
  if(hcnt<=2){      //  ちょんぼ
//    strcpy(ydata[ycnt].name,"ちょんぼ");
    str16cpy(ydata[ycnt].name, chonbo_str16);
    ydata[ycnt].han=0;
    ycnt++;
    pcnt=-8000;
    yaku_clear(0);
  }
  ydata[ycnt].han=-1; //  データの最後を示す
  return(pcnt);
}

void yaku_clear(int n)
{
  if(n==0 || n==1){
    agari_yaku.fan=0;
    agari_yaku.richi=0;
    agari_yaku.dbl_richi=0;
    agari_yaku.ipatu=0;
    agari_yaku.dora=0;
    agari_yaku.tumo=0;
    agari_yaku.haitei_tumo=0;
    agari_yaku.haitei_ron=0;
    agari_yaku.rinshan=0;
    agari_yaku.chankan=0;
    agari_yaku.pinfu=0;
    agari_yaku.ipeko=0;
    agari_yaku.tanyao=0;
    agari_yaku.fanpai=0;
    agari_yaku.doko3=0;
    agari_yaku.anko3=0;
    agari_yaku.kantu3=0;
    agari_yaku.shou3=0;
    agari_yaku.honroto=0;
    agari_yaku.chitoitu=0;
    agari_yaku.chanta_m=0;
    agari_yaku.chanta=0;
    agari_yaku.itu_m=0;
    agari_yaku.itu=0;
    agari_yaku.shoku3_m=0;
    agari_yaku.shoku3=0;
    agari_yaku.toitoi=0;
    agari_yaku.junchan_m=0;
    agari_yaku.junchan=0;
    agari_yaku.ryanpeko=0;
    agari_yaku.honitu_m=0;
    agari_yaku.honitu=0;
    agari_yaku.chinitu_m=0;
    agari_yaku.chinitu=0;
    agari_yaku.nagasi=0;
  }
  if(n==0){
    agari_yaku.renho=0;
    agari_yaku.tenho=0;
    agari_yaku.chiho=0;
    agari_yaku.chinroto=0;
    agari_yaku.kantu4=0;
    agari_yaku.ryuiso=0;
    agari_yaku.dai3gen=0;
    agari_yaku.tuiso=0;
    agari_yaku.shosusi=0;
    agari_yaku.daisusi=0;
    agari_yaku.anko4=0;
    agari_yaku.kokusimuso=0;
    agari_yaku.churenpoto=0;
    agari_yaku.puto13=0;
    agari_yaku.daisharin=0;
  }
  return;
}

void do_sute(int plyer, int n)
{
  int x;
  for(x=0;sute[plyer][x].type>=0;x++);
  latest_sute.type=pai[plyer][n].type;
  latest_sute.group=x;
  latest_sute.who=plyer;
  sute[plyer][x].type=pai[plyer][n].type;
  sute[plyer][x].naki=0;
  sute[plyer][x+1].type=-1;
  latest_pointer=&sute[plyer][x];
  pai[plyer][n].type=-1;
  pai[plyer][n].naki=0;
  pai[plyer][n].group=-1;
  sort_pai(pai[plyer]);
}
void do_pon(struct h_pai getpai, int ply, int sute_ply)
{
  int i,j,k;
  int who;
  
  tone(SoundPin, NOTE_G5, 50);
  delay(50);
  tone(SoundPin, NOTE_G4, 50);
  delay(50);
  tone(SoundPin, NOTE_G5, 50);
  delay(50);
  tone(SoundPin, NOTE_G4, 50);
  delay(50);
  tone(SoundPin, NOTE_G5, 50);
  delay(50);
  tone(SoundPin, NOTE_G4, 50);

  can_dblrichi=0;
  for(i=0;i<4;i++)
    richi_cnt[i]=0;

  who=sute_ply-ply;
  if(who<0)
    who=who+4;
  if(who>=4)
    who=who-4;
  j=0;
  for(i=0;pai[ply][i].type>=0;i++){
    if(pai[ply][i].group>j)
      j=pai[ply][i].group;
  }
  j++;
  k=2;
  for(i=0;pai[ply][i].type>=0;i++){
    if(pai[ply][i].naki==0 && pai[ply][i].type==getpai.type && k>0){
      pai[ply][i].group=j;
      pai[ply][i].naki=4;
      pai[ply][i].who=who-1;
      k--;
    }
  }
  pai[ply][i].type=getpai.type;
  pai[ply][i].group=j;
  pai[ply][i].naki=4;
  pai[ply][i].who=who-1;
  latest_pointer->naki=1;
  sort_pai(pai[ply]);
  return;
}

void do_kan(struct h_pai getpai,int ply,int sute_ply)
{
  int i,j,k,kno;
  int who;
  int ankan;
  int g, grp;
  char  kan_pai[4];

  tone(SoundPin, NOTE_G5, 50);
  delay(50);
  tone(SoundPin, NOTE_G4, 50);
  delay(50);
  tone(SoundPin, NOTE_G5, 50);
  delay(50);
  tone(SoundPin, NOTE_G4, 50);
  delay(50);
  tone(SoundPin, NOTE_G5, 50);
  delay(50);
  tone(SoundPin, NOTE_G4, 50);
  delay(50);
  tone(SoundPin, NOTE_G5, 50);
  delay(50);
  tone(SoundPin, NOTE_G4, 50);

  grp=0;
  kno=0;
  for(i=0;pai[ply][i].type>=0;i++){
    if(pai[ply][i].group>grp)
      grp=pai[ply][i].group;
  }
  grp++;
  who=sute_ply-ply;
  if(who<0)
    who=who+4;
  if(who>=4)
    who=who-4;
  if(who!=0)
    latest_pointer->naki=1;
  //  捨て牌
  if(who!=0){
    for(i=0;pai[ply][i].type>=0;i++);
    pai[ply][i].type=getpai.type;
    pai[ply][i].naki=0;
    pai[ply][i].group=-1;
    pai[ply][i].who=0;
    kan_pai[0]=getpai.type;
    kno=1;
    ankan=5;  //  ミンカン
  //  ツモ牌
  }else{
    //  カンできる牌を探す
    if(kan_no>=0){ // カン牌指定
      k=0;
      kan_no=kan_no % 100;
      g=grp;
      for(i=0;pai[ply][i].type>=0;i++){
        if(pai[ply][i].type==kan_no){
          k++;
          if(pai[ply][i].naki==4)
            g=pai[ply][i].group;
        }
      }
      if(k==4){
        kno=1;
        grp=g;
        kan_pai[0]=kan_no;
      }else{
        kno=0;
      }
    }
    if (kan_no<0 || kno==0){ // 指定なし
      kno=0;
      for(i=0;pai[ply][i].type>=0;i++){
        kan_pai[kno]=pai[ply][i].type;
        k=0;
        g=grp;
        for(j=i;pai[ply][j].type>=0;j++){
          if((pai[ply][j].naki<=1 || pai[ply][j].naki==4) && pai[ply][j].type==kan_pai[kno]){
            k++;
            if(pai[ply][j].naki==4)
              g=pai[ply][j].group;
          }
        }
        if(k==4){
          kno++;
          grp=g;
        }
      }
    }
    ankan=2;  //  アンカン
    for(i=0;pai[ply][i].type>=0;i++){
      if(pai[ply][i].type==kan_pai[0]){
        if(pai[ply][i].naki==4){// ポン以外でツモ牌をカンできない
          ankan=5;      //  ミンカン
          who=pai[ply][i].who+1;
          break;
        }
      }
    }
  }
  k=4;
  for(i=0;pai[ply][i].type>=0;i++){
    if(pai[ply][i].type==kan_pai[0]){
      pai[ply][i].group=grp;
      pai[ply][i].naki=ankan;
      pai[ply][i].who=who-1;
      k--;
    }
  }
  if(k>0){
    pai[ply][i].type=kan_pai[0];
    pai[ply][i].group=grp;
    pai[ply][i].naki=ankan;
    pai[ply][i].who=who-1;
  }
  kan_count++;
  if (ankan==5){
    can_dblrichi=0;
    for(i=0;i<4;i++)
      richi_cnt[i]=0;
  }
  sort_pai(pai[ply]);
  rinshankaiho=1;
  kan_no=-1;
  return;
}

void do_chi(struct h_pai getpai,int ply,int sute_ply)
{
  int i,j,k;
  int who;

  tone(SoundPin, NOTE_G5, 50);
  delay(50);
  tone(SoundPin, NOTE_G4, 50);

  can_dblrichi=0;
  for(i=0;i<4;i++)
    richi_cnt[i]=0;

  who=sute_ply-ply;
  if(who<0)
    who=who+4;
  if(who>=4)
    who=who-4;
  j=0;
  k=0;
  for(i=0;pai[ply][i].type>=0;i++){
    if(pai[ply][i].group>j)
      j=pai[ply][i].group;
    if(pai[ply][i].naki==0 && pai[ply][i].type==getpai.type-2)
      k=k | 1;
    if(pai[ply][i].naki==0 && pai[ply][i].type==getpai.type-1)
      k=k | 2;
    if(pai[ply][i].naki==0 && pai[ply][i].type==getpai.type+1)
      k=k | 4;
    if(pai[ply][i].naki==0 && pai[ply][i].type==getpai.type+2)
      k=k | 8;
  }
  j++;
  if (k==0x3 || k==0xb){
    chi_no[0]=getpai.type-2;
    chi_no[1]=getpai.type-1;
    chi_no[2]=getpai.type;
    k=0x3;
  }else if (k==0x6){
    chi_no[0]=getpai.type-1;
    chi_no[1]=getpai.type;
    chi_no[2]=getpai.type+1;
    k=0x6;
  }else if (k==0xc || k==0xd){
    chi_no[0]=getpai.type;
    chi_no[1]=getpai.type+1;
    chi_no[2]=getpai.type+2;
    k=0xc;
  }else if ((chi_no[0]>=0 && chi_no[0]-getpai.type==-2) ||
            (chi_no[1]>=0 && chi_no[1]-getpai.type==-2)){
    chi_no[0]=getpai.type-2;
    chi_no[1]=getpai.type-1;
    chi_no[2]=getpai.type;
    k=0x3;
  }else if ((chi_no[0]>=0 && chi_no[0]-getpai.type==2) ||
            (chi_no[1]>=0 && chi_no[1]-getpai.type==2)){
    chi_no[0]=getpai.type;
    chi_no[1]=getpai.type+1;
    chi_no[2]=getpai.type+2;
    k=0xc;
  }else{
    chi_no[0]=getpai.type-1;
    chi_no[1]=getpai.type;
    chi_no[2]=getpai.type+1;
    k=0x6;
  }

  who=0;
  if(k==0x3){
    who=who | 1;
  }
  if(k==0x6){
    who=who | 2;
  }
  if(k==0xc){
    who=who | 4;
  }

  for(i=0;pai[ply][i].type>=0;i++);
  pai[ply][i].type=getpai.type;
  pai[ply][i].group=-1;
  pai[ply][i].naki=0;
  pai[ply][i].who=0;

  for(i=0;pai[ply][i].type>=0;i++){
    if(pai[ply][i].naki==0 && pai[ply][i].type==chi_no[0]){
      pai[ply][i].group=j;
      pai[ply][i].naki=3;
      pai[ply][i].who=who;
      chi_no[0]=-1;
    }else if(pai[ply][i].naki==0 && pai[ply][i].type==chi_no[1]){
      pai[ply][i].group=j;
      pai[ply][i].naki=3;
      pai[ply][i].who=who;
      chi_no[1]=-1;
    }else if(pai[ply][i].naki==0 && pai[ply][i].type==chi_no[2]){
      pai[ply][i].group=j;
      pai[ply][i].naki=3;
      pai[ply][i].who=who;
      chi_no[2]=-1;
    }
  }
  latest_pointer->naki=1;
  sort_pai(pai[ply]);
  chi_no[0]=-1;
  return;
}
int can_richi(int ply)
{
  int i;
  if (richi[ply]>0)
    return(0);
  for(i=0;pai[ply][i].type>=0;i++){
    if (pai[ply][i].naki>=3)
      return(0);
  }
  return(1);
}
int can_chi(int ply, struct h_pai sutep)
{
  int i;
  int cnt;
  
  cnt=0;
  for(i=0;pai[ply][i].type>=0;i++){
    if (0<=sutep.type && sutep.type<48 && pai[ply][i].group<0){
      if(pai[ply][i].type==sutep.type-2)
        cnt=cnt | 1;
      if(pai[ply][i].type==sutep.type-1)
        cnt=cnt | 2;
      if(pai[ply][i].type==sutep.type+1)
        cnt=cnt | 4;
      if(pai[ply][i].type==sutep.type+2)
        cnt=cnt | 8;
    }
  }
  if ((cnt & 3)==3 || (cnt & 6)==6 || (cnt & 12)==12)
    return(1);
  return(0);
}
int can_pon(int ply, struct h_pai sutep)
{
  int i;
  int cnt;
  
  cnt=0;
  for(i=0;pai[ply][i].type>=0;i++){
    if (pai[ply][i].naki==0 && pai[ply][i].type==sutep.type)
      cnt++;
  }
  if (cnt>=2)
    return(1);
  return(0);
}

int can_kan(int ply, struct h_pai sutep)
{
  int alrdy;
  int i, j;
  int cnt;

  if (kan_count>=4)
    return(0);
  alrdy=0;
  for(i=0;pai[ply][i].type>=0;i++){
    if(pai[ply][i].naki==2 || pai[ply][i].naki==5){
      alrdy++;
      i+=3;
    }
  }
  if (kan_count==3 && alrdy<3)
    return(0);
  cnt=0;
  for(i=0;pai[ply][i].type>=0;i++){
    if (pai[ply][i].naki==0 && pai[ply][i].type==sutep.type)
      cnt++;
  }
  if (cnt>=3)
    return(1);
  if (ply!=ban/6)
    return(0);

  for(i=0;pai[ply][i].type>=0;i++){
    cnt=0;
    for(j=i+1;pai[ply][j].type>=0;j++){
      if ((pai[ply][j].naki<=1 || pai[ply][j].naki==4) &&
          pai[ply][j].type==pai[ply][i].type)
        cnt++;
    }
    if (cnt>=3)
      return(1);
  }
  return(0);
}
int can_ron(int ply, struct h_pai sutep)
{
  int i;
  struct h_pai tmp;
  struct h_pai tmppai[19];

  copy_pai(tmppai, pai[ply]);
  for(i=0;tmppai[i].type>=0;i++);
  tmppai[i].type=sutep.type;
  tmppai[i].naki=0;
  tmppai[i+1].type=-1;

  tmp.type=sutep.type;
  i=bunkatu(tmppai, &tmp);
  return(i);
}
int can_tumo(int ply)
{
  int i;
  struct h_pai tmp;
  struct h_pai tmppai[19];

  copy_pai(tmppai, pai[ply]);
  tmp.type=-1;
  i=bunkatu(tmppai, &tmp);
  return(i);
}

int can_agari(int who, struct h_pai agarip, int ron)
{
  int i;
  int rc, rin;
  int ppoint,ten_point,han_point;
  struct h_pai tmp;
  struct h_pai tmppai[19];

  copy_pai(calc_pai, pai[who]);
  for(i=0;calc_pai[i].type>=0;i++);
  if (ron==1){
    calc_pai[i].type=agarip.type;
    calc_pai[i].naki=1;
    calc_pai[i+1].type=-1;
  }

  //  フリテンのチェック
  copy_pai(tmppai, calc_pai);
  if (ron>=1){
    for(i=0;tmppai[i].type>=0;i++)
      if(tmppai[i].naki==1)
        tmppai[i].naki=0;
    for(i=0;tmppai[i].type>=0;i++){
      if(tmppai[i].type==agarip.type && tmppai[i].naki<=1){
        tmppai[i].naki=1;
        break;
      }
    }
    if(furiten(tmppai,sute[who])==1){
      ycount=-1;
      return(-1);
    }
  }

  // Dora
  if (richi[who]>0 && gm_mode[3]==1){
    if (gm_mode[4]==1){
      for(i=0;i<(kan_count+1)*2;i++){
        dora[i].type=yama[128+i];
      }
    }else{
      for(i=0;i<kan_count+2;i++){
        dora[i].type=yama[128+i];
      }
    }
    do{
      dora[i++].type=-1;
    }while(i<8);
  }else{
    for(i=0;i<(kan_count+1);i++){
      dora[i].type=yama[128+i];
    }
    do{
      dora[i++].type=-1;
    }while(i<8);
  }

  copy_pai(tmppai, calc_pai);
  tmp.type=agarip.type;
  i=bunkatu(tmppai, &tmp);
  if(i<=0){
    ten_max=0;
    han_max=0;
    point_max=0;
    return(0);
  }

  yaku_max=0;
  ten_max=0;
  han_max=0;
  point_max=0;
  if (richi_cnt[who]>0)
    rc=richi[who]+1;
  else
    rc=richi[who];
  rin=rinshankaiho+haitei*2;
  for(i=0;i<ycount;i++){
    if(ron>=1){
      ppoint=tensu_cal(yaku[i],dora,yakutxt[i],&han_point,&ten_point,
             rc,rin,0,kyoku/4,(4+who-oya_position) % 4);
    }else{
      ppoint=tensu_cal(yaku[i],dora,yakutxt[i],&han_point,&ten_point,
             rc,rin,1,kyoku/4,(4+who-oya_position) % 4);
    }
    if(ppoint>point_max){
      yaku_max=i;
      point_max=ppoint;
      ten_max=ten_point;
      han_max=han_point;
    }
  }
  return(han_max);
}

int chk_tenpai(struct h_pai *pdata)
{
  struct h_pai apai[16];
  struct h_pai tmp[19];
  int i,j,acount;
  j=0;
  for(i=0;pdata[i].type>=0;i++){
    if(pdata[i].naki!=1){
      tmp[j].type=pdata[i].type;
      tmp[j].naki=pdata[i].naki;
      tmp[j].group=pdata[i].group;
      tmp[j].who=pdata[i].who;
      j++;
    }
  }
  for(i=j;i<19;i++){
    tmp[i].type=-1;
    tmp[i].naki=0;
    tmp[i].group=-1;
    tmp[i].who=0;
  }
  acount=agari_pai(tmp,apai);
  return(acount);
}

int thinking(int ply,struct h_pai *hdata,struct h_pai *sdata,struct h_pai *sutep)
{
  int i,j,k;
  int snum,smin,tmp;
  int honitu[3],hontype,honitup,chantap;
  int menzen, tenpai_chk;
  int score[19];
  struct h_pai agarip;
  struct h_pai tmp_pai[19];
  struct h_pai tmp_agari[16];

  ply=ply % 4;
  for(i=0;hdata[i].type>=0;i++);
  agarip.type=hdata[i-1].type;
  //  上がり
  if(can_agari(ply,agarip,0)>0){
    agari=ply;
    return(10);
  }
  //  カンする?
  if((ply_think[ply].think & 0x00f0)>0){
  for(i=0;hdata[i].type>=0;i++){
    if(hdata[i].naki==0 || hdata[i].naki==4){
    snum=0;
    smin=0;
    for(j=i;hdata[j].type>=0;j++){
      if(hdata[j].naki==0 || hdata[j].naki==4){
      if(hdata[i].type==hdata[j].type){
        snum++;
        if(smin<hdata[j].naki)
        smin=hdata[j].naki;
      }
      }
    }
    if(snum==4 && can_kan(ply, latest_tumo)==1 && ((ply_think[ply].think & 0x00f0)>=0x30 || smin==4)){
      do_kan(hdata[i],ply,ply);
      get_1pai(ply);
      //  上がり
      if(can_agari(ply,agarip,0)>0){
      agari=ply;
      return(10);
      }
      break;
    }
    }
  }
  }
  //  既にリーチしている？
  if(richi[ply]>0){
    //  一発解除
    if(richi[ply]==2 || richi[ply]==4)
    richi[ply]--;
    j=0;
    for(i=0;hdata[i].type>=0;i++){
    if(hdata[i].naki<=1)
      j=i;
    score[i]=10000;
    }
    score[j]=1;
    goto sute_shori;
  }
  //  テンパイ？
  sort_pai(hdata);
  menzen=1;
  tenpai_chk=0;
  for(i=0;hdata[i].type>=0;i++){
    if(hdata[i].naki>=3)
    menzen=0;
    if(hdata[i].naki>0)
    score[i]=10000;
    else{
    copy_pai(tmp_pai,hdata);
    tmp_pai[i].type=-1;
    tmp_pai[i].group=-1;
    score[i]=100-agari_pai(tmp_pai,tmp_agari);
    if(score[i]<100)
      tenpai_chk=1;
    }
  }
  ply_think[ply].tenpai=tenpai_chk;
  if(tenpai_chk==1){
    if((ply_think[ply].think & 0x000f)>0){
    //  リーチする？
    if(menzen==1 && richi[ply]==0 && yama_count<(136-14-4)){
      richi[ply]=can_dblrichi*2+1;
      for(j=0;sdata[j].type>=0;j++);
      richi_no[ply]=j;
      richi_bo_now++;
      points[ply]-=1000;
      richi_cnt[ply]=5;
      tone(SoundPin, NOTE_C5, 50);
      delay(50);
      tone(SoundPin, NOTE_E5, 50);
      delay(50);
      tone(SoundPin, NOTE_G5, 50);
    }
    }
  //  捨て牌の決定
  }else{
    //  ねらいを決める
    honitu[0]=0;
    honitu[1]=0;
    honitu[2]=0;
    chantap=0;
    for(i=0;hdata[i].type>=0;i++){
    if(hdata[i].type>=48){
      honitu[0]++;
      honitu[1]++;
      honitu[2]++;
      chantap++;
    }else{
      honitu[(hdata[i].type)/16]++;
      if((hdata[i].type % 16)<=2 || 6<=(hdata[i].type % 16))
      chantap++;
    }
    }
    honitup=0;
    for(i=0;i<3;i++){
    if(honitu[i]>honitup){
      honitup=honitu[i];
      hontype=i;
    }
    }
    if((ply_think[ply].think & 0x0f00)==0)
    honitup=0;
    if((ply_think[ply].think & 0x0f00)==0x0100 && honitup<10)
    honitup=0;
    if((ply_think[ply].think & 0x0f00)==0x0200 && honitup<8)
    honitup=0;
    if((ply_think[ply].think & 0xf000)==0)
    chantap=0;
    if((ply_think[ply].think & 0xf000)==0x1000 && chantap<12)
    chantap=0;
    if((ply_think[ply].think & 0xf000)==0x2000 && chantap<10)
    chantap=0;
    if(honitup>0)
    ply_think[ply].honitu=1+hontype;
    else
    ply_think[ply].honitu=0;
    if(chantap>0)
    ply_think[ply].chanta=1;
    else
    ply_think[ply].chanta=0;
    //  各牌のポイント計算
    for(i=0;hdata[i].type>=0;i++){
    //  鳴いている牌は捨てない
    if(hdata[i].naki>0)
      score[i]=10000;
    //  白発中の扱い
    else if(hdata[i].type>=52){
      if(honitup>0 || chantap>0)
      score[i]=30;
      else
      score[i]=10;
    //  東南西北の扱い
    }else if(hdata[i].type>=48){
      if(honitup>0 || chantap>0)
      score[i]=20;
      else
      score[i]=0;
      if(hdata[i].type==(kyoku/4+48) || hdata[i].type==((4+ply-oya_position) % 4+48))
      score[i]+=7;
    //  一九牌の扱い
    }else if((hdata[i].type % 16)==0 || (hdata[i].type % 16)==8){
      if(chantap>0)
      score[i]=20;
      else
      score[i]=0;
    }else
      score[i]=7;
    //  混一色牌の扱い
    if(honitup>0 && (hdata[i].type/16)==hontype)
      score[i]+=50;
    //  ドラ牌の扱い
    for(j=0;dora[j].type>=0;j++){
      tmp=dora[j].type+1;
      if(tmp<48 && (tmp % 16)==9)
      tmp=tmp-9;
      else if(tmp==52)
      tmp=48;
      else if(tmp==55)
      tmp=52;
      if(hdata[i].type==tmp)
      score[i]+=5;
    }
    }
    //  複数持っている牌や連続牌の扱い
    for(j=0;hdata[j].type>=0;j++){
    score[i]=score[i]+100+rand() % 10;
    tmp=th_same(hdata,hdata[j].type);
    if(tmp==3)
      score[j]+=80;
    if(tmp==2)
      score[j]+=50;
    score[j]=score[j]+th_near(hdata,hdata[j].type);
    }
    //  リーチした人の捨て牌チェック
    for(i=0;i<3 && (ply_think[ply].think & 0xf0000)>0;i++){
    if(richi[i]>0){
      for(j=0;hdata[j].type>=0;j++){
      //  捨て牌の扱い
      for(k=0;sute[i][k].type>=0;k++){
        if(hdata[j].type==sute[i][k].type){
        if(richi[i]==2 || richi[i]==4 || (ply_think[ply].think & 0xf0000)==0x20000)
          score[j]-=20;
        else
          score[j]-=10;
        break;
        }else if(abs(hdata[j].type-sute[i][k].type)==3){
        score[j]-=5;
        break;
        }
      }
      //  字牌の扱い
      if(hdata[j].type>=48)
        score[j]-=5;
      //  ドラ牌の扱い
      for(k=0;dora[k].type>=0;k++){
        tmp=dora[k].type+1;
        if(tmp<48 && (tmp % 16)==9)
        tmp=tmp-9;
        else if(tmp==52)
        tmp=48;
        else if(tmp==55)
        tmp=52;
        if(hdata[j].type==tmp)
        score[j]+=10;
      }
      }
    }
    }
  }
  sute_shori:
  snum=0;
  smin=10000;
  for(j=0;hdata[j].type>=0;j++){
    if(score[j]<smin){
    snum=j;
    smin=score[j];
    }
  }
  for(j=0;sdata[j].type>=0;j++);
  sutep->type=hdata[snum].type;
  sutep->group=j;
  sutep->who=ply;
  sdata[j].type=hdata[snum].type;
  sdata[j].naki=0;
  latest_pointer=&sdata[j];
  hdata[snum].type=-1;
  sort_pai(hdata);
  return(0);
}
int th_same(struct h_pai *pdata,char ty)
{
  int i,cnt;
  cnt=0;
  for(i=0;pdata[i].type>=0;i++){
    if(pdata[i].naki<=0 && pdata[i].type==ty)
    cnt++;
  }
  return(cnt);
}
int th_near(struct h_pai *pdata,char ty)
{
  int i,cnt1,cnt2;
  cnt1=0;
  cnt2=0;
  for(i=0;pdata[i].type>=0;i++){
    if(pdata[i].naki<=0 && pdata[i].type<48){
    if(pdata[i].type==ty+1 || pdata[i].type==ty-1)
      cnt1=20;
    if(pdata[i].type==ty+2 || pdata[i].type==ty-2)
      cnt2=10;
    }
  }
  return(cnt1+cnt2);
}

int think_naki(int plyer,int sute_plyer,struct h_pai *sutep)
{
  int i,j,k;
  int i_have;
  int count;
  struct h_pai tmp[19];

  if(sutep->type<0)
    return(0);
  plyer=plyer % 4;
  sute_plyer=sute_plyer % 4;

  //  上がり
  copy_pai(tmp,pai[plyer]);
  for(i=0;tmp[i].type>=0;i++);
  tmp[i].type=sutep->type;
  tmp[i].naki=0;
  tmp[i].group=-1;
  tmp[i].who=0;
  tmp[i+1].type=-1;
  if(can_agari(plyer,sutep[0],1)>0){
    copy_pai(pai[plyer],tmp);
    latest_pointer->naki=1;
    agari=plyer;
    return(10);
  }
  //  既にリーチ済
  if(richi[plyer]>0)
    return(0);
  //  鳴き判定
  count=sute_plyer-plyer;
  if(count<0)
    count=count+4;
  if(count==3){ //  ポン、チー、カン
    j=0;
    k=0;
    i_have=0;
    for(i=0;pai[plyer][i].type>=0;i++){
    if(pai[plyer][i].type==sutep->type && pai[plyer][i].naki<=0)
      i_have=1;
    if(pai[plyer][i].naki==0 && pai[plyer][i].type==sutep->type){
      j++;
    }
    if(0<=sutep->type && sutep->type<48 && pai[plyer][i].naki==0){
      if(pai[plyer][i].type==(sutep->type-2))
      k=k | 1;
      if(pai[plyer][i].type==(sutep->type-1))
      k=k | 2;
      if(pai[plyer][i].type==(sutep->type+1))
      k=k | 4;
      if(pai[plyer][i].type==(sutep->type+2))
      k=k | 8;
    }
    }
    if(j==3 && can_kan(plyer, latest_sute)==1){    //  カンできる
    if((ply_think[plyer].think & 0x00f0)<0x0020)
      return(0);
    if((ply_think[plyer].think & 0x00f0)==0x0020){
      if(sutep->type<48 && ply_think[plyer].honitu!=(sutep->type/16+1))
      return(0);
      if(sutep->type<52 && sutep->type!=(kyoku/4+48) && sutep->type!=((4+plyer-oya_position) % 4+48))
      return(0);
      if(ply_think[plyer].tenpai==1)
      return(0);
    }
    sort_pai(pai[plyer]);
    do_kan(sutep[0],plyer,sute_plyer);
    get_1pai(plyer);
    sutep->type=-1;
    }else if(j==2){   //  ポンできる
    if((ply_think[plyer].think & 0x00f0)<0x0020)
      return(0);
    if((ply_think[plyer].think & 0x00f0)==0x0020){
      if(sutep->type<48 && ply_think[plyer].honitu!=(sutep->type/16+1))
      return(0);
      if(sutep->type<52 && sutep->type!=(kyoku/4+48) && sutep->type!=((4+plyer-oya_position) % 4+48))
      return(0);
      if(ply_think[plyer].tenpai==1)
      return(0);
    }
    sort_pai(pai[plyer]);
    do_pon(sutep[0],plyer,sute_plyer);
    sutep->type=-1;
    }else if((k & 3)==3 || (k & 6)==6 || (k & 0xC)==0xC){ //  チーできる
    if((ply_think[plyer].think & 0x00f0)<0x0020)
      return(0);
    if(ply_think[plyer].tenpai==1)
      return(0);
    if(ply_think[plyer].honitu!=(sutep->type/16+1))
      return(0);
    if(i_have>0)
      return(0);
    sort_pai(pai[plyer]);
    do_chi(sutep[0],plyer,sute_plyer);
    sutep->type=-1;
    }
  }else if(count!=0){ //  ポン、カン
    j=0;
    for(i=0;pai[plyer][i].type>=0;i++){
    if(pai[plyer][i].naki==0 && pai[plyer][i].type==sutep->type){
      j++;
    }
    }
    if(j==3 && can_kan(plyer, latest_sute)==1){        //  カンできる
    if((ply_think[plyer].think & 0x00f0)<0x0020)
      return(0);
    if((ply_think[plyer].think & 0x00f0)==0x0020){
      if(sutep->type<48 && ply_think[plyer].honitu!=(sutep->type/16+1))
      return(0);
      if(sutep->type<52 && sutep->type!=(kyoku/4+48) && sutep->type!=((4+plyer-oya_position) % 4+48))
      return(0);
      if(ply_think[plyer].tenpai==1)
      return(0);
    }
    sort_pai(pai[plyer]);
    do_kan(sutep[0],plyer,sute_plyer);
    get_1pai(plyer);
    sutep->type=-1;
    }else if(j==2){   //  ポンできる
    if((ply_think[plyer].think & 0x00f0)<0x0020)
      return(0);
    if((ply_think[plyer].think & 0x00f0)==0x0020){
      if(sutep->type<48 && ply_think[plyer].honitu!=(sutep->type/16+1))
      return(0);
      if(sutep->type<52 && sutep->type!=(kyoku/4+48) && sutep->type!=((4+plyer-oya_position) % 4+48))
      return(0);
      if(ply_think[plyer].tenpai==1)
      return(0);
    }
    sort_pai(pai[plyer]);
    do_pon(sutep[0],plyer,sute_plyer);
    sutep->type=-1;
    }
  }
  if((sutep->type)<0){
    sort_pai(pai[plyer]);
    return(1);
  }
  return(0);
}

void set_point(int ply, int ply_furi, int ron)
{
  int i;
  int pp;
  int n;

  // Ryukyoku
  if (ron<0){
    n=0;
    for(i=0;i<4;i++){
      if (tenpai[i]>0)
        n++;
    }
    if (n==1){
      for(i=0;i<4;i++){
        if (tenpai[i]>0)
          pnt_add[i]=3000;
        else 
          pnt_add[i]=-1000;
      }
    }else if (n==2){
      for(i=0;i<4;i++){
        if (tenpai[i]>0)
          pnt_add[i]=1500;
        else 
          pnt_add[i]=-1500;
      }
    }else if (n==3){
      for(i=0;i<4;i++){
        if (tenpai[i]>0)
          pnt_add[i]=1000;
        else 
          pnt_add[i]=-3000;
      }
    }else{
      for(i=0;i<4;i++)
        pnt_add[i]=0;
    }
    richi_bo_old=richi_bo_old+richi_bo_now;
    richi_bo_now=0;
    return;
  }
  
  // Chonbo
  if (point_max<=0){
    if (ply==oya_position){
      for(i=0;i<4;i++){
        if (i==ply)
          pnt_add[i]=-12000;
        else
          pnt_add[i]=4000;
      }
    }else{
      for(i=0;i<4;i++){
        if (i==ply)
          pnt_add[i]=-8000;
        else if (i==oya_position)
          pnt_add[i]=4000;
        else
          pnt_add[i]=2000;
      }
    }    
    for(i=0;i<4;i++){
      if (richi[i]>0)
        pnt_add[i]=pnt_add[i]+1000;
    }
    richi_bo_now=0;
    return;
  }

  // Oya
  if (ply==oya_position){
    if (ron>0){
      if (point_max==2000)
        pp=2900;
      else if (point_max==2300)
        pp=3400;
      else if (point_max==3900)
        pp=5800;
      else if (point_max==5200)
        pp=7700;
      else if (point_max==7100)
        pp=10600;
      else
        pp=point_max+(point_max+100)/200*100;
    }else
      pp=(point_max+100)/200*300;
  }else
    pp=point_max;

  // Ron
  if (ron>0){
    for(i=0;i<4;i++){
      if (i==ply)
        pnt_add[i]=pp+hon_ba*100;
      else if (i==ply_furi)
        pnt_add[i]=-pp-hon_ba*100;
      else
        pnt_add[i]=0;
    }
  // Tumo
  }else if(ply==oya_position){
    n=((point_max+100)/200)*100;
    for(i=0;i<4;i++){
      if (i==ply)
        pnt_add[i]=n*3+hon_ba*300;
      else
        pnt_add[i]=-n-hon_ba*100;
    }
  }else{
    n=((point_max+100)/200)*100;
    for(i=0;i<4;i++){
      if (i==ply){
        pnt_add[i]=n+((n+100)/200)*200;
        pnt_add[i]=pnt_add[i]+hon_ba*300;
      }else if (i==oya_position){
        pnt_add[i]=-n;
        pnt_add[i]=pnt_add[i]-hon_ba*100;
      }else{
        pnt_add[i]=-((n+100)/200)*100;
        pnt_add[i]=pnt_add[i]-hon_ba*100;
      }
    }
  }

  // Richi bo
  if (richi[ply]>0){
    pnt_add[ply]=pnt_add[ply]+(richi_bo_old+richi_bo_now)*1000;
    richi_bo_old=0;
    richi_bo_now=0;
  }else{
    pnt_add[ply]=pnt_add[ply]+richi_bo_now*1000;
    richi_bo_now=0;
  }
}
void add_point()
{
  int i;
  for(i=0;i<4;i++)
    points[i]=points[i]+pnt_add[i];
}
